@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.3-branch/Apollonius_graph_2/demo/Apollonius_graph_2/edit_vertex_layer.h $
-// $Id: edit_vertex_layer.h 37003 2007-03-10 16:55:12Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Apollonius_graph_2/demo/Apollonius_graph_2/edit_vertex_layer.h $
+// $Id: edit_vertex_layer.h 48557 2009-03-27 14:10:29Z mkaravel $
 //
 //
 // Author(s)     : Menelaos Karavelas <mkaravel@cse.nd.edu>
@@ -20,7 +20,6 @@
 #ifndef APOLLONIUS_GRAPH_2_EDIT_VERTEX_H
 #define APOLLONIUS_GRAPH_2_EDIT_VERTEX_H
 
-#ifdef CGAL_USE_QT
 
 #include <CGAL/IO/Qt_widget.h>
 #include <CGAL/IO/Qt_widget_layer.h>
@@ -73,7 +72,6 @@ signals:
   void apollonius_graph_changed();
 };
 
-#include "edit_vertex_layer.moc"
 
 
 template <class AG>
@@ -279,6 +277,5 @@ private:
 
 
 
-#endif // CGAL_USE_QT
 
 #endif // APOLLONIUS_GRAPH_2_EDIT_VERTEX_H
