@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.4-branch/Boolean_set_operations_2/demo/Boolean_set_operations_2/Qt_widget_circle_segment_2.h $
-// $Id: Qt_widget_circle_segment_2.h 39985 2007-08-22 22:58:35Z golubevs $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Boolean_set_operations_2/demo/Boolean_set_operations_2/Qt_widget_circle_segment_2.h $
+// $Id: Qt_widget_circle_segment_2.h 49046 2009-04-30 13:39:06Z spion $
 //
 //
 // Author(s)     : Baruch Zukerman <baruchzu@post.tau.ac.il>
@@ -35,13 +35,13 @@ operator<<(CGAL::Qt_widget & widget,
   if(arc.orientation() == COLLINEAR)
   {
     typedef Simple_cartesian<double> DK;
-    typedef DK::Segment_2            DS;
+    typedef DK::Segment_2            DS_;
     typedef DK::Point_2              DP;
     double sx = CGAL::to_double(arc.source().x());
     double sy = CGAL::to_double(arc.source().y());
     double tx = CGAL::to_double(arc.target().x());
     double ty = CGAL::to_double(arc.target().y());
-    DS seg(DP(sx ,sy), DP(tx, ty));
+    DS_ seg(DP(sx ,sy), DP(tx, ty));
     widget << seg;
     return (widget);
   }
