@@ -1,15 +1,16 @@
 #include "Viewer.h"
-#include "Scene.h"
+#include "Scene_draw_interface.h"
 
 Viewer::Viewer(QWidget* parent, bool antialiasing)
   : QGLViewer(parent),
     scene(0),
-    antialiasing(antialiasing)
+    antialiasing(antialiasing),
+    twosides(false)
 {
   setBackgroundColor(::Qt::white);
 }
 
-void Viewer::setScene(Scene* scene)
+void Viewer::setScene(Scene_draw_interface* scene)
 {
   this->scene = scene;
 }
@@ -20,6 +21,12 @@ void Viewer::setAntiAliasing(bool b)
   updateGL();
 }
 
+void Viewer::setTwoSides(bool b)
+{
+  twosides = b;
+  updateGL();
+}
+
 void Viewer::draw()
 {
   draw_aux(false);
@@ -38,12 +45,17 @@ void Viewer::draw_aux(bool with_names)
     return;
 
   ::glLineWidth(1.0f);
-  ::glPointSize(10.f);
+  ::glPointSize(2.f);
   ::glEnable(GL_POLYGON_OFFSET_FILL);
   ::glPolygonOffset(1.0f,1.0f);
   ::glClearColor(1.0f,1.0f,1.0f,0.0f);
   ::glPolygonMode(GL_FRONT_AND_BACK,GL_FILL);
 
+  if(twosides)
+    ::glLightModeli(GL_LIGHT_MODEL_TWO_SIDE, GL_TRUE);
+  else
+    ::glLightModeli(GL_LIGHT_MODEL_TWO_SIDE, GL_FALSE);
+
   if(antiAliasing())
   {
     ::glEnable(GL_BLEND);
@@ -59,7 +71,10 @@ void Viewer::draw_aux(bool with_names)
     ::glBlendFunc(GL_ONE, GL_ZERO);
     ::glHint(GL_LINE_SMOOTH_HINT, GL_FASTEST);
   }
-  scene->draw(with_names);
+  if(with_names)
+    scene->drawWithNames();
+  else
+    scene->draw();
 }
 
 void Viewer::drawWithNames()
