@@ -6,15 +6,15 @@
 #include <list>
 #include <cassert>
 
-typedef CGAL::Exact_predicates_inexact_constructions_kernel K;
+typedef CGAL::Exact_predicates_inexact_constructions_kernel Gt;
 
-typedef CGAL::Alpha_shape_vertex_base_3<K>          Vb;
-typedef CGAL::Alpha_shape_cell_base_3<K>            Fb;
-typedef CGAL::Triangulation_data_structure_3<Vb,Fb> Tds;
-typedef CGAL::Delaunay_triangulation_3<K,Tds>       Triangulation_3;
-typedef CGAL::Alpha_shape_3<Triangulation_3>        Alpha_shape_3;
+typedef CGAL::Alpha_shape_vertex_base_3<Gt>          Vb;
+typedef CGAL::Alpha_shape_cell_base_3<Gt>            Fb;
+typedef CGAL::Triangulation_data_structure_3<Vb,Fb>  Tds;
+typedef CGAL::Delaunay_triangulation_3<Gt,Tds>       Triangulation_3;
+typedef CGAL::Alpha_shape_3<Triangulation_3>         Alpha_shape_3;
 
-typedef K::Point_3                                  Point;
+typedef Gt::Point_3                                  Point;
 typedef Alpha_shape_3::Alpha_iterator               Alpha_iterator;
 
 int main()
