@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Arrangement_on_surface_2/include/CGAL/Arr_bounded_planar_topology_traits_2.h $
-// $Id: Arr_bounded_planar_topology_traits_2.h 50366 2009-07-05 12:56:48Z efif $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Arrangement_on_surface_2/include/CGAL/Arr_bounded_planar_topology_traits_2.h $
+// $Id: Arr_bounded_planar_topology_traits_2.h 51984 2009-09-20 16:18:10Z efif $
 // 
 //
 // Author(s) : Ron Wein        <wein@post.tau.ac.il>
@@ -84,19 +84,19 @@ public:
   ///! \name The side tags
   //@{
   // are inherited from the geometry traits
-  typedef typename Traits_adaptor_2::Arr_left_side_tag   Arr_left_side_tag;
-  typedef typename Traits_adaptor_2::Arr_bottom_side_tag Arr_bottom_side_tag;
-  typedef typename Traits_adaptor_2::Arr_top_side_tag    Arr_top_side_tag;
-  typedef typename Traits_adaptor_2::Arr_right_side_tag  Arr_right_side_tag;
+  typedef typename Traits_adaptor_2::Arr_left_side_category   Arr_left_side_category;
+  typedef typename Traits_adaptor_2::Arr_bottom_side_category Arr_bottom_side_category;
+  typedef typename Traits_adaptor_2::Arr_top_side_category    Arr_top_side_category;
+  typedef typename Traits_adaptor_2::Arr_right_side_category  Arr_right_side_category;
   
   BOOST_MPL_ASSERT
-  ((boost::is_same< Arr_left_side_tag, Arr_oblivious_side_tag >));
+  ((boost::is_same< Arr_left_side_category, Arr_oblivious_side_tag >));
   BOOST_MPL_ASSERT
-  ((boost::is_same< Arr_bottom_side_tag, Arr_oblivious_side_tag >));
+  ((boost::is_same< Arr_bottom_side_category, Arr_oblivious_side_tag >));
   BOOST_MPL_ASSERT
-  ((boost::is_same< Arr_top_side_tag, Arr_oblivious_side_tag >));
+  ((boost::is_same< Arr_top_side_category, Arr_oblivious_side_tag >));
   BOOST_MPL_ASSERT
-  ((boost::is_same< Arr_right_side_tag, Arr_oblivious_side_tag >));
+  ((boost::is_same< Arr_right_side_category, Arr_oblivious_side_tag >));
   //@}
 
   /*! \struct
