@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Arrangement_on_surface_2/include/CGAL/Arr_landmarks_point_location.h $
-// $Id: Arr_landmarks_point_location.h 41926 2008-01-30 21:03:54Z golubevs $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Arrangement_on_surface_2/include/CGAL/Arr_landmarks_point_location.h $
+// $Id: Arr_landmarks_point_location.h 51066 2009-08-05 12:57:00Z efif $
 // 
 //
 // Author(s)     : Idit Haran   <haranidi@post.tau.ac.il>
@@ -175,9 +175,7 @@ public:
 
     CGAL_assertion(lm_gen != NULL);
     if (lm_gen)
-    {
-      lm_gen->detach(p_arr);
-    }
+      lm_gen->detach();
   }
   
   /*!
