@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Arrangement_on_surface_2/include/CGAL/Arr_rational_arc_traits_2.h $
-// $Id: Arr_rational_arc_traits_2.h 49772 2009-06-03 21:25:53Z eric $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Arrangement_on_surface_2/include/CGAL/Arr_rational_arc_traits_2.h $
+// $Id: Arr_rational_arc_traits_2.h 51984 2009-09-20 16:18:10Z efif $
 // 
 //
 // Author(s)     : Ron Wein          <wein@post.tau.ac.il>
@@ -57,10 +57,10 @@ public:
   typedef Tag_true                                      Has_left_category;
   typedef Tag_true                                      Has_merge_category;
 
-  typedef Arr_open_side_tag                             Arr_left_side_tag;
-  typedef Arr_open_side_tag                             Arr_bottom_side_tag;
-  typedef Arr_open_side_tag                             Arr_top_side_tag;
-  typedef Arr_open_side_tag                             Arr_right_side_tag;
+  typedef Arr_open_side_tag                             Arr_left_side_category;
+  typedef Arr_open_side_tag                             Arr_bottom_side_category;
+  typedef Arr_open_side_tag                             Arr_top_side_category;
+  typedef Arr_open_side_tag                             Arr_right_side_category;
 
   // Traits objects:
   typedef _Rational_arc_2<Alg_kernel, Nt_traits>        Curve_2;
