@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Arrangement_on_surface_2/include/CGAL/Arr_tracing_traits_2.h $
-// $Id: Arr_tracing_traits_2.h 50366 2009-07-05 12:56:48Z efif $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Arrangement_on_surface_2/include/CGAL/Arr_tracing_traits_2.h $
+// $Id: Arr_tracing_traits_2.h 51984 2009-09-20 16:18:10Z efif $
 //
 // Author(s)     : Efi Fogel    <efif@post.tau.ac.il>
 
@@ -192,14 +192,14 @@ public:
   typedef typename Base::Has_left_category      Has_left_category;
   typedef typename Base::Has_merge_category     Has_merge_category;
 
-  typedef typename CGALi::Arr_complete_left_side_tag< Base >::Tag
-                                                Arr_left_side_tag;
-  typedef typename CGALi::Arr_complete_bottom_side_tag< Base >::Tag
-                                                Arr_bottom_side_tag;
-  typedef typename CGALi::Arr_complete_top_side_tag< Base >::Tag
-                                                Arr_top_side_tag;
-  typedef typename CGALi::Arr_complete_right_side_tag< Base >::Tag
-                                                Arr_right_side_tag;
+  typedef typename internal::Arr_complete_left_side_tag< Base >::Tag
+                                                Arr_left_side_category;
+  typedef typename internal::Arr_complete_bottom_side_tag< Base >::Tag
+                                                Arr_bottom_side_category;
+  typedef typename internal::Arr_complete_top_side_tag< Base >::Tag
+                                                Arr_top_side_category;
+  typedef typename internal::Arr_complete_right_side_tag< Base >::Tag
+                                                Arr_right_side_category;
   
   typedef typename Base::Point_2                Point_2;
   typedef typename Base::X_monotone_curve_2     X_monotone_curve_2;
