@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Arrangement_on_surface_2/include/CGAL/Arrangement_2/Arr_on_surface_with_history_2_impl.h $
-// $Id: Arr_on_surface_with_history_2_impl.h 50366 2009-07-05 12:56:48Z efif $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Arrangement_on_surface_2/include/CGAL/Arrangement_2/Arr_on_surface_with_history_2_impl.h $
+// $Id: Arr_on_surface_with_history_2_impl.h 53081 2009-11-17 20:48:24Z efif $
 // 
 //
 // Author(s)     : Ron Wein         <wein@post.tau.ac.il>
@@ -58,7 +58,7 @@ Arrangement_on_surface_with_history_2 (const Self& arr) :
 template<class GeomTr, class TopTr>
 Arrangement_on_surface_with_history_2<GeomTr,TopTr>::
 Arrangement_on_surface_with_history_2 (const Geometry_traits_2 * tr) :
-  Base_arr_2 (static_cast<Data_traits_2*> (tr))
+  Base_arr_2 (static_cast<const Data_traits_2*> (tr))
 {
   m_observer.attach (*this);
 }
