@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Arrangement_on_surface_2/include/CGAL/Arrangement_2/Arr_traits_adaptor_2_dispatching.h $
-// $Id: Arr_traits_adaptor_2_dispatching.h 49772 2009-06-03 21:25:53Z eric $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Arrangement_on_surface_2/include/CGAL/Arrangement_2/Arr_traits_adaptor_2_dispatching.h $
+// $Id: Arr_traits_adaptor_2_dispatching.h 51984 2009-09-20 16:18:10Z efif $
 // 
 //
 // Author(s): Eric Berberich    <ericb@post.tau.ac.il>
@@ -42,7 +42,7 @@ struct Arr_use_dummy_tag {};
 //! tag to specify to call the corresponding traits method
 struct Arr_use_traits_tag {};
 
-namespace CGALi {
+namespace internal {
 
 ////////////////
 // left-right //
@@ -609,75 +609,75 @@ struct Arr_left_right_implementation_dispatch {
 public:
   
   //! This instance's first template parameter
-  typedef ArrLeftSideTag   Arr_left_side_tag;
+  typedef ArrLeftSideTag   Arr_left_side_category;
   
   //! This instance's second template parameter
-  typedef ArrRightSideTag  Arr_right_side_tag;
+  typedef ArrRightSideTag  Arr_right_side_category;
   
 public:
   
   //! tag type for Parameter_space_in_x_2 (curve-end signature)
-  typedef typename CGALi::Or_traits<
+  typedef typename internal::Or_traits<
     typename 
-    CGALi::Parameter_space_in_x_2::Curve_end< Arr_left_side_tag >::type,
+    internal::Parameter_space_in_x_2::Curve_end< Arr_left_side_category >::type,
     typename 
-    CGALi::Parameter_space_in_x_2::Curve_end< Arr_right_side_tag >::type 
+    internal::Parameter_space_in_x_2::Curve_end< Arr_right_side_category >::type 
   >::type
   Parameter_space_in_x_2_curve_end_tag;
 
   //! tag type for Parameter_space_in_x_2 (curve signature)
-  typedef typename CGALi::Or_traits<
+  typedef typename internal::Or_traits<
     typename 
-    CGALi::Parameter_space_in_x_2::Curve< Arr_left_side_tag >::type,
+    internal::Parameter_space_in_x_2::Curve< Arr_left_side_category >::type,
     typename 
-    CGALi::Parameter_space_in_x_2::Curve< Arr_right_side_tag >::type 
+    internal::Parameter_space_in_x_2::Curve< Arr_right_side_category >::type 
   >::type
   Parameter_space_in_x_2_curve_tag;
   
   //! tag type for Parameter_space_in_x_2 (point signature)
-  typedef typename CGALi::Or_traits<
+  typedef typename internal::Or_traits<
     typename
-    CGALi::Parameter_space_in_x_2::Point< Arr_left_side_tag >::type,
+    internal::Parameter_space_in_x_2::Point< Arr_left_side_category >::type,
     typename
-    CGALi::Parameter_space_in_x_2::Point< Arr_right_side_tag >::type >::type
+    internal::Parameter_space_in_x_2::Point< Arr_right_side_category >::type >::type
   Parameter_space_in_x_2_point_tag;
 
   
   //! tag type for Compare_y_near_boundary_2 (curve-ends signature)
-  typedef typename CGALi::Or_traits<
+  typedef typename internal::Or_traits<
     typename 
-    CGALi::Compare_y_near_boundary_2::Curve_ends< Arr_left_side_tag >::type,
+    internal::Compare_y_near_boundary_2::Curve_ends< Arr_left_side_category >::type,
     typename 
-    CGALi::Compare_y_near_boundary_2::Curve_ends< Arr_right_side_tag >::type 
+    internal::Compare_y_near_boundary_2::Curve_ends< Arr_right_side_category >::type 
   >::type
   Compare_y_near_boundary_2_curve_ends_tag;
 
   // TODO Compare_y_right_of_2 ???
 
   //! tag type for Compare_y_on_boundary_2 (points signature)
-  typedef typename CGALi::Or_traits<
+  typedef typename internal::Or_traits<
     typename 
-    CGALi::Compare_y_on_boundary_2::Points< Arr_left_side_tag >::type,
+    internal::Compare_y_on_boundary_2::Points< Arr_left_side_category >::type,
     typename 
-    CGALi::Compare_y_on_boundary_2::Points< Arr_right_side_tag >::type 
+    internal::Compare_y_on_boundary_2::Points< Arr_right_side_category >::type 
   >::type
   Compare_y_on_boundary_2_points_tag;
 
   //! tag type for Is_on_y_identification_2 (point signature)
-  typedef typename CGALi::Or_traits<
+  typedef typename internal::Or_traits<
     typename 
-    CGALi::Is_on_y_identification_2::Point< Arr_left_side_tag >::type,
+    internal::Is_on_y_identification_2::Point< Arr_left_side_category >::type,
     typename 
-    CGALi::Is_on_y_identification_2::Point< Arr_right_side_tag >::type 
+    internal::Is_on_y_identification_2::Point< Arr_right_side_category >::type 
   >::type
   Is_on_y_identification_2_point_tag;
 
   //! tag type for Is_on_y_identification_2 (curve signature)
-  typedef typename CGALi::Or_traits<
+  typedef typename internal::Or_traits<
     typename 
-    CGALi::Is_on_y_identification_2::Curve< Arr_left_side_tag >::type,
+    internal::Is_on_y_identification_2::Curve< Arr_left_side_category >::type,
     typename 
-    CGALi::Is_on_y_identification_2::Curve< Arr_right_side_tag >::type 
+    internal::Is_on_y_identification_2::Curve< Arr_right_side_category >::type 
   >::type
   Is_on_y_identification_2_curve_tag;
 
@@ -690,88 +690,88 @@ struct Arr_bottom_top_implementation_dispatch {
 public:
   
   //! This instance's first template parameter
-  typedef ArrBottomSideTag   Arr_bottom_side_tag;
+  typedef ArrBottomSideTag   Arr_bottom_side_category;
   
   //! This instance's second template parameter
-  typedef ArrTopSideTag  Arr_top_side_tag;
+  typedef ArrTopSideTag  Arr_top_side_category;
   
 public:
 
   //! tag type for Parameter_space_in_y_2 (curve-end signature)
-  typedef typename CGALi::Or_traits<
+  typedef typename internal::Or_traits<
     typename 
-    CGALi::Parameter_space_in_y_2::Curve_end< Arr_bottom_side_tag >::type,
+    internal::Parameter_space_in_y_2::Curve_end< Arr_bottom_side_category >::type,
     typename 
-    CGALi::Parameter_space_in_y_2::Curve_end< Arr_top_side_tag >::type 
+    internal::Parameter_space_in_y_2::Curve_end< Arr_top_side_category >::type 
   >::type
   Parameter_space_in_y_2_curve_end_tag;
 
   //! tag type for Parameter_space_in_y_2 (curve signature)
-  typedef typename CGALi::Or_traits<
+  typedef typename internal::Or_traits<
     typename 
-    CGALi::Parameter_space_in_y_2::Curve< Arr_bottom_side_tag >::type,
+    internal::Parameter_space_in_y_2::Curve< Arr_bottom_side_category >::type,
     typename 
-    CGALi::Parameter_space_in_y_2::Curve< Arr_top_side_tag >::type 
+    internal::Parameter_space_in_y_2::Curve< Arr_top_side_category >::type 
   >::type
   Parameter_space_in_y_2_curve_tag;
   
   //! tag type for Parameter_space_in_y_2 (point signature)
-  typedef typename CGALi::Or_traits<
+  typedef typename internal::Or_traits<
     typename
-    CGALi::Parameter_space_in_y_2::Point< Arr_bottom_side_tag >::type,
+    internal::Parameter_space_in_y_2::Point< Arr_bottom_side_category >::type,
     typename
-    CGALi::Parameter_space_in_y_2::Point< Arr_top_side_tag >::type >::type
+    internal::Parameter_space_in_y_2::Point< Arr_top_side_category >::type >::type
   Parameter_space_in_y_2_point_tag;
   
   //! tag type for Compare_x_near_boundary_2 (point-curve-end signature)
-  typedef typename CGALi::Or_traits<
+  typedef typename internal::Or_traits<
     typename 
-    CGALi::Compare_x_near_boundary_2::Point_curve_end< Arr_bottom_side_tag >
+    internal::Compare_x_near_boundary_2::Point_curve_end< Arr_bottom_side_category >
     ::type,
     typename 
-    CGALi::Compare_x_near_boundary_2::Point_curve_end< Arr_top_side_tag >::type 
+    internal::Compare_x_near_boundary_2::Point_curve_end< Arr_top_side_category >::type 
   >::type
   Compare_x_near_boundary_2_point_curve_end_tag;
 
   //! tag type for Compare_x_near_boundary_2 (curve-ends signature)
-  typedef typename CGALi::Or_traits<
+  typedef typename internal::Or_traits<
     typename 
-    CGALi::Compare_x_near_boundary_2::Curve_ends< Arr_bottom_side_tag >::type,
+    internal::Compare_x_near_boundary_2::Curve_ends< Arr_bottom_side_category >::type,
     typename 
-    CGALi::Compare_x_near_boundary_2::Curve_ends< Arr_top_side_tag >::type 
+    internal::Compare_x_near_boundary_2::Curve_ends< Arr_top_side_category >::type 
   >::type
   Compare_x_near_boundary_2_curve_ends_tag;
 
   //! tag type for Compare_y_on_boundary_2 (points signature)
-  typedef typename CGALi::Or_traits<
+  typedef typename internal::Or_traits<
     typename 
-    CGALi::Compare_x_on_boundary_2::Points< Arr_bottom_side_tag >::type,
+    internal::Compare_x_on_boundary_2::Points< Arr_bottom_side_category >::type,
     typename 
-    CGALi::Compare_x_on_boundary_2::Points< Arr_top_side_tag >::type 
+    internal::Compare_x_on_boundary_2::Points< Arr_top_side_category >::type 
   >::type
   Compare_x_on_boundary_2_points_tag;
 
   //! tag type for Is_on_x_identification_2 (point signature)
-  typedef typename CGALi::Or_traits<
+  typedef typename internal::Or_traits<
     typename 
-    CGALi::Is_on_x_identification_2::Point< Arr_bottom_side_tag >::type,
+    internal::Is_on_x_identification_2::Point< Arr_bottom_side_category >::type,
     typename 
-    CGALi::Is_on_x_identification_2::Point< Arr_top_side_tag >::type 
+    internal::Is_on_x_identification_2::Point< Arr_top_side_category >::type 
   >::type
   Is_on_x_identification_2_point_tag;
 
   //! tag type for Is_on_x_identification_2 (curve signature)
-  typedef typename CGALi::Or_traits<
+  typedef typename internal::Or_traits<
     typename 
-    CGALi::Is_on_x_identification_2::Curve< Arr_bottom_side_tag >::type,
+    internal::Is_on_x_identification_2::Curve< Arr_bottom_side_category >::type,
     typename 
-    CGALi::Is_on_x_identification_2::Curve< Arr_top_side_tag >::type 
+    internal::Is_on_x_identification_2::Curve< Arr_top_side_category >::type 
   >::type
   Is_on_x_identification_2_curve_tag;
   
 }; // bottom-top-dispatch
 
-} // namespace CGALi
+} // namespace internal
 
 CGAL_END_NAMESPACE
 
