@@ -15,8 +15,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.4-branch/Kernel_23/include/CGAL/Bbox_3.h $
-// $Id: Bbox_3.h 45152 2008-08-26 13:08:16Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Kernel_23/include/CGAL/Bbox_3.h $
+// $Id: Bbox_3.h 49057 2009-04-30 14:03:52Z spion $
 //
 // Author(s)     : Andreas Fabri
 
@@ -35,7 +35,7 @@ struct Simple_cartesian;
 
 class Bbox_3
 {
-  CGAL::array<double, 6>   rep;
+  cpp0x::array<double, 6>   rep;
 
 public:
 
