@@ -11,18 +11,30 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.3-branch/Boolean_set_operations_2/include/CGAL/Boolean_set_operations_2/Gps_agg_op.h $
-// $Id: Gps_agg_op.h 28831 2006-02-27 14:28:18Z baruchzu $ $Date: 2006-02-27 15:28:18 +0100 (Mon, 27 Feb 2006) $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Boolean_set_operations_2/include/CGAL/Boolean_set_operations_2/Gps_agg_op.h $
+// $Id: Gps_agg_op.h 50368 2009-07-05 13:14:14Z efif $ $Date: 2009-07-05 15:14:14 +0200 (Sun, 05 Jul 2009) $
 // 
 //
 // Author(s)     : Baruch Zukerman <baruchzu@post.tau.ac.il>
+//                 Ophir Setter    <ophir.setter@cs.tau.ac.il>
 
 #ifndef CGAL_GPS_AGG_OP_H
 #define CGAL_GPS_AGG_OP_H
 
+/*!
+  \file   Gps_agg_op.h
+  \brief  The class Gps_agg_op is responsible for aggregated Boolean set 
+          operations depending on a visitor template parameter.
+          It uses the sweep-line algorithm from the arrangement packages
+          to overlay all the polygon sets, and then it uses a BFS that 
+          determines which of the faces is contained in the result using
+          the visitor.
+*/
+
+
 #include <CGAL/Boolean_set_operations_2/Gps_agg_meta_traits.h>
 #include <CGAL/Boolean_set_operations_2/Gps_agg_op_sweep.h>
-#include <CGAL/Sweep_line_2/Arr_construction_curve.h>
+#include <CGAL/Sweep_line_2/Arr_construction_subcurve.h>
 #include <CGAL/Sweep_line_2/Arr_construction_event.h>
 
 #include <CGAL/Boolean_set_operations_2/Gps_agg_op_visitor.h>
@@ -38,7 +50,7 @@ template <class Arrangement_, class Bfs_visitor_>
 class Gps_agg_op
 {
   typedef Arrangement_                                Arrangement_2;
-  typedef typename Arrangement_2::Traits_2            Traits_2;
+  typedef typename Arrangement_2::Traits_adaptor_2    Traits_2;
   typedef typename Traits_2::Curve_const_iterator     Curve_const_iterator;
   typedef Gps_agg_meta_traits<Arrangement_2>          Meta_traits;
   typedef typename Meta_traits::Curve_data            Curve_data;
@@ -56,10 +68,12 @@ class Gps_agg_op
   typedef std::pair<Arrangement_2 *,
                     std::vector<Vertex_handle> *>     Arr_entry;
 
-  typedef Arr_construction_curve<Meta_traits>         Subcurve; 
+  typedef Arr_construction_subcurve<Meta_traits>      Subcurve; 
+
   typedef Arr_construction_event<Meta_traits,
                                  Subcurve,
-                                 Halfedge_handle>     Base_event;
+//				 Halfedge_handle>       Base_event;
+                                 Arrangement_2>       Base_event;
 
   typedef Indexed_event<Base_event>                   Event;
 
@@ -94,7 +108,7 @@ public:
 
   /*! Constructor. */
   Gps_agg_op (Arrangement_2& arr, std::vector<Vertex_handle>& vert_vec,
-              Traits_2& tr) :
+              const Traits_2 & tr) :
     m_arr (&arr),
     m_traits(new Meta_traits(tr)),
     m_visitor (&arr, &m_edges_hash, &vert_vec),
@@ -104,7 +118,7 @@ public:
   void sweep_arrangements(unsigned int lower,
                           unsigned int upper,
                           unsigned int jump,
-                          std::vector<Arr_entry>&  arr_vec)
+                          std::vector<Arr_entry>& arr_vec)
   {
     std::list<Meta_X_monotone_curve_2> curves_list;
 
@@ -118,8 +132,10 @@ public:
 
     for (i = lower; i <= upper; i += jump, ++n_pgn)
     {
+      // The BFS scan (after the loop) starts in the reference face,
+      // so we count the number of polygons that contain the reference face.
       Arrangement_2* arr = (arr_vec[i]).first;
-      if (arr->unbounded_face()->contained())
+      if (arr->reference_face()->contained())
         ++n_inf_pgn;
 
       Edge_iterator  itr = arr->edges_begin();
@@ -130,8 +146,7 @@ public:
         Halfedge_iterator he = itr;
         if(he->face()->contained() == he->twin()->face()->contained())
           continue;
-
-        if(he->direction() == LARGER)
+        if ((Arr_halfedge_direction)he->direction() == ARR_RIGHT_TO_LEFT)
           he = he->twin();
 
         Curve_data cv_data(arr, he, 1, 0);
@@ -143,9 +158,9 @@ public:
                         lower, upper, jump,
                         arr_vec);
 
-    m_faces_hash[m_arr->unbounded_face()] = n_inf_pgn; 
+    m_faces_hash[m_arr->reference_face()] = n_inf_pgn; 
     Bfs_visitor visitor(&m_edges_hash, &m_faces_hash, n_pgn);
-    visitor.visit_ubf(m_arr->unbounded_face(), n_inf_pgn);
+    visitor.visit_ubf(m_arr->faces_begin(), n_inf_pgn);
     Bfs_scanner scanner(visitor);
     scanner.scan(*m_arr);
     visitor.after_scan(*m_arr);
