@@ -11,11 +11,12 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.4-branch/Boolean_set_operations_2/include/CGAL/Boolean_set_operations_2/Gps_bfs_scanner.h $
-// $Id: Gps_bfs_scanner.h 39799 2007-08-09 13:35:21Z golubevs $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Boolean_set_operations_2/include/CGAL/Boolean_set_operations_2/Gps_bfs_scanner.h $
+// $Id: Gps_bfs_scanner.h 48113 2009-02-17 16:21:43Z ophirset $
 // 
 //
 // Author(s)     : Baruch Zukerman <baruchzu@post.tau.ac.il>
+//                 Ophir Setter    <ophir.setter@cs.tau.ac.il>
 
 #ifndef CGAL_GPS_BFS_SCANNER_H
 #define CGAL_GPS_BFS_SCANNER_H
@@ -30,7 +31,7 @@ class Gps_bfs_scanner
 {
   typedef Arrangement_     Arrangement;
 
-  typedef typename Arrangement::Inner_ccb_iterator    Hole_iterator;
+  typedef typename Arrangement::Inner_ccb_iterator    Inner_ccb_iterator;
   typedef typename Arrangement::Ccb_halfedge_circulator 
                                                   Ccb_halfedge_circulator;
   typedef typename Arrangement::Face_iterator    Face_iterator;
@@ -40,7 +41,7 @@ class Gps_bfs_scanner
 
 protected:
   Visitor*                     m_visitor;
-  std::queue<Hole_iterator>   m_holes;
+  std::queue<Inner_ccb_iterator>   m_holes;
   std::stack<Ccb_halfedge_circulator>  m_ccb_stcak;
 
 public:
@@ -50,15 +51,23 @@ public:
 
   void scan(Arrangement& arr)
   {
-    Face_iterator ubf = arr.unbounded_face();
-    ubf->set_visited(true);
-    push_to_queue_holes_of_face(ubf);
-    
-    while(!m_holes.empty())
+    Face_iterator ubf;
+    for (ubf = arr.faces_begin(); ubf != arr.faces_end(); ++ubf)
     {
-      Hole_iterator hole = m_holes.front();
-      m_holes.pop();
-      scan(*hole);
+      if (ubf->number_of_outer_ccbs() != 0)
+        continue;
+      if (ubf->visited() == true)
+        continue;
+
+      ubf->set_visited(true);
+      push_to_queue_holes_of_face(ubf);
+      
+      while(!m_holes.empty())
+      {
+        Inner_ccb_iterator hole = m_holes.front();
+        m_holes.pop();
+        scan(*hole);
+      }
     }
   }
 
@@ -86,7 +95,7 @@ public:
       {
         push_to_queue_holes_of_face(he->twin()->face());
         new_f->set_visited(true);
-        m_visitor->flip_face(he->face(), new_f, he); 
+        m_visitor->discovered_face(he->face(), new_f, he); 
         
         //scan(he->twin());
         m_ccb_stcak.push(he->twin());
@@ -99,7 +108,8 @@ public:
   
   void push_to_queue_holes_of_face(Face_iterator f)
   {
-    for(Hole_iterator hit = f->holes_begin(); hit!= f->holes_end(); ++hit)
+    for(Inner_ccb_iterator hit = f->inner_ccbs_begin(); 
+        hit!= f->inner_ccbs_end(); ++hit)
     {
       m_holes.push(hit);
     }
