@@ -15,8 +15,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Cartesian_kernel/include/CGAL/Cartesian/Triangle_3.h $
-// $Id: Triangle_3.h 49057 2009-04-30 14:03:52Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Cartesian_kernel/include/CGAL/Cartesian/Triangle_3.h $
+// $Id: Triangle_3.h 51456 2009-08-24 17:10:04Z spion $
 // 
 //
 // Author(s)     : Andreas Fabri
@@ -112,7 +112,7 @@ CGAL_KERNEL_MEDIUM_INLINE
 typename TriangleC3<R>::FT
 TriangleC3<R>::squared_area() const
 {
-  return CGALi::squared_area(vertex(0), vertex(1), vertex(2), R());
+  return internal::squared_area(vertex(0), vertex(1), vertex(2), R());
 }
 
 template < class R >
