@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Circular_kernel_2/include/CGAL/Circular_kernel_2/Circular_arc_2.h $
-// $Id: Circular_arc_2.h 45974 2008-10-01 15:12:01Z pmachado $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Circular_kernel_2/include/CGAL/Circular_kernel_2/Circular_arc_2.h $
+// $Id: Circular_arc_2.h 51456 2009-08-24 17:10:04Z spion $
 //
 // Author(s)     : Monique Teillaud, Sylvain Pion, Pedro Machado
 
@@ -42,7 +42,7 @@
 #include <CGAL/intersections.h>
 
 namespace CGAL {
-namespace CGALi {
+namespace internal {
 
   template <class CK >
   class Circular_arc_2
@@ -66,7 +66,7 @@ namespace CGALi {
   
 #ifdef CGAL_USEFUL_MAPS_FOR_THE_CIRCULAR_KERNEL
   public:
-    typedef CGALi::Intersection_line_2_circle_2_map Table;
+    typedef internal::Intersection_line_2_circle_2_map Table;
 #endif
 
   private:
@@ -657,14 +657,14 @@ public:
 
 #ifdef CGAL_INTERSECTION_MAP_FOR_XMONOTONIC_ARC_WITH_SAME_SUPPORTING_CIRCLE
   template < typename CK >
-  CGALi::Intersection_line_2_circle_2_map Circular_arc_2< CK >::table = 
-    CGALi::Intersection_line_2_circle_2_map();
+  internal::Intersection_line_2_circle_2_map Circular_arc_2< CK >::table = 
+    internal::Intersection_line_2_circle_2_map();
 #endif
 
 #ifdef CGAL_INTERSECTION_MAP_FOR_SUPPORTING_CIRCLES 
   template < typename CK >
-  CGALi::Intersection_line_2_circle_2_map Circular_arc_2< CK >::circle_table = 
-    CGALi::Intersection_line_2_circle_2_map();
+  internal::Intersection_line_2_circle_2_map Circular_arc_2< CK >::circle_table = 
+    internal::Intersection_line_2_circle_2_map();
 #endif
 
   template < typename CK >
@@ -719,7 +719,7 @@ public:
     }
   }     
 
-} // namespace CGALi
+} // namespace internal
 } // namespace CGAL
 
 #undef CGAL_USEFUL_MAPS_FOR_THE_CIRCULAR_KERNEL
