@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Circular_kernel_3/include/CGAL/Circular_kernel_3/Line_arc_3.h $
-// $Id: Line_arc_3.h 50731 2009-07-21 09:08:07Z sloriot $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Circular_kernel_3/include/CGAL/Circular_kernel_3/Line_arc_3.h $
+// $Id: Line_arc_3.h 51456 2009-08-24 17:10:04Z spion $
 //
 // Author(s) : Monique Teillaud, Sylvain Pion, Pedro Machado, 
 //             Sebastien Loriot, Julien Hazebrouck, Damien Leroy
@@ -28,7 +28,7 @@
 #include <boost/tuple/tuple.hpp>
 
 namespace CGAL {
-  namespace CGALi{
+  namespace internal{
     template <class SK> class Line_arc_3 {
 
       typedef typename SK::Plane_3              Plane_3;
