@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.3-branch/Surface_mesh_parameterization/include/CGAL/Convertible_circulator_project.h $
-// $Id: Convertible_circulator_project.h 31278 2006-05-24 09:29:28Z lsaboret $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Surface_mesh_parameterization/include/CGAL/Convertible_circulator_project.h $
+// $Id: Convertible_circulator_project.h 44130 2008-07-12 21:58:52Z spion $
 //
 //
 // Author(s)     : Laurent Saboret, Pierre Alliez, Bruno Levy
@@ -57,8 +57,8 @@ public:
   /// OPERATIONS Forward Category
   /// ---------------------------
 
-    bool  operator==(CGAL_NULL_TYPE ptr) const { return (const Base&)*this == ptr; }
-    bool  operator!=(CGAL_NULL_TYPE ptr) const { return ! (*this == ptr); }
+    bool  operator==(Nullptr_t ptr) const { return (const Base&)*this == ptr; }
+    bool  operator!=(Nullptr_t ptr) const { return ! (*this == ptr); }
     bool  operator==(const Self& cir)    const { return (const Base&)*this == cir; }
     bool  operator!=(const Self& cir)    const { return ! (*this == cir); }
 
