@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.4-branch/Envelope_2/include/CGAL/Envelope_2/Env_divide_and_conquer_2_impl.h $
-// $Id: Env_divide_and_conquer_2_impl.h 41109 2007-12-06 15:27:05Z efif $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Envelope_2/include/CGAL/Envelope_2/Env_divide_and_conquer_2_impl.h $
+// $Id: Env_divide_and_conquer_2_impl.h 50144 2009-06-28 13:18:53Z efif $
 //
 // Author(s)     : Ron Wein   <wein@post.tau.ac.il>
 
@@ -23,25 +23,10 @@
  * Definitions of the functions of the Envelope_divide_and_conquer_2 class.
  */
 
+#include <boost/optional.hpp>
+
 CGAL_BEGIN_NAMESPACE
 
-/*! \todo Make the handlers default constructibe
- * Some compilers complain that the handlers are not initialized. Currently,
- * there is no requirement from the concepts they model respectively to
- * have default constructors. The following is a work around.
- */
-template <typename Handle>
-class Vertex_initializer {
-public:
-  void operator()(Handle & handle) {}
-};
-
-template <typename Vertex>
-class Vertex_initializer<Vertex *> {
-public:
-  void operator()(Vertex * & handle) {handle = NULL; }
-};
-
 // ---------------------------------------------------------------------------
 // Construct the lower/upper envelope of the given list of non-vertical curves.
 //
@@ -70,16 +55,9 @@ _construct_envelope_non_vertical (Curve_pointer_iterator begin,
   else
   {
     // Divide the given range of curves into two.
+    std::size_t size = std::distance(begin, end);
     Curve_pointer_iterator  div_it = begin;
-    unsigned int            count = 0;
-    
-    for (iter = begin; iter != end; ++iter)
-    {
-      if (count % 2 == 0)
-        ++div_it;
-      
-      count++;
-    }
+    std::advance(div_it, size / 2);
     
     // Construct the diagrams (envelopes) for the two sub-ranges recursively 
     // and then merge the two diagrams to obtain the result.
@@ -241,20 +219,15 @@ _merge_envelopes (const Envelope_diagram_1& d1,
 {
   Edge_const_handle    e1 = d1.leftmost();
   bool                 is_leftmost1 = true;
-  Vertex_const_handle  v1;
+  Vertex_const_handle  v1 = Vertex_const_handle();
   Edge_const_handle    e2 = d2.leftmost();
   bool                 is_leftmost2 = true;
-  Vertex_const_handle  v2;
-  Vertex_const_handle  next_v;
+  Vertex_const_handle  v2 = Vertex_const_handle();
+  Vertex_const_handle  next_v = Vertex_const_handle();
   bool                 next_exists = true;
   Comparison_result    res_v = EQUAL;
   bool                 same_x = false;
 
-  Vertex_initializer<Vertex_const_handle> v_init;
-  v_init(v1);
-  v_init(v2);
-  v_init(next_v);
-    
   do
   {
     // Locate the vertex that has smaller x-coordinate between v1 and v2.
@@ -299,23 +272,23 @@ _merge_envelopes (const Envelope_diagram_1& d1,
       _merge_two_intervals (e1, is_leftmost1,
                             e2, is_leftmost2,
                             next_v, next_exists,
-                            (res_v == SMALLER) ? 1 : 2,
-                            out_d);
+                            res_v, out_d);
+      
     }
     else if (! e1->is_empty() && e2->is_empty())
     {
       // e1 is not empty but e2 is empty:
-      _merge_single_interval (e1,
+      _merge_single_interval (e1, e2,
                               next_v, next_exists,
-                              (res_v == SMALLER),
+                              res_v,
                               out_d);
     }
     else if (e1->is_empty() && ! e2->is_empty())
     {
       // e1 is empty and e2 is not empty:
-      _merge_single_interval (e2,
+      _merge_single_interval (e2, e1,
                               next_v, next_exists,
-                              (res_v != SMALLER),
+                              CGAL::opposite(res_v),
                               out_d);
     }
     else
@@ -324,7 +297,17 @@ _merge_envelopes (const Envelope_diagram_1& d1,
       if (next_exists)
       {
         Vertex_handle  new_v = _append_vertex (out_d, next_v->point(), e1);
-        new_v->add_curves (next_v->curves_begin(), next_v->curves_end());
+        switch(res_v)
+        {
+        case SMALLER:
+          new_v->add_curves (v1->curves_begin(), v1->curves_end()); break;
+        case LARGER:
+          new_v->add_curves (v2->curves_begin(), v2->curves_end()); break;
+        case EQUAL:
+          new_v->add_curves (v1->curves_begin(), v1->curves_end());
+          new_v->add_curves (v2->curves_begin(), v2->curves_end());
+          break;
+        }
       }
     }
     
@@ -332,6 +315,7 @@ _merge_envelopes (const Envelope_diagram_1& d1,
     if (next_exists)
     {
       // Check if we should proceed on d1 or on d2.
+      // \todo: we do not need 3 cases, only two.
       if (res_v == SMALLER)
       {
         e1 = v1->right();
@@ -394,16 +378,11 @@ _compare_vertices (Vertex_const_handle v1,
   // In case the x-coordinates of the two vertices are equal:
   res = traits->compare_xy_2_object() (v1->point(),
                                        v2->point());
-  
-  if ((env_type == LOWER && res == SMALLER) ||
-      (env_type == UPPER && res == LARGER))
-    return (SMALLER);
-  else if ((env_type == LOWER && res == LARGER) ||
-           (env_type == UPPER && res == SMALLER))
-    return (LARGER);
-  
-  // The two vertices represent equal points:
-  return (EQUAL);
+
+  // In case of upper envlope we take the opposite result
+  if (env_type == UPPER)
+    return CGAL::opposite (res);
+  return res;
 }
 
 // ---------------------------------------------------------------------------
@@ -412,9 +391,9 @@ _compare_vertices (Vertex_const_handle v1,
 //
 template <class Traits, class Diagram>
 void Envelope_divide_and_conquer_2<Traits,Diagram>::
-_merge_single_interval (Edge_const_handle e,
+_merge_single_interval (Edge_const_handle e, Edge_const_handle other_edge,
                         Vertex_const_handle v, bool v_exists,
-                        bool same_org,
+                        Comparison_result origin_of_v,
                         Envelope_diagram_1& out_d)
 {
   if (! v_exists)
@@ -427,7 +406,7 @@ _merge_single_interval (Edge_const_handle e,
   
   Vertex_handle      new_v;
   
-  if (same_org)
+  if (origin_of_v == SMALLER)
   {
     // The non-empty edge ends at v, so we simply insert it to out_d.
     new_v = _append_vertex (out_d, v->point(), e);
@@ -435,7 +414,16 @@ _merge_single_interval (Edge_const_handle e,
     
     return;
   }
-  
+
+  if (origin_of_v == EQUAL) // the edges have vertices at the same place.
+  {
+    new_v = _append_vertex (out_d, v->point(), e);
+    new_v->add_curves (e->right()->curves_begin(), e->right()->curves_end());
+    new_v->add_curves (other_edge->right()->curves_begin(), 
+                       other_edge->right()->curves_end());
+    return;
+  }
+
   // If v is not on e, we should insert it to the merged diagram only if it
   // is below (or above, in case of an upper envelope) the curves of e.
   Comparison_result  res = traits->compare_y_at_x_2_object() (v->point(),
@@ -458,64 +446,254 @@ _merge_single_interval (Edge_const_handle e,
   return;
 }
 
+//! \brief Functions that should be on Arr_traits_adaptor.
+/*@{*/
+
+//! Compare the $y$-coordinates of two curves at their endpoints
+/*! The function compares the $y$ values of two curves with a joint 
+  range of $x$ values, at the end of the joint range.
+  \param xcv1 The first curve
+  \param xcv2 The second curve
+  \param curve_end ARR_MIN_END - compare the $y$ value of the smaller 
+  endpoint, ARR_MAX_END - compare the $y$ value of the larger endpoint.
+  \pre The two $x$-monotone curves need to have a partially overlapping 
+  $x$-ranges.
+  \return 
+  \todo Move it to Arr_traits_adaptor ?
+*/
+template <class Traits, class Diagram>
+Comparison_result Envelope_divide_and_conquer_2<Traits,Diagram>::
+compare_y_at_end(const X_monotone_curve_2& xcv1,
+                                   const X_monotone_curve_2& xcv2,
+                                   Arr_curve_end curve_end) const
+{
+  CGAL_precondition (traits->is_in_x_range_2_object() (xcv1, xcv2));
+
+  typedef typename Traits::Compare_xy_2               Compare_xy_2;
+  typedef typename Traits::Compare_y_at_x_2           Compare_y_at_x_2;
+  typedef typename Traits::Construct_min_vertex_2     Construct_min_vertex_2;
+  typedef typename Traits::Construct_max_vertex_2     Construct_max_vertex_2;
+
+  Compare_y_at_x_2       compare_y_at_x = traits->compare_y_at_x_2_object();
+  Construct_min_vertex_2 min_vertex =
+    traits->construct_min_vertex_2_object();
+  Construct_max_vertex_2 max_vertex =
+    traits->construct_max_vertex_2_object();
+  
+  // First check whether any of the curves is defined at x boundary.
+  const Arr_parameter_space ps_x1 = traits->parameter_space_in_x_2_object()
+    (xcv1, curve_end);
+  const Arr_parameter_space ps_x2 = traits->parameter_space_in_x_2_object()
+    (xcv2, curve_end);
+  Comparison_result         res;
+  
+  if (ps_x1 != ARR_INTERIOR)
+  {
+    if (ps_x2 != ARR_INTERIOR)
+    {
+      // Compare the relative position of the curves at x boundary.
+      return (traits->compare_y_near_boundary_2_object()
+	      (xcv1, xcv2, curve_end));
+    }
+    
+    // Check if the left end of xcv2 lies at y boundary.
+    const Arr_parameter_space ps_y2 =  traits->parameter_space_in_y_2_object()
+      (xcv2, curve_end);
+    
+    if (ps_y2 == ARR_BOTTOM_BOUNDARY)
+      return (LARGER);          // xcv2 is obviously below xcv1.
+    else if (ps_y2 == ARR_TOP_BOUNDARY)
+      return (SMALLER);         // xcv2 is obviously above xcv1.
+          
+    // Compare the position of the left end of xcv2 (which is a normal
+    // point) to xcv1.
+    if (curve_end == ARR_MIN_END)
+      res = compare_y_at_x (min_vertex (xcv2), xcv1);
+    else
+      res = compare_y_at_x (max_vertex (xcv2), xcv1);
+
+    // Swap the result.
+    return CGAL::opposite(res);
+  }
+  else if (ps_x2 != ARR_INTERIOR)
+  {
+    // Check if the left end of xcv1 lies at y boundary.
+    const Arr_parameter_space ps_y1 =  traits->parameter_space_in_y_2_object()
+      (xcv1, curve_end);
+    
+    if (ps_y1 == ARR_BOTTOM_BOUNDARY)
+      return (SMALLER);         // xcv1 is obviously below xcv2.
+    else if (ps_y1 == ARR_TOP_BOUNDARY)
+      return (LARGER);          // xcv1 is obviously above xcv2.
+    
+    // Compare the position of the left end of xcv1 (which is a normal
+    // point) to xcv2.
+    if (curve_end == ARR_MIN_END)
+      res = compare_y_at_x (min_vertex (xcv1), xcv2);
+    else
+      res = compare_y_at_x (max_vertex (xcv1), xcv2);
+    
+    return (res);
+  }
+  
+  // Check if the left curve end lies at y = +/- oo.
+  const Arr_parameter_space ps_y1 =  traits->parameter_space_in_y_2_object()
+    (xcv1, curve_end);
+  const Arr_parameter_space ps_y2 =  traits->parameter_space_in_y_2_object()
+    (xcv2, curve_end);
+  Comparison_result         l_res;
+  
+  if (ps_y1 != ARR_INTERIOR)
+  {
+    if (ps_y2 != ARR_INTERIOR)
+    {
+      // The curve ends have boundary conditions with oposite signs in y,
+      // we readily know their relative position (recall that they do not
+      // instersect).
+      if (ps_y1 == ARR_BOTTOM_BOUNDARY && ps_y2 == ARR_TOP_BOUNDARY)
+	return (SMALLER);
+      else if (ps_y1 == ARR_TOP_BOUNDARY && ps_y2 == ARR_BOTTOM_BOUNDARY)
+	return (LARGER);
+
+      // Both curves have vertical asymptotes with the same sign in y.
+      // Check which asymptote is the rightmost. Note that in this case
+      // the vertical asymptotes cannot be equal.
+      l_res = traits->compare_x_near_boundary_2_object()
+	(xcv1, curve_end, xcv2, curve_end);
+      CGAL_assertion (l_res != EQUAL);
+      
+      if (ps_y1 == ARR_TOP_BOUNDARY)
+	return (l_res);
+      else
+	return CGAL::opposite(l_res);
+    }
+
+    // xcv1 has a vertical asymptote and xcv2 has a normal left endpoint.
+    // Compare the x-positions of this endpoint and the asymptote.
+    const Point_2&  left2 = 
+      (curve_end == ARR_MIN_END) ? min_vertex(xcv2) : max_vertex(xcv2);
+        
+    l_res = traits->compare_x_near_boundary_2_object()
+      (left2, xcv1, curve_end);
+    
+    if (l_res == LARGER)
+    {
+      // left2 lies in the x-range of xcv1, so it is safe to compare:
+      res = compare_y_at_x (left2, xcv1);
+      
+      return CGAL::opposite(res);
+    }
+    else
+    {
+      if (ps_y1 == ARR_BOTTOM_BOUNDARY)
+	return (SMALLER);          // xcv1 is obviously below xcv2.
+      else
+	return (LARGER);           // xcv2 is obviously above xcv1.
+    }
+  }
+  else if (ps_y2 != ARR_INTERIOR)
+  {
+    // xcv2 has a vertical asymptote and xcv1 has a normal left endpoint.
+    // Compare the x-positions of this endpoint and the asymptote.
+    const Point_2&  left1 = 
+      (curve_end == ARR_MIN_END) ? min_vertex(xcv1) : max_vertex(xcv1);
+        
+    l_res = traits->compare_x_near_boundary_2_object()
+      (left1, xcv2, curve_end);
+    
+    if (l_res == LARGER)
+    {
+      // left1 lies in the x-range of xcv2, so it is safe to compare:
+      return (compare_y_at_x (left1, xcv2));
+    }
+    else
+    {
+      return (ps_y2 == ARR_BOTTOM_BOUNDARY) ? LARGER : SMALLER;
+    }
+  }
+
+  // In this case we compare two normal points.
+  Compare_xy_2            compare_xy = traits->compare_xy_2_object();
+
+  // Get the left endpoints of xcv1 and xcv2.
+  const Point_2&  left1 = 
+    (curve_end == ARR_MIN_END) ? min_vertex(xcv1) : max_vertex(xcv1);
+  const Point_2&  left2 = 
+    (curve_end == ARR_MIN_END) ? min_vertex(xcv2) : max_vertex(xcv2);
+
+  // Locate the rightmost point of left1 and left2 and compare its position
+  // to the other curve.
+  l_res = compare_xy (left1, left2);
+  
+  if (l_res != SMALLER)
+  {
+    // left1 is in the x-range of xcv2:
+    return compare_y_at_x (left1, xcv2);
+  }
+  else
+  {
+    // left2 is in the x-range of xcv1:
+    return CGAL::opposite(compare_y_at_x (left2, xcv1));
+  }
+}
+/*@}*/
+
 // ---------------------------------------------------------------------------
 // Merge two non-empty intervals into the merged diagram.
 //
 template <class Traits, class Diagram>
 void Envelope_divide_and_conquer_2<Traits,Diagram>::
-_merge_two_intervals (Edge_const_handle e1, bool is_leftmost1,
+_merge_two_intervals (Edge_const_handle e1, bool is_leftmost1, 
                       Edge_const_handle e2, bool is_leftmost2,
                       Vertex_const_handle v, bool v_exists,
-                      int org_v,
+                      Comparison_result origin_of_v,
                       Envelope_diagram_1& out_d)
 {
+  typedef std::pair<Point_2, typename Traits::Multiplicity>  Intersection_point;
+
+  Comparison_result                current_res;
+  bool                             equal_at_v = false;
+ 
   // Get the relative position of two curves associated with e1 and e2
   // at the rightmost of the left endpoints of e1 and e2.
-  Comparison_result      u_res;
-  bool                   equal_at_v = false;
-  Point_2                pu;
-  bool                   pu_exists = false;
- 
-  u_res = traits->compare_y_position_2_object() (e1->curve(),
-                                                 e2->curve());
-  
+  current_res = compare_y_at_end(e1->curve(), e2->curve(), ARR_MIN_END);
   // Flip the result in case of an upper envelope.
   if (env_type == UPPER)
-    u_res = CGAL::opposite (u_res);
+    current_res = CGAL::opposite (current_res);
+
   
   // Use the current rightmost of the two left vertices as a reference point.
-  bool                 v_rm_exists = true;
-  Vertex_const_handle  v_rm;
-  Vertex_initializer<Vertex_const_handle> v_init;
-  v_init(v_rm);
+  // This is the rightmost vertex in the current minimization diagram (out_d).
+  // The intersection points/curves that interest us are the ones in
+  // [v_leftmost, v].
+  boost::optional<Vertex_const_handle>  v_leftmost;
 
-  if (is_leftmost1)
+  if (is_leftmost1 == true)
   {
-    if (is_leftmost2)
-      v_rm_exists = false;
-    else
-      v_rm = e2->left();
+    if (is_leftmost2 == false)
+      v_leftmost = e2->left();
   }
   else
   {
-    if (is_leftmost2)
-      v_rm = e1->left();
+    if (is_leftmost2 == true)
+      v_leftmost = e1->left();
     else
     {
       if ((traits->compare_xy_2_object() (e1->left()->point(),
                                           e2->left()->point()) == LARGER))
-        v_rm = e1->left();
+        v_leftmost = e1->left();
       else
-        v_rm = e2->left();
+        v_leftmost = e2->left();
     }
   }
 
   // Find the next intersection of the envelopes to the right of the current
   // rightmost point in the merged diagram.
+  // \todo Use the faster object_cast.
   std::list<CGAL::Object>           objects;
   CGAL::Object                      obj;
-  X_monotone_curve_2                icv;
-  std::pair<Point_2, unsigned int>  ipt;
+  const X_monotone_curve_2*         intersection_curve;
+  const Intersection_point*         intersection_point;
   
   traits->intersect_2_object() (e1->curve(), e2->curve(),
                                 std::back_inserter(objects));
@@ -526,233 +704,262 @@ _merge_two_intervals (Edge_const_handle e1, bool is_leftmost1,
     obj = objects.front();
     objects.pop_front();
     
-    if (CGAL::assign(ipt, obj))
+    if ((intersection_point = CGAL::object_cast<Intersection_point>(&obj)) 
+        != NULL)
     {
       // We have a simple intersection point.
-      if (v_rm_exists &&
-          traits->compare_xy_2_object() (ipt.first, 
-                                         v_rm->point()) != LARGER)
+      bool is_in_x_range = true; // true if the intersection point is to the 
+                                 // right of v_leftmost.
+      // check if we are before the leftmost point.
+      if (v_leftmost &&
+          traits->compare_xy_2_object() (intersection_point->first, 
+                                         (*v_leftmost)->point()) != LARGER)
       {
         // The point is to the left of the current rightmost vertex in out_d,
         // so we skip it and continue examining the next intersections.
         // However, we update the last intersection point observed.
-        pu = ipt.first;
-        pu_exists = true;
-        continue;
+        is_in_x_range = false;
       }
       
-      if (v_exists)
+      // check if we arrived at the rightmost point (stop if indeed we are
+      // there).
+      if (is_in_x_range && v_exists)
       {
-        Comparison_result res = traits->compare_xy_2_object() (ipt.first, 
-                                                               v->point());
+        Comparison_result res = traits->compare_xy_2_object() 
+          (intersection_point->first, v->point());
         
+        // v is an intersection points, so both curves are equal there:
         if (res == EQUAL)
-          // v is an intersection points, so both curves are equal there:
           equal_at_v = true;
         
-        if (res != SMALLER)
-        {
-          // We passed the next vertex, so we can stop here.
+        // We passed the next vertex, so we can stop here.
+        if (res == LARGER)
           break;
-        }
       }
       
       // Create a new vertex in the output diagram that corrsponds to the
       // current intersection point.
-      Vertex_handle        new_v;
-      
-      if (pu_exists)
+      if (is_in_x_range)
       {
-        // Update the relative position of the two curves, which is their
-        // order immediately to the right of their last observed intersection
-        // point pu.
-        u_res = traits->compare_y_at_x_right_2_object() (e1->curve(),
-                                                         e2->curve(),
-                                                         pu);
- 
-        if (env_type == UPPER)
-          u_res = CGAL::opposite (u_res);
-      }
-      CGAL_assertion (u_res != EQUAL);
-      
-      if (u_res == SMALLER)
-        new_v = _append_vertex (out_d, ipt.first, e1);
-      else
-        new_v = _append_vertex (out_d, ipt.first, e2);
-      
-      // Note that the new vertex is incident to all curves in e1 and in e2.
-      new_v->add_curves (e1->curves_begin(), e1->curves_end());
-      new_v->add_curves (e2->curves_begin(), e2->curves_end());
-      
-      // Update the handle to the rightmost vertex in the output diagram.
-      v_rm = new_v;
-      v_rm_exists = true;
+        Vertex_handle        new_v;
+        
+        CGAL_assertion(current_res != EQUAL);
 
+        if (current_res == SMALLER)
+          new_v = _append_vertex (out_d, intersection_point->first, e1);
+        else
+          new_v = _append_vertex (out_d, intersection_point->first, e2);
+        
+        // if we are at v, then this is a special case that is handled after
+        // the loop. We need to add the curves from the original vertices.
+        if (equal_at_v == false)
+        {
+          // Note that the new vertex is incident to all curves in e1 and in e2.
+          new_v->add_curves (e1->curves_begin(), e1->curves_end());
+          new_v->add_curves (e2->curves_begin(), e2->curves_end());
+        }
+        
+        // Update the handle to the rightmost vertex in the output diagram.
+        v_leftmost = new_v;
+      }
+
+      // Update the relative position of the two curves, which is their
+      // order immediately to the right of their last observed intersection
+      // point.
+      
       // Get the curve order immediately to the right of the intersection
       // point. Note that in case of even (non-zero) multiplicity the order
       // remains the same.
-      if (ipt.second % 2 == 1)
+      if (current_res != EQUAL && intersection_point->second % 2 == 1)
       {
         // Odd multiplicity: flip the current comparison result.
-        u_res = CGAL::opposite (u_res);
+        current_res = CGAL::opposite (current_res);
       }
-      else if (ipt.second == 0)
+      // if we are at v, then we may not be able to call compare_y_at_x_right_2.
+      else if ((intersection_point->second == 0 || current_res == EQUAL) 
+	       && equal_at_v == false)
       {
         // The multiplicity is unknown, so we have to compare the curves to
         // the right of their intersection point.
-        u_res = traits->compare_y_at_x_right_2_object() (e1->curve(),
-                                                         e2->curve(),
-                                                         ipt.first);
-        CGAL_assertion (u_res != EQUAL);
+        current_res = traits->compare_y_at_x_right_2_object() 
+          (e1->curve(),
+           e2->curve(),
+           intersection_point->first);
+        // Flip the result in case of an upper envelope.
+        if (env_type == UPPER)
+          current_res = CGAL::opposite (current_res);
       }
     }
     else
     {
       // We have an x-monotone curve representing an overlap of the two
       // curves.
-      bool     assign_success = CGAL::assign (icv, obj);
+      intersection_curve = CGAL::object_cast<X_monotone_curve_2>(&obj);
       
-      CGAL_assertion (assign_success);
-      if (! assign_success)
-        continue;
+      if (intersection_curve == NULL)
+        CGAL_error_msg ("unrecognized intersection object.");
 
       // Get the endpoints of the overlapping curves.
       const bool  has_left = 
-        (traits->parameter_space_in_x_2_object() (icv, ARR_MIN_END) == ARR_INTERIOR);
+        (traits->parameter_space_in_x_2_object() 
+         (*intersection_curve, ARR_MIN_END) == ARR_INTERIOR);
       const bool  has_right = 
-        (traits->parameter_space_in_x_2_object() (icv, ARR_MAX_END) == ARR_INTERIOR);
-      Point_2     p1, p2;
+        (traits->parameter_space_in_x_2_object() 
+         (*intersection_curve, ARR_MAX_END) == ARR_INTERIOR);
+      Point_2     p_left, p_right;
       
       if (has_left)
-        p1 = traits->construct_min_vertex_2_object() (icv);
+        p_left = traits->construct_min_vertex_2_object() (*intersection_curve);
       
       if (has_right)
-        p2 = traits->construct_max_vertex_2_object() (icv);
-      
+        p_right = traits->construct_max_vertex_2_object() (*intersection_curve);
+
+      bool is_in_x_range = true;
       // Check if the overlapping curve is not relevant to our range.
-      if (v_rm_exists && has_right &&
-          traits->compare_xy_2_object() (p2, 
-                                         v_rm->point()) != LARGER)
+      if (v_leftmost && has_right &&
+          traits->compare_xy_2_object() (p_right, 
+                                         (*v_leftmost)->point()) != LARGER)
       {
         // The right point of the overlappinf curve is to the left of the
         // current rightmost vertex in out_d, so we skip it and continue
         // examining the next intersections.
         // However, we update the last intersection point observed.
-        pu = p2;
-        pu_exists = true;
-        continue;
+        is_in_x_range = false;
       }
       
-      if (v_exists && has_right)
+      if (is_in_x_range && v_exists && has_left)
       {
-        Comparison_result res = traits->compare_xy_2_object() (p1, 
+        Comparison_result res = traits->compare_xy_2_object() (p_left, 
                                                                v->point());
         
+        // v is an intersection points, so both curves are equal there:
         if (res == EQUAL)
-          // v is an intersection points, so both curves are equal there:
-          equal_at_v = true;
-        
-        if (res != SMALLER)
         {
-          // We passed the next vertex, so we can stop here.
-          break;
+          equal_at_v = true;
         }
+        
+        // We passed the next vertex, so we can stop here.
+        if (res == LARGER)
+          break;
       }
       
-      // There is an overlap between the range [u, v] and icv.
-      if (has_left && 
-          (! v_rm_exists ||
-           traits->compare_xy_2_object() (p1, 
-                                          v_rm->point()) == LARGER))
+      // There is an overlap between the range [u, v] and intersection_curve.
+      if (is_in_x_range && has_left && 
+          (! v_leftmost ||
+           traits->compare_xy_2_object() (p_left, 
+                                          (*v_leftmost)->point()) == LARGER))
       {
         // Create an output edge that represent the portion of [u, v] to the
         // left of the overlapping curve.
         Vertex_handle        new_v;
 
-        if (pu_exists)
-        {
-          // Update the relative position of the two curves, which is their
-          // order immediately to the right of their last observed intersection
-          // point pu.
-          u_res = traits->compare_y_at_x_right_2_object() (e1->curve(),
-                                                           e2->curve(),
-                                                           pu);
- 
-          if (env_type == UPPER)
-            u_res = CGAL::opposite (u_res);
-        }        
-        CGAL_assertion (u_res != EQUAL);
+        CGAL_assertion (current_res != EQUAL);
 
-        if (u_res == SMALLER)
-          new_v = _append_vertex (out_d, ipt.first, e1);
+        if (current_res == SMALLER)
+          new_v = _append_vertex (out_d, p_left, e1);
         else
-          new_v = _append_vertex (out_d, ipt.first, e2);
+          new_v = _append_vertex (out_d, p_left, e2);
+        
+        // if we are at v, then this is a special case that is handled after
+        // the loop. We need to add the curves from the original vertices.
+        if (equal_at_v == false)
+        {
+          // Note that the new vertex is incident to all curves in e1 and
+          // in e2.
+          new_v->add_curves (e1->curves_begin(), e1->curves_end());
+          new_v->add_curves (e2->curves_begin(), e2->curves_end());
+        }
         
-        // Note that the new vertex is incident to all curves in e1 and
-        // in e2.
-        new_v->add_curves (e1->curves_begin(), e1->curves_end());
-        new_v->add_curves (e2->curves_begin(), e2->curves_end());
-
         // Update the handle to the rightmost vertex in the output diagram.
-        v_rm = new_v;
-        v_rm_exists = true;
+        v_leftmost = new_v;
       }
       
-      if (has_right &&
+      if (is_in_x_range && has_right &&
           (! v_exists ||
-           traits->compare_xy_2_object() (p2, 
+           traits->compare_xy_2_object() (p_right, 
                                           v->point()) == SMALLER))
       {
         // Create an edge that represents the overlapping curve.
         Vertex_handle        new_v;
         
-        new_v = _append_vertex (out_d, ipt.first, e1);
+        new_v = _append_vertex (out_d, p_right, e1);
         new_v->left()->add_curves (e2->curves_begin(), e2->curves_end());
         
+
+        // We are not at v becuase p_right is smaller than v.
+        // The special case that we are at v is handled in the next
+        // condition.
+        // If we were at v, then this was a special case that is handled
+        // later.
+        CGAL_assertion (equal_at_v == false);
         new_v->add_curves (e1->curves_begin(), e1->curves_end());
         new_v->add_curves (e2->curves_begin(), e2->curves_end());
         
         // Update the handle to the rightmost vertex in the output diagram.
-        v_rm = new_v;
-        v_rm_exists = true;
-
-        // Compare the curves to the right of p2.
-        u_res = traits->compare_y_at_x_right_2_object() (e1->curve(),
-                                                         e2->curve(),
-                                                         p2);
-        CGAL_assertion (u_res != EQUAL);
+        v_leftmost = new_v;
       }
-      else
+      
+      if (has_right == false || 
+          (v_exists && traits->compare_xy_2_object() (p_right, 
+                                                      v->point()) != SMALLER))
       {
         // The overlapping curves reaches v.
+        if (v_exists)
+        {
+          Vertex_handle        new_v;
+          new_v = _append_vertex (out_d, v->point(), e1);
+          new_v->left()->add_curves (e2->curves_begin(), e2->curves_end());
+        }
+        
         equal_at_v = true;
-        u_res = EQUAL;
+        current_res = EQUAL;
         break;
       }
+
+      // We arrive here only if we are not at v and the overlap has a right
+      // endpoint.
+      // Compare the curves to the right of p_right.
+      current_res = traits->compare_y_at_x_right_2_object() (e1->curve(),
+                                                             e2->curve(),
+                                                             p_right);
+      // Flip the result in case of an upper envelope.
+      if (env_type == UPPER)
+        current_res = CGAL::opposite (current_res);
       
     }
     
   } // End of the traversal over the intersection objects.
-  
+
+
   // Handle the portion after the intersection objects.
   if (equal_at_v)
   {
     CGAL_assertion (v_exists);
-    
-    // In this case the two urves intersect (or overlap) at v.
-    Vertex_handle        new_v;
-    
-    if (u_res == SMALLER)
-      new_v = _append_vertex (out_d, v->point(), e1);
+
+    // v_leftmost should be our vertex at v.
+    // In this case the two curves intersect (or overlap) at v.
+    // We need to add the correct curves to v_leftmost.
+
+    Vertex_handle v_to_be_updated = out_d.rightmost()->left();
+
+    if (origin_of_v == EQUAL)
+    {
+      // If the vertices of the edge are the same, we have to get the 
+      // curves from there:
+      v_to_be_updated->add_curves (e1->right()->curves_begin(), 
+                                   e1->right()->curves_end());
+      v_to_be_updated->add_curves (e2->right()->curves_begin(), 
+                                   e2->right()->curves_end());
+    }
     else
-      new_v = _append_vertex (out_d, v->point(), e2);
-    
-    if (u_res == EQUAL)
-      new_v->left()->add_curves (e1->curves_begin(), e1->curves_end());
-    
-    // Note that the new vertex is incident to all curves in e1 and in e2.
-    new_v->add_curves (e1->curves_begin(), e1->curves_end());
-    new_v->add_curves (e2->curves_begin(), e2->curves_end());
+    {
+      // We add the curves from the original vertex and from the edge of the
+      // other diagram.
+      Edge_const_handle e = (origin_of_v == SMALLER) ? e2 : e1;
+
+      v_to_be_updated->add_curves (v->curves_begin(), v->curves_end());
+      v_to_be_updated->add_curves (e->curves_begin(), e->curves_end());
+    }
     
     return;
   }
@@ -761,37 +968,39 @@ _merge_two_intervals (Edge_const_handle e1, bool is_leftmost1,
   {
     // Both edges are unbounded from the right, so we simply have
     // to update the rightmost edge in out_d.
-    CGAL_assertion (u_res != EQUAL);
-    
-    if (u_res == SMALLER)
+    switch (current_res)
+    {
+    case SMALLER:
       out_d.rightmost()->add_curves (e1->curves_begin(), e1->curves_end());
-    else
+      return;
+    case LARGER:
       out_d.rightmost()->add_curves (e2->curves_begin(), e2->curves_end());
-    
-    return;
+      return;
+    case EQUAL:
+      out_d.rightmost()->add_curves (e1->curves_begin(), e1->curves_end());
+      out_d.rightmost()->add_curves (e2->curves_begin(), e2->curves_end());
+      return;
+    default:
+      CGAL_error_msg("should not reach here.");
+      return;
+    }
   }
+
+  // origin_of_v could be EQUAL but the curves do not intersect.
+  // This is because of the fact that v could be the endpoint of the NEXT
+  // curve (which is lower than the currrent curve. The second diagram, however,
+  // has a curve that ends at v.
+  // For example:
+  // First diagram is the segment: [(0, -1), (1, 0)]
+  // Second diagram of the two segments: [(0, 0), (1, 1)], [(1, 0), (2, 1)]
   
   // Check if we need to insert v into the diagram.
-  if (pu_exists)
-  {
-    // Update the relative position of the two curves, which is their
-    // order immediately to the right of their last observed intersection
-    // point pu.
-    u_res = traits->compare_y_at_x_right_2_object() (e1->curve(),
-                                                     e2->curve(),
-                                                     pu);
-    
-    if (env_type == UPPER)
-      u_res = CGAL::opposite (u_res);
-  }
-  CGAL_assertion (u_res != EQUAL);
-
-  if (u_res == SMALLER)
+  if (current_res == SMALLER)
   {    
     // The final part of the interval is taken from e1.
     Vertex_handle        new_v;
 
-    if (org_v == 1)
+    if (origin_of_v == SMALLER)
     {
       // In case v is also from e1, append it to the merged diagram.
       new_v = _append_vertex (out_d, v->point(), e1);
@@ -799,21 +1008,36 @@ _merge_two_intervals (Edge_const_handle e1, bool is_leftmost1,
     }
     else
     {
-      // If v is from e2, check if it below (or above, in case of an upper
-      // envelope) cv1 to insert it.
-      const Comparison_result  res = 
-        traits->compare_y_at_x_2_object() (v->point(),
-                                           e1->curve());
-      
-      if (res == EQUAL ||
-          (env_type == LOWER && res == SMALLER) ||
-          (env_type == UPPER && res == LARGER))
+      // if origin_of_v is EQUAL then the two diagram have a vertex at
+      // exact same place.
+      if (origin_of_v == EQUAL)
       {
         new_v = _append_vertex (out_d, v->point(), e1);
         new_v->add_curves (v->curves_begin(), v->curves_end());
         
-        if (res == EQUAL)
-          new_v->add_curves (e1->curves_begin(), e1->curves_end());
+        // adding the curves of the vertex of the first diagram (vertices are
+        // equal...)
+        new_v->add_curves (e1->right()->curves_begin(), 
+                           e1->right()->curves_end());
+      }
+      else
+      {
+        // If v is from e2, check if it below (or above, in case of an upper
+        // envelope) cv1 to insert it.
+        const Comparison_result  res = 
+          traits->compare_y_at_x_2_object() (v->point(),
+                                             e1->curve());
+        
+        if (res == EQUAL ||
+            (env_type == LOWER && res == SMALLER) ||
+            (env_type == UPPER && res == LARGER))
+          {
+            new_v = _append_vertex (out_d, v->point(), e1);
+            new_v->add_curves (v->curves_begin(), v->curves_end());
+            
+            if (res == EQUAL)
+              new_v->add_curves (e1->curves_begin(), e1->curves_end());
+          }
       }
     }
   }
@@ -822,11 +1046,21 @@ _merge_two_intervals (Edge_const_handle e1, bool is_leftmost1,
     // The final part of the interval is taken from e2.
     Vertex_handle        new_v;
 
-    if (org_v == 2)
+    if (origin_of_v != SMALLER)
     {
       // In case v is also from e2, append it to the merged diagram.
       new_v = _append_vertex (out_d, v->point(), e2);
       new_v->add_curves (v->curves_begin(), v->curves_end());
+      
+      // if origin_of_v is EQUAL then the two diagram have a vertex at
+      // exact same place.
+      if (origin_of_v == EQUAL)
+      {
+        // adding the curves of the vertex of the first diagram (vertices are
+        // equal...)
+        new_v->add_curves (e1->right()->curves_begin(), 
+                           e1->right()->curves_end());
+      }
     }
     else
     {
@@ -920,7 +1154,7 @@ _merge_vertical_segments (Curve_pointer_vector& vert_vec,
                                       traits->construct_max_vertex_2_object();
 
   Edge_handle             e = out_d.leftmost();
-  Vertex_handle           v;
+  Vertex_handle           v = Vertex_handle();
   Curve_pointer_iterator  iter = vert_vec.begin();
   Curve_pointer_iterator  next;
   Comparison_result       res;
@@ -928,9 +1162,6 @@ _merge_vertical_segments (Curve_pointer_vector& vert_vec,
   bool                    on_v;
   Point_2                 p;
 
-  Vertex_initializer<Vertex_handle> v_init;
-  v_init(v);
-  
   while (iter != vert_vec.end())
   {
     // Check if the current vertical segment is on the x-range of the current
