@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.3-branch/Envelope_3/include/CGAL/Envelope_3/Envelope_divide_and_conquer_3.h $
-// $Id: Envelope_divide_and_conquer_3.h 37935 2007-04-04 17:12:45Z efif $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Envelope_3/include/CGAL/Envelope_3/Envelope_divide_and_conquer_3.h $
+// $Id: Envelope_divide_and_conquer_3.h 50517 2009-07-09 20:54:58Z efif $
 //
 // Author(s)     : Michal Meyerovitch     <gorgymic@post.tau.ac.il>
 //                 Baruch Zukerman        <baruchzu@post.tau.ac.il>
@@ -25,7 +25,6 @@
 #define CGAL_ENVELOPE_USE_BFS_FACE_ORDER
 
 #include <iostream>
-#include <cassert>
 #include <list>
 #include <set>
 #include <vector>
@@ -36,13 +35,14 @@
 #include <CGAL/enum.h>
 #include <CGAL/Arr_observer.h>
 #include <CGAL/Envelope_3/Envelope_base.h>
-#include <CGAL/Envelope_3/Env_overlay_2.h>
+#include <CGAL/Envelope_3/Envelope_overlay_2.h>
 #include <CGAL/Envelope_3/Envelope_element_visitor_3.h>
 #include <CGAL/Envelope_3/set_dividors.h>
 
 #ifdef CGAL_ENVELOPE_USE_BFS_FACE_ORDER
 #include <CGAL/Arr_face_map.h>
 #include <CGAL/graph_traits_Dual_Arrangement_2.h>
+#include <climits> // Needed because BGL forgot it.
 #include <boost/graph/dijkstra_shortest_paths.hpp>
 #endif
 
@@ -130,8 +130,8 @@ protected:
     Vertex_handle;
   typedef typename Minimization_diagram_2::Vertex_iterator
     Vertex_iterator;
-  typedef typename Minimization_diagram_2::Hole_iterator
-    Hole_iterator;
+  typedef typename Minimization_diagram_2::Inner_ccb_iterator
+    Inner_ccb_iterator;
   typedef typename Minimization_diagram_2::Ccb_halfedge_circulator
     Ccb_halfedge_circulator;
   typedef typename Minimization_diagram_2::Halfedge_around_vertex_circulator
@@ -149,37 +149,37 @@ protected:
 
 public:
   // c'tor
-  Envelope_divide_and_conquer_3(Envelope_type type = LOWER)
+  Envelope_divide_and_conquer_3(Envelope_type type = ENVELOPE_LOWER)
   {    
     // Allocate the traits.
-    traits = new Traits;                                                     
-
-    own_traits = true;
+    m_geom_traits = new Traits;
+    m_own_traits = true;
 
     // Allocate the Envelope resolver with our traits
-    resolver = new Envelope_resolver(traits, type);
+    resolver = new Envelope_resolver(m_geom_traits, type);
 
-    m_is_lower = ((type == LOWER) ? true : false);
+    m_is_lower = ((type == ENVELOPE_LOWER) ? true : false);
   }
 
-  Envelope_divide_and_conquer_3(Traits* tr, Envelope_type type = LOWER)
+  Envelope_divide_and_conquer_3(const Traits * geom_traits,
+                                Envelope_type type = ENVELOPE_LOWER)
   {
     // Set the traits.
-    traits = tr;
-    own_traits = false;
+    m_geom_traits = geom_traits;
+    m_own_traits = false;
 
     // Allocate the Envelope resolver with our traits
-    resolver = new Envelope_resolver(traits, type);
+    resolver = new Envelope_resolver(m_geom_traits, type);
 
-    m_is_lower = ((type == LOWER) ? true : false);
+    m_is_lower = ((type == ENVELOPE_LOWER) ? true : false);
   }
   
   // virtual destructor.
   virtual ~Envelope_divide_and_conquer_3()
   {
     // Free the traits object, if necessary.
-    if (own_traits)
-      delete traits;
+    if (m_own_traits)
+      delete m_geom_traits;
 
     // Free the resolver
     delete resolver;
@@ -191,7 +191,7 @@ public:
   void construct_lu_envelope(SurfaceIterator begin, SurfaceIterator end,
                              Minimization_diagram_2 &result)
   {
-    Arbitrary_dividor dividor;
+    Envelope_3::Arbitrary_dividor dividor;
     construct_lu_envelope(begin, end, result, dividor);
   }
     
@@ -210,8 +210,9 @@ public:
     // make the general surfaces xy-monotone
     std::list<Xy_monotone_surface_3> xy_monotones;
     for (; begin != end; ++begin)
-      traits->make_xy_monotone_3_object()(*begin, m_is_lower,
-                                          std::back_inserter(xy_monotones));
+      m_geom_traits->
+        make_xy_monotone_3_object()(*begin, m_is_lower,
+                                    std::back_inserter(xy_monotones));
 
     // recursively construct the envelope of the xy-monotone parts
     construct_lu_envelope_xy_monotones(xy_monotones.begin(), 
@@ -227,7 +228,7 @@ public:
                                       SurfaceIterator end,
                                       Minimization_diagram_2 &result)
   {
-    Arbitrary_dividor dividor;
+    Envelope_3::Arbitrary_dividor dividor;
     construct_envelope_xy_monotone(begin, end, result, dividor);
   }
 
@@ -247,16 +248,10 @@ public:
     CGAL_assertion(is_envelope_valid(result));
   }
 
-  /*! Access the traits object (const version). */
-  const Traits* get_traits() const
+  /*! Access the traits object. */
+  const Traits * get_traits() const
   {
-    return traits;
-  }
-
-  /*! Access the traits object (non-const version). */
-  Traits* get_traits() 
-  {
-    return traits;
+    return m_geom_traits;
   }
 
   void reset()
@@ -291,12 +286,13 @@ protected:
    
     // divide the surfaces into 2 groups (insert surface to each group
     // alternately)
+    // Efi: this copy is redundant. It is sufficient to determine the range
     std::list<Xy_monotone_surface_3> group1, group2;
     dividor(first, end,
             std::back_inserter(group1), std::back_inserter(group2));
     
     // recursively calculate the LU_envelope of the 2 groups
-    Minimization_diagram_2 result1(traits), result2(traits);
+    Minimization_diagram_2 result1(m_geom_traits), result2(m_geom_traits);
     construct_lu_envelope_xy_monotones(group1.begin(), group1.end(),
                                        result1, dividor);
     construct_lu_envelope_xy_monotones(group2.begin(), group2.end(),
@@ -307,8 +303,8 @@ protected:
 
     result1.clear();
     result2.clear();
-    
-    CGAL_assertion(is_envelope_valid(result));   
+
+    CGAL_assertion(is_envelope_valid(result));
   }
 
   void deal_with_one_surface(Xy_monotone_surface_3& surf,
@@ -319,30 +315,32 @@ protected:
     typedef Boundary_list::iterator                      Boundary_iterator;
 
     Boundary_list     boundary;
-    traits->
+    m_geom_traits->
       construct_projected_boundary_2_object()(surf,
                                               std::back_inserter(boundary));
     
-    if(boundary.empty())
+    if (boundary.empty())
     {
       //one infinite surface
-      result.unbounded_face()->set_data(surf);
+      CGAL_assertion_msg (result.number_of_faces() == 1,
+                          "In the beginning there should be only one face");
+      result.faces_begin()->set_data(surf);
       return;
     }
 
     for (Boundary_iterator boundary_it = boundary.begin();
-        boundary_it != boundary.end();
-        ++boundary_it)
+         boundary_it != boundary.end();
+         ++boundary_it)
     {
       const Object& obj = *boundary_it;
       Boundary_xcurve boundary_cv;
-      if(assign(boundary_cv, obj))
+      if (assign(boundary_cv, obj))
       {
         Oriented_side side = boundary_cv.second;
         Halfedge_handle he =
           insert_non_intersecting_curve(result, boundary_cv.first);
         
-        if(side == ON_ORIENTED_BOUNDARY)
+        if (side == ON_ORIENTED_BOUNDARY)
         {
           // vertical xy-surface
           he->face()->set_no_data();
@@ -351,13 +349,13 @@ protected:
           continue;
         }
 
-        if(he->face() != he->twin()->face())
+        if (he->face() != he->twin()->face())
         {
           // new face created.
           // 'he' is directed from left to right, so the face to the left
           // of 'he'  is above 'cv.
           Face_handle f;
-          if(side == ON_NEGATIVE_SIDE) // the surface is below cv.
+          if (side == ON_NEGATIVE_SIDE) // the surface is below cv.
           {
             f = he->twin()->face();
             f->set_data(surf);
@@ -427,7 +425,6 @@ protected:
   
 
 public:
-  
   void merge_envelopes(Minimization_diagram_2& result1,
                        Minimization_diagram_2& result2,
                        Minimization_diagram_2& result)
@@ -467,19 +464,19 @@ public:
       CGAL_assertion(!aux_has_no_data(hh, 1) || !aux_has_no_data(hh, 0));
       if (aux_has_no_data(hh, 0) && !aux_has_no_data(hh, 1))
       {
-        hh->set_decision(SECOND);
-        hh->twin()->set_decision(SECOND);
+        hh->set_decision(DAC_DECISION_SECOND);
+        hh->twin()->set_decision(DAC_DECISION_SECOND);
         continue;
       }
       else if (!aux_has_no_data(hh, 0) && aux_has_no_data(hh, 1))
       {
-        hh->set_decision(FIRST);
-        hh->twin()->set_decision(FIRST);
+        hh->set_decision(DAC_DECISION_FIRST);
+        hh->twin()->set_decision(DAC_DECISION_FIRST);
         continue;
       }
 
       bool should_resolve = true;
-      #ifdef CGAL_ENVELOPE_SAVE_COMPARISONS
+#ifdef CGAL_ENVELOPE_SAVE_COMPARISONS
         if (hh->get_has_equal_aux_data_in_face(0) &&
             hh->get_has_equal_aux_data_in_face(1))
           should_resolve = false;
@@ -487,7 +484,7 @@ public:
         if (hh->twin()->get_has_equal_aux_data_in_face(0) &&
             hh->twin()->get_has_equal_aux_data_in_face(1))
           should_resolve = false;
-      #endif
+#endif
 
       // we collect the edges in a list to deal afterwards, because the resolve
       // can split edges, and destroy the iterator
@@ -513,7 +510,7 @@ public:
 
     std::list<Face_handle> faces_to_split;
 
-    #ifdef CGAL_ENVELOPE_USE_BFS_FACE_ORDER
+#ifdef CGAL_ENVELOPE_USE_BFS_FACE_ORDER
     // we traverse the faces of result in BFS order to maximize the
     // efficiency gain by the conclusion mechanism of
     // compare_distance_to_envelope results
@@ -543,7 +540,7 @@ public:
         // if a surface of one map doesn't exist, then we set the second surface
         if (aux_has_no_data(fh, 0) && !aux_has_no_data(fh, 1))
         {
-          fh->set_decision(SECOND);
+          fh->set_decision(DAC_DECISION_SECOND);
           continue;
         }
         else if (aux_has_no_data(fh, 0) && aux_has_no_data(fh, 1))
@@ -555,7 +552,7 @@ public:
         }
         else if (!aux_has_no_data(fh, 0) && aux_has_no_data(fh, 1))
         {
-          fh->set_decision(FIRST);
+          fh->set_decision(DAC_DECISION_FIRST);
           continue;
         }
 
@@ -564,8 +561,8 @@ public:
         // face can change and destroy the iterator
         faces_to_split.push_back(fh);
       }
-    #endif
-        
+#endif
+
     deal_with_faces_to_split(faces_to_split, result);
 
 //    #ifndef CGAL_ENVELOPE_SAVE_COMPARISONS
@@ -594,12 +591,12 @@ public:
       CGAL_assertion(!aux_has_no_data(vh, 1) || !aux_has_no_data(vh, 0));
       if (aux_has_no_data(vh, 0) && !aux_has_no_data(vh, 1))
       {
-        vh->set_decision(SECOND);
+        vh->set_decision(DAC_DECISION_SECOND);
         continue;
       }
       else if (!aux_has_no_data(vh, 0) && aux_has_no_data(vh, 1))
       {
-        vh->set_decision(FIRST);
+        vh->set_decision(DAC_DECISION_FIRST);
         continue;
       }
       resolver->resolve(vh);
@@ -733,8 +730,8 @@ protected:
       Halfedge_handle h = *ci;
       Vertex_handle src = h->source(), trg = h->target();
       Face_handle h_face = h->face();
-      bool remove_src = can_remove_edge_target(h->twin()),
-           remove_trg = can_remove_edge_target(h);
+      bool remove_src = can_remove_edge_target(h->twin());
+      bool remove_trg = can_remove_edge_target(h);
       bool src_is_equal_0 = (h->twin()->get_is_equal_aux_data_in_face(0) &&
                              h->twin()->get_is_equal_aux_data_in_target(0));
       bool src_is_equal_1 = (h->twin()->get_is_equal_aux_data_in_face(1) &&
@@ -750,12 +747,17 @@ protected:
       bool trg_has_equal_0 = h->get_has_equal_aux_data_in_target_and_face(0);
       bool trg_has_equal_1 = h->get_has_equal_aux_data_in_target_and_face(1);
 
+      /* A vertex at an open boundary is removed once it becomes redundant
+       * regardless of the boolean values passed as the 2nd and 3rd argument
+       * to the remove_edge() member function.
+       */
+      if (src->is_at_open_boundary()) remove_src = true;
+      if (trg->is_at_open_boundary()) remove_trg = true;
       result.remove_edge(*ci, remove_src, remove_trg);
       // otherwise, we should make sure, they will not be removed
       // the first check is needed since if the vertex was removed, then the
       // handle is invalid
-      if (!remove_src && src->is_isolated())
-      {
+      if (!remove_src && src->is_isolated()) {
         // to be precise we copy from the halfedge-face and halfedge-target
         // relations
         src->set_is_equal_aux_data_in_face(0, src_is_equal_0);
@@ -850,10 +852,10 @@ protected:
     bool equal_second = (hh->get_is_equal_aux_data_in_face(1) &&
                          hh->twin()->get_is_equal_aux_data_in_face(1));
 
-    if (decision == FIRST)
+    if (decision == DAC_DECISION_FIRST)
       return equal_first;
    
-    if (decision == SECOND)
+    if (decision == DAC_DECISION_SECOND)
       return equal_second;
     
     return (equal_first && equal_second);
@@ -864,10 +866,25 @@ protected:
   // this means that the target has the same envelope information as the edge
   bool can_remove_edge_target(Halfedge_handle h)
   {
-    if(h->target()->is_at_infinity())
+    // \todo Use new design
+    /* The code below uses the is_at_open_boundary.
+       The comment from the calling function says:
+       "if the endpoints become isolated after the removal we need to remove
+        them if they have the same data as the edge."
+
+       When I tried to use the following code I got a Segmentation Fault when
+       trying to compute power diagram:
+       
+       if ((v->parameter_space_in_x() != ARR_INTERIOR) ||
+          (v->parameter_space_in_y() != ARR_INTERIOR))
+          return false;
+
+     */
+    Vertex_handle v = h->target();
+    if (v->is_at_open_boundary())
       return false;
 
-    Vertex_handle v = h->target();
+
     /*if (v->get_is_fake() && !v->is_decision_set())
       return true;
    
@@ -891,10 +908,10 @@ protected:
     bool equal_first = (h->get_is_equal_aux_data_in_target(0));
     bool equal_second = (h->get_is_equal_aux_data_in_target(1));
 
-    if (decision == FIRST)
+    if (decision == DAC_DECISION_FIRST)
       return equal_first;
    
-    if (decision == SECOND)
+    if (decision == DAC_DECISION_SECOND)
       return equal_second;
     
     return (equal_first && equal_second);
@@ -918,10 +935,10 @@ protected:
     bool equal_first = (vh->get_is_equal_aux_data_in_face(0));
     bool equal_second = (vh->get_is_equal_aux_data_in_face(1));
 
-    if (decision == FIRST)
+    if (decision == DAC_DECISION_FIRST)
       return equal_first;
     
-    if (decision == SECOND)
+    if (decision == DAC_DECISION_SECOND)
       return equal_second;
     
     return (equal_first && equal_second);
@@ -961,10 +978,10 @@ protected:
     bool equal_second = (he1->get_is_equal_aux_data_in_target(1) &&
                          he2->get_is_equal_aux_data_in_target(1));
 
-    if (decision == FIRST)
+    if (decision == DAC_DECISION_FIRST)
       return equal_first;
     
-    if (decision == SECOND)
+    if (decision == DAC_DECISION_SECOND)
       return equal_second;
 
     return (equal_first && equal_second);
@@ -1002,9 +1019,9 @@ protected:
         isolated_to_remove.push_back(vh);
     }
 
-    typename Traits::Merge_2 curves_merge = traits->merge_2_object();
+    typename Traits::Merge_2 curves_merge = m_geom_traits->merge_2_object();
     typename Traits::Are_mergeable_2 curves_can_merge = 
-                                              traits->are_mergeable_2_object();
+      m_geom_traits->are_mergeable_2_object();
 
     // check the candidates and remove if necessary
     typename std::list<Vertex_handle>::iterator ci;
@@ -1044,19 +1061,27 @@ protected:
       // x----------->x<------------x
       //  <----------- ------------>
       //   he1->twin()   he2->twin()
-      he1->set_is_equal_aux_data_in_target(0, he2->twin()->get_is_equal_aux_data_in_target(0));
-      he1->set_is_equal_aux_data_in_target(1, he2->twin()->get_is_equal_aux_data_in_target(1));
-      he1->set_has_equal_aux_data_in_target(0, he2->twin()->get_has_equal_aux_data_in_target(0));
-      he1->set_has_equal_aux_data_in_target(1, he2->twin()->get_has_equal_aux_data_in_target(1));
+      he1->set_is_equal_aux_data_in_target
+        (0, he2->twin()->get_is_equal_aux_data_in_target(0));
+      he1->set_is_equal_aux_data_in_target
+        (1, he2->twin()->get_is_equal_aux_data_in_target(1));
+      he1->set_has_equal_aux_data_in_target
+        (0, he2->twin()->get_has_equal_aux_data_in_target(0));
+      he1->set_has_equal_aux_data_in_target
+        (1, he2->twin()->get_has_equal_aux_data_in_target(1));
       he1->set_has_equal_aux_data_in_target_and_face
         (0, he2->twin()->get_has_equal_aux_data_in_target_and_face(0));
       he1->set_has_equal_aux_data_in_target_and_face
         (1, he2->twin()->get_has_equal_aux_data_in_target_and_face(1));
 
-      he2->set_is_equal_aux_data_in_target(0, he1->twin()->get_is_equal_aux_data_in_target(0));
-      he2->set_is_equal_aux_data_in_target(1, he1->twin()->get_is_equal_aux_data_in_target(1));
-      he2->set_has_equal_aux_data_in_target(0, he1->twin()->get_has_equal_aux_data_in_target(0));
-      he2->set_has_equal_aux_data_in_target(1, he1->twin()->get_has_equal_aux_data_in_target(1));
+      he2->set_is_equal_aux_data_in_target
+        (0, he1->twin()->get_is_equal_aux_data_in_target(0));
+      he2->set_is_equal_aux_data_in_target
+        (1, he1->twin()->get_is_equal_aux_data_in_target(1));
+      he2->set_has_equal_aux_data_in_target
+        (0, he1->twin()->get_has_equal_aux_data_in_target(0));
+      he2->set_has_equal_aux_data_in_target
+        (1, he1->twin()->get_has_equal_aux_data_in_target(1));
       he2->set_has_equal_aux_data_in_target_and_face
         (0, he1->twin()->get_has_equal_aux_data_in_target_and_face(0));
       he2->set_has_equal_aux_data_in_target_and_face
@@ -1093,19 +1118,19 @@ protected:
     Vertex_handle v;
     Face_handle f;
 
-    if (decision == FIRST || decision == BOTH)
+    if (decision == DAC_DECISION_FIRST || decision == DAC_DECISION_BOTH)
     {
       Envelope_data_iterator begin, end;
       get_aux_data_iterators(0, fh, begin, end);
       fh->set_data(begin, end);
     }
-    if (decision == SECOND || decision == BOTH)
+    if (decision == DAC_DECISION_SECOND || decision == DAC_DECISION_BOTH)
     {
       // copy data from second envelope
       Envelope_data_iterator begin, end;
       get_aux_data_iterators(1, fh, begin, end);
 
-      if (decision == SECOND)
+      if (decision == DAC_DECISION_SECOND)
         fh->set_data(begin, end);
       else
         fh->add_data(begin, end);
@@ -1142,23 +1167,23 @@ protected:
     bool is_equal, has_equal;
     is_equal = (h->get_decision() == h->face()->get_decision());
     // has equal can be true even if the decision is not the same,
-    // but has same surfaces, i.e. one of the features got BOTH
+    // but has same surfaces, i.e. one of the features got DAC_DECISION_BOTH
     // decision, and the other didn't
     has_equal = (h->get_decision() == h->face()->get_decision() ||
-                 h->get_decision() == BOTH ||
-                 h->face()->get_decision() == BOTH);
+                 h->get_decision() == DAC_DECISION_BOTH ||
+                 h->face()->get_decision() == DAC_DECISION_BOTH);
 
     CGAL::Dac_decision decision = h->face()->get_decision();
     bool is_equal_first = (h->get_is_equal_aux_data_in_face(0));
     bool has_equal_first = (h->get_has_equal_aux_data_in_face(0));
     bool is_equal_second = (h->get_is_equal_aux_data_in_face(1));
     bool has_equal_second = (h->get_has_equal_aux_data_in_face(1));
-    if (decision == FIRST)
+    if (decision == DAC_DECISION_FIRST)
     {
       is_equal &= is_equal_first;
       has_equal &= has_equal_first;
     }
-    else if (decision == SECOND)
+    else if (decision == DAC_DECISION_SECOND)
     {
       is_equal &= is_equal_second;
       has_equal &= has_equal_second;
@@ -1170,9 +1195,9 @@ protected:
 
       // we update the flag according to the halfedge decision
       decision = h->get_decision();
-      if (decision == FIRST)
+      if (decision == DAC_DECISION_FIRST)
       has_equal &= has_equal_first;
-      else if (decision == SECOND)
+      else if (decision == DAC_DECISION_SECOND)
       has_equal &= has_equal_second;
       else      
       has_equal &= (has_equal_first & has_equal_second);
@@ -1187,24 +1212,24 @@ protected:
 
     is_equal = (h->get_decision() == h->target()->get_decision());
     // has equal can be true even if the decision is not the same,
-    // but has same surfaces, i.e. one of the features got BOTH
+    // but has same surfaces, i.e. one of the features got DAC_DECISION_BOTH
     // decision, and the other didn't
     has_equal = (h->get_decision() == h->target()->get_decision() ||
-                 h->get_decision() == BOTH ||
-                 h->target()->get_decision() == BOTH);
+                 h->get_decision() == DAC_DECISION_BOTH ||
+                 h->target()->get_decision() == DAC_DECISION_BOTH);
 
     CGAL::Dac_decision decision = h->get_decision();
     bool is_equal_first = (h->get_is_equal_aux_data_in_target(0));
     bool has_equal_first = (h->get_has_equal_aux_data_in_target(0));
     bool is_equal_second = (h->get_is_equal_aux_data_in_target(1));
     bool has_equal_second = (h->get_has_equal_aux_data_in_target(1));
-    if (decision == FIRST)
+    if (decision == DAC_DECISION_FIRST)
     {
       is_equal &= is_equal_first;
       has_equal &= has_equal_first;
     }
 
-    else if (decision == SECOND)
+    else if (decision == DAC_DECISION_SECOND)
     {
       is_equal &= is_equal_second;
       has_equal &= has_equal_second;
@@ -1215,9 +1240,9 @@ protected:
       // we check if the vertex has a different decision, and if so,
       // we update the flag according to the vertex decision
       decision = h->target()->get_decision();
-      if (decision == FIRST)
+      if (decision == DAC_DECISION_FIRST)
       has_equal &= has_equal_first;
-      else if (decision == SECOND)
+      else if (decision == DAC_DECISION_SECOND)
       has_equal &= has_equal_second;
 
       else      
@@ -1230,27 +1255,27 @@ protected:
   {
     bool has_equal;
     // has equal can be true even if the decision is not the same,
-    // but has same surfaces, i.e. one of the features got BOTH
+    // but has same surfaces, i.e. one of the features got DAC_DECISION_BOTH
     // decision, and the other didn't
     has_equal = (h->face()->get_decision() == h->target()->get_decision() ||
-                 h->face()->get_decision() == BOTH ||
-                 h->target()->get_decision() == BOTH);
+                 h->face()->get_decision() == DAC_DECISION_BOTH ||
+                 h->target()->get_decision() == DAC_DECISION_BOTH);
 
     CGAL::Dac_decision decision = h->face()->get_decision();
     bool has_equal_first = (h->get_has_equal_aux_data_in_target_and_face(0));
     bool has_equal_second = (h->get_has_equal_aux_data_in_target_and_face(1));
-    if (decision == FIRST)
+    if (decision == DAC_DECISION_FIRST)
       has_equal &= has_equal_first;
-    else if (decision == SECOND)
+    else if (decision == DAC_DECISION_SECOND)
       has_equal &= has_equal_second;
     else
     {
       // we check if the vertex has a different decision, and if so,
       // we update the flag according to the vertex decision
       decision = h->target()->get_decision();
-      if (decision == FIRST)
+      if (decision == DAC_DECISION_FIRST)
         has_equal &= has_equal_first;
-      else if (decision == SECOND)
+      else if (decision == DAC_DECISION_SECOND)
         has_equal &= has_equal_second;
 
       else      
@@ -1264,24 +1289,24 @@ protected:
     bool is_equal, has_equal;
     is_equal = (v->get_decision() == f->get_decision());
     // has equal can be true even if the decision is not the same,
-    // but has same surfaces, i.e. one of the features got BOTH
+    // but has same surfaces, i.e. one of the features got DAC_DECISION_BOTH
     // decision, and the other didn't
 
     has_equal = (v->get_decision() == f->get_decision() ||
-                 v->get_decision() == BOTH ||
-                 f->get_decision() == BOTH);
+                 v->get_decision() == DAC_DECISION_BOTH ||
+                 f->get_decision() == DAC_DECISION_BOTH);
 
     CGAL::Dac_decision decision = v->get_decision();
     bool is_equal_first = (v->get_is_equal_aux_data_in_face(0));
     bool has_equal_first = (v->get_has_equal_aux_data_in_face(0));
     bool is_equal_second = (v->get_is_equal_aux_data_in_face(1));
     bool has_equal_second = (v->get_has_equal_aux_data_in_face(1));
-    if (decision == FIRST)
+    if (decision == DAC_DECISION_FIRST)
     {
       is_equal &= is_equal_first;
       has_equal &= has_equal_first;
     }
-    else if (decision == SECOND)
+    else if (decision == DAC_DECISION_SECOND)
     {
       is_equal &= is_equal_second;
       has_equal &= has_equal_second;
@@ -1292,9 +1317,9 @@ protected:
       // we check if the face has a different decision, and if so,
       // we update the flag according to the face decision
       decision = f->get_decision();
-      if (decision == FIRST)
+      if (decision == DAC_DECISION_FIRST)
       has_equal &= has_equal_first;
-      else if (decision == SECOND)
+      else if (decision == DAC_DECISION_SECOND)
         has_equal &= has_equal_second;
       else      
       has_equal &= (has_equal_first & has_equal_second);
@@ -1442,7 +1467,7 @@ protected:
         ++face_hec;
       } while(face_hec != face_hec_begin);
 
-      Hole_iterator inner_iter = fh->holes_begin();
+      Inner_ccb_iterator inner_iter = fh->holes_begin();
       for (; inner_iter != fh->holes_end(); ++inner_iter)
 
       {
@@ -1531,12 +1556,11 @@ protected:
       
       all_ok &= (hh->get_is_set());
       if (!all_ok)
-        std::cout << "edge: " << hh->curve() << std::endl;
+        std::cerr << "edge: " << hh->curve() << std::endl;
       CGAL_assertion_msg(all_ok, "data not set over edge");
       all_ok &= (!hh->has_no_data());
       if (!all_ok)
-
-        std::cout << "edge: " << hh->curve() << std::endl;
+        std::cerr << "edge: " << hh->curve() << std::endl;
       CGAL_assertion_msg(all_ok, "data empty over edge");
 
       /*all_ok &= (!hh->get_is_fake());*/
@@ -1576,7 +1600,6 @@ protected:
         new_f->set_decision(org_f->get_decision());
     }
   };
-
   
 
   // observer for the minimization diagram
@@ -1594,10 +1617,10 @@ protected:
                                                    EnvelopeResolver_3, 
                                                    Overlay_2>::Self Self;
     Keep_edge_data_observer(Minimization_diagram_2& arr,
-                            Self* b = NULL) :
+                            Self* b) :
       Md_observer(arr), base(b)
     {
-      CGAL_assertion(base);
+      CGAL_assertion(base != NULL);
     }
 
     /*virtual void before_split_edge (Halfedge_handle e,
@@ -1652,26 +1675,40 @@ protected:
       /*new_vertex->set_is_fake(org_he->get_is_fake());*/
 
       // update all new bools
-      new_he->
-        set_is_equal_aux_data_in_face(0, org_he->get_is_equal_aux_data_in_face(0));
-      new_he->twin()->set_is_equal_aux_data_in_face(0, org_he->twin()->get_is_equal_aux_data_in_face(0));
-      new_he->set_is_equal_aux_data_in_face(1, org_he->get_is_equal_aux_data_in_face(1));
-      new_he->twin()->set_is_equal_aux_data_in_face(1, org_he->twin()->get_is_equal_aux_data_in_face(1));
+      new_he->set_is_equal_aux_data_in_face
+        (0, org_he->get_is_equal_aux_data_in_face(0));
+      new_he->twin()->set_is_equal_aux_data_in_face
+        (0, org_he->twin()->get_is_equal_aux_data_in_face(0));
+      new_he->set_is_equal_aux_data_in_face
+        (1, org_he->get_is_equal_aux_data_in_face(1));
+      new_he->twin()->set_is_equal_aux_data_in_face
+        (1, org_he->twin()->get_is_equal_aux_data_in_face(1));
 
-      new_he->set_has_equal_aux_data_in_face(0, org_he->get_has_equal_aux_data_in_face(0));
-      new_he->twin()->set_has_equal_aux_data_in_face(0, org_he->twin()->get_has_equal_aux_data_in_face(0));
-      new_he->set_has_equal_aux_data_in_face(1, org_he->get_has_equal_aux_data_in_face(1));
-      new_he->twin()->set_has_equal_aux_data_in_face(1, org_he->twin()->get_has_equal_aux_data_in_face(1));
+      new_he->set_has_equal_aux_data_in_face
+        (0, org_he->get_has_equal_aux_data_in_face(0));
+      new_he->twin()->set_has_equal_aux_data_in_face
+        (0, org_he->twin()->get_has_equal_aux_data_in_face(0));
+      new_he->set_has_equal_aux_data_in_face
+        (1, org_he->get_has_equal_aux_data_in_face(1));
+      new_he->twin()->set_has_equal_aux_data_in_face
+        (1, org_he->twin()->get_has_equal_aux_data_in_face(1));
 
-      // new_he->target is the original edge's target, and org_he->target is the new vertex
-      new_he->set_is_equal_aux_data_in_target(0, org_he->get_is_equal_aux_data_in_target(0));
-      new_he->set_is_equal_aux_data_in_target(1, org_he->get_is_equal_aux_data_in_target(1));
+      // new_he->target is the original edge's target, and org_he->target
+      // is the new vertex
+      new_he->set_is_equal_aux_data_in_target
+        (0, org_he->get_is_equal_aux_data_in_target(0));
+      new_he->set_is_equal_aux_data_in_target
+        (1, org_he->get_is_equal_aux_data_in_target(1));
       org_he->set_is_equal_aux_data_in_target(0, true);
       org_he->set_is_equal_aux_data_in_target(1, true);
-      new_he->set_has_equal_aux_data_in_target(0, org_he->get_has_equal_aux_data_in_target(0));
-      new_he->set_has_equal_aux_data_in_target(1, org_he->get_has_equal_aux_data_in_target(1));
-      org_he->set_has_equal_aux_data_in_target(0, !base->aux_has_no_data(org_he, 0));
-      org_he->set_has_equal_aux_data_in_target(1, !base->aux_has_no_data(org_he, 1));
+      new_he->set_has_equal_aux_data_in_target
+        (0, org_he->get_has_equal_aux_data_in_target(0));
+      new_he->set_has_equal_aux_data_in_target
+        (1, org_he->get_has_equal_aux_data_in_target(1));
+      org_he->set_has_equal_aux_data_in_target
+        (0, !base->aux_has_no_data(org_he, 0));
+      org_he->set_has_equal_aux_data_in_target
+        (1, !base->aux_has_no_data(org_he, 1));
       new_he->set_has_equal_aux_data_in_target_and_face
         (0, org_he->get_has_equal_aux_data_in_target_and_face(0));
       new_he->set_has_equal_aux_data_in_target_and_face
@@ -1681,11 +1718,14 @@ protected:
       org_he->set_has_equal_aux_data_in_target_and_face
         (1, org_he->get_has_equal_aux_data_in_face(1));
 
-      // new_he->source is the new vertex, and org_he->source is the original vertex
+      // new_he->source is the new vertex, and org_he->source is the
+      // original vertex
       new_he->twin()->set_is_equal_aux_data_in_target(0, true);
       new_he->twin()->set_is_equal_aux_data_in_target(1, true);
-      new_he->twin()->set_has_equal_aux_data_in_target(0,!base->aux_has_no_data(org_he, 0));
-      new_he->twin()->set_has_equal_aux_data_in_target(1,!base->aux_has_no_data(org_he, 1));
+      new_he->twin()->set_has_equal_aux_data_in_target
+        (0,!base->aux_has_no_data(org_he, 0));
+      new_he->twin()->set_has_equal_aux_data_in_target
+        (1,!base->aux_has_no_data(org_he, 1));
 
       new_he->twin()->set_has_equal_aux_data_in_target_and_face
         (0, org_he->twin()->get_has_equal_aux_data_in_face(0));
@@ -1719,12 +1759,12 @@ protected:
 
     // Constructor.
     Faces_order_bfs_visitor(const IndexMap& imap, std::list<Face_handle>& f,
-                            Self* b = NULL) :
+                            Self* b) :
       index_map (&imap),
       faces(f),
       base(b)
     {
-      CGAL_assertion(base);
+      CGAL_assertion(base != NULL);
     }
 
     // Write the discover time for a given vertex.
@@ -1735,7 +1775,7 @@ protected:
       // first we check if we can set the decision immediately
       // if a surface of one map doesn't exist, then we set the second surface
       if (base->aux_has_no_data(fh, 0) && !base->aux_has_no_data(fh, 1))
-        fh->set_decision(SECOND);
+        fh->set_decision(DAC_DECISION_SECOND);
       else if (base->aux_has_no_data(fh, 0) && base->aux_has_no_data(fh, 1))
       {
 
@@ -1743,7 +1783,7 @@ protected:
         fh->set_no_data();
       }
       else if (!base->aux_has_no_data(fh, 0) && base->aux_has_no_data(fh, 1))
-        fh->set_decision(FIRST);
+        fh->set_decision(DAC_DECISION_FIRST);
       else
         // here, we have both surfaces.
         // we save the face in a list for a later treatment, because the
@@ -1755,9 +1795,8 @@ protected:
   
 protected:
   Envelope_resolver         *resolver;
-  Traits                    *traits;
-  // Should we evetually free the traits object
-  bool                      own_traits; 
+  const Traits * m_geom_traits;
+  bool m_own_traits; 
   bool                      m_is_lower;
 };
 
