@@ -15,8 +15,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Homogeneous_kernel/include/CGAL/Homogeneous/Homogeneous_base.h $
-// $Id: Homogeneous_base.h 45156 2008-08-26 13:40:26Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Homogeneous_kernel/include/CGAL/Homogeneous/Homogeneous_base.h $
+// $Id: Homogeneous_base.h 56795 2010-06-16 13:05:02Z lrineau $
 // 
 //
 // Author(s)     : Stefan Schirra, Sylvain Pion
@@ -85,6 +85,8 @@ struct Homogeneous_base
     typedef Homogeneous_tag                         Rep_tag;
     typedef Homogeneous_tag                         Kernel_tag;
 
+    enum { Has_filtered_predicates = false };
+
     typedef CGAL::Object                            Object_2;
     typedef CGAL::Object                            Object_3;
 
@@ -138,8 +140,8 @@ struct Homogeneous_base
     typedef CircleC3<Kernel>                        Circle_3;
     typedef Aff_transformationH3<Kernel>            Aff_transformation_3;
 
-    typedef Cartesian_const_iterator_d<const RT *>  Cartesian_const_iterator_2;
-    typedef Cartesian_const_iterator_d<const RT *>  Cartesian_const_iterator_3;
+    typedef Cartesian_const_iterator_d<typename cpp0x::array<RT, 3>::const_iterator> Cartesian_const_iterator_2;
+    typedef Cartesian_const_iterator_d<typename cpp0x::array<RT, 4>::const_iterator> Cartesian_const_iterator_3;
 
     typedef FT_                                     Cartesian_coordinate_type;
     typedef const RT_&                              Homogeneous_coordinate_type;
