@@ -15,8 +15,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.3-branch/Homogeneous_kernel/include/CGAL/Homogeneous/Iso_cuboidH3.h $
-// $Id: Iso_cuboidH3.h 35641 2006-12-27 23:25:54Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Homogeneous_kernel/include/CGAL/Homogeneous/Iso_cuboidH3.h $
+// $Id: Iso_cuboidH3.h 49057 2009-04-30 14:03:52Z spion $
 // 
 //
 // Author(s)     : Stefan Schirra
@@ -24,7 +24,7 @@
 #ifndef CGAL_ISO_CUBOIDH3_H
 #define CGAL_ISO_CUBOIDH3_H
 
-#include <CGAL/Twotuple.h>
+#include <CGAL/array.h>
 
 CGAL_BEGIN_NAMESPACE
 
@@ -36,7 +36,7 @@ class Iso_cuboidH3
   typedef typename R_::Point_3              Point_3;
   typedef typename R_::Aff_transformation_3 Aff_transformation_3;
 
-  typedef Twotuple<Point_3>                        Rep;
+  typedef cpp0x::array<Point_3, 2>          Rep;
   typedef typename R_::template Handle<Rep>::type  Base;
 
   Base base;
@@ -47,7 +47,7 @@ public:
   Iso_cuboidH3() {}
 
   Iso_cuboidH3(const Point_3& p, const Point_3& q, int)
-    : base(p, q)
+    : base(CGAL::make_array(p, q))
   {
     CGAL_kernel_assertion(p.x()<=q.x());
     CGAL_kernel_assertion(p.y()<=q.y());
@@ -145,8 +145,8 @@ Iso_cuboidH3(const typename Iso_cuboidH3<R>::Point_3& p,
       minz = q.hz()*p.hw();
       maxz = p.hz()*q.hw();
   }
-  base = Rep(Point_3(minx, miny, minz, minw),
-             Point_3(maxx, maxy, maxz, maxw));
+  base = Rep(CGAL::make_array(Point_3(minx, miny, minz, minw),
+                               Point_3(maxx, maxy, maxz, maxw)));
 }
 
 template < class R >
@@ -158,14 +158,14 @@ Iso_cuboidH3(const typename Iso_cuboidH3<R>::Point_3& left,
              const typename Iso_cuboidH3<R>::Point_3& top,
              const typename Iso_cuboidH3<R>::Point_3& far_,
              const typename Iso_cuboidH3<R>::Point_3& close)
-  : base(Point_3(left.hx()   * bottom.hw() * far_.hw(),
-                 bottom.hy() * left.hw()   * far_.hw(),
-                 far_.hz()   * left.hw()   * bottom.hw(),
-                 left.hw()   * bottom.hw() * far_.hw()),
-         Point_3(right.hx()  * top.hw()    * close.hw(),
-                 top.hy()    * right.hw()  * close.hw(),
-                 close.hz()  * right.hw()  * top.hw(),
-                 right.hw()  * top.hw()    * close.hw()))
+  : base(CGAL::make_array(Point_3(left.hx()   * bottom.hw() * far_.hw(),
+                                   bottom.hy() * left.hw()   * far_.hw(),
+                                   far_.hz()   * left.hw()   * bottom.hw(),
+                                   left.hw()   * bottom.hw() * far_.hw()),
+                           Point_3(right.hx()  * top.hw()    * close.hw(),
+                                   top.hy()    * right.hw()  * close.hw(),
+                                   close.hz()  * right.hw()  * top.hw(),
+                                   right.hw()  * top.hw()    * close.hw())))
 {
   CGAL_kernel_precondition(!less_x(right, left));
   CGAL_kernel_precondition(!less_y(top, bottom));
@@ -177,8 +177,8 @@ CGAL_KERNEL_LARGE_INLINE
 Iso_cuboidH3<R>::
 Iso_cuboidH3(const RT& min_hx, const RT& min_hy, const RT& min_hz,
              const RT& max_hx, const RT& max_hy, const RT& max_hz)
-  : base(Point_3(min_hx, min_hy, min_hz, RT(1)),
-         Point_3(max_hx, max_hy, max_hz, RT(1)))
+  : base(CGAL::make_array(Point_3(min_hx, min_hy, min_hz, RT(1)),
+                           Point_3(max_hx, max_hy, max_hz, RT(1))))
 {}
 
 template < class R >
@@ -187,8 +187,8 @@ Iso_cuboidH3<R>::
 Iso_cuboidH3(const RT& min_hx, const RT& min_hy, const RT& min_hz,
              const RT& max_hx, const RT& max_hy, const RT& max_hz, 
              const RT& hw)
-  : base(Point_3(min_hx, min_hy, min_hz, hw),
-         Point_3(max_hx, max_hy, max_hz, hw))
+  : base(CGAL::make_array(Point_3(min_hx, min_hy, min_hz, hw),
+                           Point_3(max_hx, max_hy, max_hz, hw)))
 {}
 
 template < class R >
@@ -209,13 +209,13 @@ template < class R >
 inline
 const typename Iso_cuboidH3<R>::Point_3 &
 Iso_cuboidH3<R>::min BOOST_PREVENT_MACRO_SUBSTITUTION () const
-{ return get(base).e0; }
+{ return get(base)[0]; }
 
 template < class R >
 inline
 const typename Iso_cuboidH3<R>::Point_3 &
 Iso_cuboidH3<R>::max BOOST_PREVENT_MACRO_SUBSTITUTION () const
-{ return get(base).e1; }
+{ return get(base)[1]; }
 
 template < class R >
 inline
