@@ -15,8 +15,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.3-branch/Homogeneous_kernel/include/CGAL/Homogeneous/Iso_rectangleH2.h $
-// $Id: Iso_rectangleH2.h 33347 2006-08-16 14:43:19Z afabri $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Homogeneous_kernel/include/CGAL/Homogeneous/Iso_rectangleH2.h $
+// $Id: Iso_rectangleH2.h 49057 2009-04-30 14:03:52Z spion $
 //
 //
 // Author(s)     : Stefan Schirra
@@ -24,7 +24,7 @@
 #ifndef CGAL_ISO_RECTANGLEH2_H
 #define CGAL_ISO_RECTANGLEH2_H
 
-#include <CGAL/Twotuple.h>
+#include <CGAL/array.h>
 
 CGAL_BEGIN_NAMESPACE
 
@@ -36,7 +36,7 @@ class Iso_rectangleH2
   typedef typename R_::Point_2              Point_2;
   typedef typename R_::Iso_rectangle_2      Iso_rectangle_2;
 
-  typedef Twotuple<Point_2>                        Rep;
+  typedef cpp0x::array<Point_2, 2>          Rep;
   typedef typename R_::template Handle<Rep>::type  Base;
 
   Base base;
@@ -49,7 +49,7 @@ public:
   Iso_rectangleH2() {}
 
   Iso_rectangleH2(const Point_2& p, const Point_2& q, int)
-    : base(p, q)
+    : base(CGAL::make_array(p, q))
   {
     // I have to remove the assertions, because of Homogeneous_converter.
     // CGAL_kernel_assertion(p.x()<=q.x());
@@ -68,13 +68,13 @@ template < class R >
 inline
 const typename Iso_rectangleH2<R>::Point_2 &
 Iso_rectangleH2<R>::min BOOST_PREVENT_MACRO_SUBSTITUTION () const
-{ return get(base).e0; }
+{ return get(base)[0]; }
 
 template < class R >
 inline
 const typename Iso_rectangleH2<R>::Point_2 &
 Iso_rectangleH2<R>::max BOOST_PREVENT_MACRO_SUBSTITUTION () const
-{ return get(base).e1; }
+{ return get(base)[1]; }
 
 template < class R >
 CGAL_KERNEL_INLINE
