@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Surface_mesher/include/CGAL/IO/Complex_2_in_triangulation_3_polyhedron_builder.h $
-// $Id: Complex_2_in_triangulation_3_polyhedron_builder.h 48774 2009-04-14 15:24:57Z lsaboret $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Surface_mesher/include/CGAL/IO/Complex_2_in_triangulation_3_polyhedron_builder.h $
+// $Id: Complex_2_in_triangulation_3_polyhedron_builder.h 51028 2009-08-03 10:57:57Z lsaboret $
 //
 //
 // Author(s)     : Laurent Rineau
@@ -50,6 +50,7 @@ public:
   void operator()(HDS& hds) {
     typedef typename Tr::Vertex_handle Vertex_handle;
     typedef typename Tr::Point Point;
+    typedef typename Tr::Geom_traits::Vector_3 Vector;
     typedef typename Tr::Edge Edge;
     typedef typename Tr::Facet Facet;
     typedef typename Tr::Finite_vertices_iterator Finite_vertices_iterator;
@@ -78,34 +79,60 @@ public:
 
       CGAL_assertion_code(typename Tr::size_type nb_facets = 0; )
 
-	while (oriented_set.size() != number_of_facets) {
-	  while ( fit->first->is_facet_on_surface(fit->second) == false ||
-		  oriented_set.find(*fit) != oriented_set.end() ||
+      while (oriented_set.size() != number_of_facets) {
+        while ( fit->first->is_facet_on_surface(fit->second) == false ||
+                oriented_set.find(*fit) != oriented_set.end() ||
 
-		  oriented_set.find(c2t3.opposite_facet(*fit)) !=
-		  oriented_set.end() ) {
-	    ++fit;
-	  }
-	  oriented_set.insert(*fit);
-	  stack.push(*fit);
-	  while(! stack.empty() ) {
-	    Facet f = stack.top();
-	    stack.pop();
-	    for(int ih = 0 ; ih < 3 ; ++ih) {
-	      const int i1  = tr.vertex_triple_index(f.second, tr. cw(ih));
-	      const int i2  = tr.vertex_triple_index(f.second, tr.ccw(ih));
-	      if( c2t3.face_status(Edge(f.first, i1, i2)) == C2t3::REGULAR ) {
-		Facet fn = c2t3.neighbor(f, ih);
-		if (oriented_set.find(fn) == oriented_set.end() &&
-		    oriented_set.find(c2t3.opposite_facet(fn)) == oriented_set.end())
-		{
-		  oriented_set.insert(fn);
-		  stack.push(fn);
-		}
-	      } // end "if the edge is regular"
-	    } // end "for each neighbor of f"
-	  } // end "stack non empty"
-	} // end "oriented_set not full"
+                oriented_set.find(c2t3.opposite_facet(*fit)) !=
+                oriented_set.end() ) {
+          ++fit;
+        }
+        oriented_set.insert(*fit);
+        stack.push(*fit);
+        while(! stack.empty() ) {
+          Facet f = stack.top();
+          stack.pop();
+          for(int ih = 0 ; ih < 3 ; ++ih) {
+            const int i1  = tr.vertex_triple_index(f.second, tr. cw(ih));
+            const int i2  = tr.vertex_triple_index(f.second, tr.ccw(ih));
+            if( c2t3.face_status(Edge(f.first, i1, i2)) == C2t3::REGULAR ) {
+              Facet fn = c2t3.neighbor(f, ih);
+              if (oriented_set.find(fn) == oriented_set.end() &&
+                  oriented_set.find(c2t3.opposite_facet(fn)) == oriented_set.end())
+              {
+                oriented_set.insert(fn);
+                stack.push(fn);
+              }
+            } // end "if the edge is regular"
+          } // end "for each neighbor of f"
+        } // end "stack non empty"
+      } // end "oriented_set not full"
+
+      // Orients the whole mesh towards outside:
+      // - find the facet with max z
+      typename std::set<Facet>::const_iterator top_facet = oriented_set.begin();
+      for(typename std::set<Facet>::const_iterator fit = oriented_set.begin();
+	  fit != oriented_set.end();
+	  ++fit)
+      {
+	double top_z = 
+	  (top_facet->first->vertex(tr.vertex_triple_index(top_facet->second, 0))->point().z()
+	 + top_facet->first->vertex(tr.vertex_triple_index(top_facet->second, 1))->point().z()
+	 + top_facet->first->vertex(tr.vertex_triple_index(top_facet->second, 2))->point().z())/3.;
+	double z = 
+	  (fit->first->vertex(tr.vertex_triple_index(fit->second, 0))->point().z()
+	 + fit->first->vertex(tr.vertex_triple_index(fit->second, 1))->point().z()
+	 + fit->first->vertex(tr.vertex_triple_index(fit->second, 2))->point().z())/3.;
+        if (top_z < z)
+          top_facet = fit;
+      }
+      // - orient the facet with max z towards +Z axis
+      Vertex_handle v0 = top_facet->first->vertex(tr.vertex_triple_index(top_facet->second, 0));
+      Vertex_handle v1 = top_facet->first->vertex(tr.vertex_triple_index(top_facet->second, 1));
+      Vertex_handle v2 = top_facet->first->vertex(tr.vertex_triple_index(top_facet->second, 2));
+      Vector normal = cross_product(v1->point()-v0->point(), v2->point()-v1->point());
+      const Vector Z(0, 0, 1);
+      bool regular_orientation = (Z * normal >= 0);
 
       for(typename std::set<Facet>::const_iterator fit =
 	    oriented_set.begin();
@@ -117,7 +144,11 @@ public:
 	for (int i=0; i<3; i++)
 	  indices[index++] =
 	    V[fit->first->vertex(tr.vertex_triple_index(fit->second, i))];
-	builder.add_facet(indices+0, indices+3);
+	builder.begin_facet();
+	  builder.add_vertex_to_facet(indices[0]);
+	  builder.add_vertex_to_facet(regular_orientation ? indices[1] : indices[2]);
+	  builder.add_vertex_to_facet(regular_orientation ? indices[2] : indices[1]);
+	builder.end_facet();
 	CGAL_assertion_code(++nb_facets);
       }
       CGAL_assertion(nb_facets == number_of_facets);
