@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.3-branch/Apollonius_graph_2/include/CGAL/IO/Qt_widget_Hyperbola_2.h $
-// $Id: Qt_widget_Hyperbola_2.h 28567 2006-02-16 14:30:13Z lsaboret $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Apollonius_graph_2/include/CGAL/IO/Qt_widget_Hyperbola_2.h $
+// $Id: Qt_widget_Hyperbola_2.h 45459 2008-09-09 22:29:51Z lrineau $
 // 
 //
 // Author(s)     : Menelaos Karavelas <mkaravel@cse.nd.edu>
@@ -20,8 +20,6 @@
 #ifndef CGAL_QT_WIDGET_HYPERBOLA_2_H
 #define CGAL_QT_WIDGET_HYPERBOLA_2_H
 
-#if defined CGAL_USE_QT
-
 #include <CGAL/Hyperbola_2.h>
 #include <CGAL/Hyperbola_ray_2.h>
 #include <CGAL/IO/Qt_widget.h>
@@ -46,7 +44,4 @@ Qt_widget& operator<<(Qt_widget &s, Hyperbola_ray_2<Gt> &H)
 
 CGAL_END_NAMESPACE
 
-#endif
-
-
 #endif // CGAL_QT_WIDGET_HYPERBOLA_2_H
