@@ -14,8 +14,8 @@
 //
 // These files are provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/CGALimageIO/include/CGAL/ImageIO.h $
-// $Id: ImageIO.h 46133 2008-10-07 13:00:59Z lrineau $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/CGALimageIO/include/CGAL/ImageIO.h $
+// $Id: ImageIO.h 53026 2009-11-14 11:49:52Z spion $
 //
 
 #ifndef IMAGEIO_H
@@ -206,7 +206,7 @@ typedef struct imformat {
   char realName[IMAGE_FORMAT_NAME_LENGTH];
   /* pointer towards the next image format*/
   struct imformat *next;
-} IMAGE_FORMAT, *PTRIMAGE_FORMAT;;
+} IMAGE_FORMAT, *PTRIMAGE_FORMAT;
 
 /** Image descriptor */
 typedef struct point_image {
