@@ -15,8 +15,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Kernel_23/include/CGAL/Is_a_predicate.h $
-// $Id: Is_a_predicate.h 41543 2008-01-11 22:56:35Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Kernel_23/include/CGAL/Is_a_predicate.h $
+// $Id: Is_a_predicate.h 51456 2009-08-24 17:10:04Z spion $
 // 
 //
 // Author(s)     : Sylvain Pion
@@ -31,7 +31,7 @@
 
 CGAL_BEGIN_NAMESPACE
 
-namespace CGALi {
+namespace internal {
 
 // By default it's a construction
 template <typename Return_type>
@@ -60,11 +60,11 @@ struct Return_type_of_predicate<CGAL::Angle> {
     typedef CGAL::Tag_true type;
 };
 
-} // namespace CGALi
+} // namespace internal
 
 template <typename Functor>
 struct Is_a_predicate {
-  typedef typename CGALi::Return_type_of_predicate<
+  typedef typename internal::Return_type_of_predicate<
                    typename Functor::result_type>::type type;
 };
 
