@@ -3,6 +3,7 @@
 // INRIA Sophia-Antipolis (France), Martin-Luther-University Halle-Wittenberg
 // (Germany), Max-Planck-Institute Saarbruecken (Germany), RISC Linz (Austria),
 // and Tel-Aviv University (Israel).  All rights reserved.
+// Copyright (c) 2009 GeometryFactory (France)
 //
 // This file is part of CGAL (www.cgal.org); you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public License as
@@ -15,8 +16,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Kernel_23/include/CGAL/Kernel/function_objects.h $
-// $Id: function_objects.h 47275 2008-12-08 14:47:16Z afabri $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Kernel_23/include/CGAL/Kernel/function_objects.h $
+// $Id: function_objects.h 56955 2010-06-22 07:22:56Z sloriot $
 //
 //
 // Author(s)     : Stefan Schirra, Sylvain Pion
@@ -163,6 +164,136 @@ namespace CommonKernelFunctors {
     { return assign(t, o); }
   };
 
+  template <typename K>
+  class Compare_dihedral_angle_3
+  {
+    typedef typename K::Point_3            Point_3;
+    typedef typename K::Vector_3           Vector_3;
+    typedef typename K::FT                 FT;
+  public:
+    typedef typename K::Comparison_result  result_type;
+
+    result_type
+    operator()(const Point_3& a1, const Point_3& b1, 
+               const Point_3& c1, const Point_3& d1, 
+               const Point_3& a2, const Point_3& b2, 
+               const Point_3& c2, const Point_3& d2) const
+    {
+      const Vector_3 ab1 = b1 - a1;
+      const Vector_3 ac1 = c1 - a1;
+      const Vector_3 ad1 = d1 - a1;
+
+      const Vector_3 ab2 = b2 - a2;
+      const Vector_3 ac2 = c2 - a2;
+      const Vector_3 ad2 = d2 - a2;
+      return this->operator()(ab1, ac1, ad1, ab2, ac2, ad2);
+    }
+
+    result_type
+    operator()(const Point_3& a1, const Point_3& b1, 
+               const Point_3& c1, const Point_3& d1, 
+               const FT& cosine) const
+    {
+      const Vector_3 ab1 = b1 - a1;
+      const Vector_3 ac1 = c1 - a1;
+      const Vector_3 ad1 = d1 - a1;
+
+      return this->operator()(ab1, ac1, ad1, cosine);
+    }
+
+    result_type
+    operator()(const Vector_3& ab1, const Vector_3& ac1, const Vector_3& ad1,
+               const FT& cosine)
+      const
+    {
+      typedef typename K::FT                                 FT;
+      typedef typename K::Construct_cross_product_vector_3   Cross_product;
+      Cross_product xproduct = K().construct_cross_product_vector_3_object();
+
+      const Vector_3 abac1 = xproduct(ab1, ac1);
+      const Vector_3 abad1 = xproduct(ab1, ad1);
+      const FT sc_prod_1 = abac1 * abad1;
+
+      CGAL_kernel_assertion_msg( abac1 != NULL_VECTOR,
+                                 "ab1 and ac1 are collinear" );
+      CGAL_kernel_assertion_msg( abad1 != NULL_VECTOR,
+                                 "ab1 and ad1 are collinear" );
+
+      if(sc_prod_1 >= 0 ) {
+        if(cosine >= 0) {
+          // the two cosine are >= 0, cosine is decreasing on [0,1]
+          return compare(CGAL::square(cosine)*
+                         abac1.squared_length()*abad1.squared_length(),
+                         CGAL::square(sc_prod_1));
+        }
+        else {
+          return SMALLER;
+        }
+      }
+      else {
+        if(cosine < 0) {
+          // the two cosine are < 0, cosine is increasing on [-1,0]
+          return compare(CGAL::square(sc_prod_1),
+                         CGAL::square(cosine)*
+                         abac1.squared_length()*abad1.squared_length());
+        }
+        else
+          return LARGER;
+        }
+    }
+
+    result_type
+    operator()(const Vector_3& ab1, const Vector_3& ac1, const Vector_3& ad1,
+               const Vector_3& ab2, const Vector_3& ac2, const Vector_3& ad2)
+      const
+    {
+      typedef typename K::FT                                 FT;
+      typedef typename K::Construct_cross_product_vector_3   Cross_product;
+      Cross_product xproduct = K().construct_cross_product_vector_3_object();
+
+      const Vector_3 abac1 = xproduct(ab1, ac1);
+      const Vector_3 abad1 = xproduct(ab1, ad1);
+      const FT sc_prod_1 = abac1 * abad1;
+
+      const Vector_3 abac2 = xproduct(ab2, ac2);
+      const Vector_3 abad2 = xproduct(ab2, ad2);
+      const FT sc_prod_2 = abac2 * abad2;
+
+      CGAL_kernel_assertion_msg( abac1 != NULL_VECTOR,
+                                 "ab1 and ac1 are collinear" );
+      CGAL_kernel_assertion_msg( abad1 != NULL_VECTOR,
+                                 "ab1 and ad1 are collinear" );
+      CGAL_kernel_assertion_msg( abac2 != NULL_VECTOR,
+                                 "ab2 and ac2 are collinear" );
+      CGAL_kernel_assertion_msg( abad2 != NULL_VECTOR,
+                                 "ab2 and ad2 are collinear" );
+
+      if(sc_prod_1 >= 0 ) {
+        if(sc_prod_2 >= 0) {
+          // the two cosine are >= 0, cosine is decreasing on [0,1]
+          return compare(CGAL::square(sc_prod_2)*
+                         abac1.squared_length()*abad1.squared_length(),
+                         CGAL::square(sc_prod_1)*
+                         abac2.squared_length()*abad2.squared_length());
+        }
+        else {
+          return SMALLER;
+        }
+      }
+      else {
+        if(sc_prod_2 < 0) {
+          // the two cosine are < 0, cosine is increasing on [-1,0]
+          return compare(CGAL::square(sc_prod_1)*
+                         abac2.squared_length()*abad2.squared_length(),
+                         CGAL::square(sc_prod_2)*
+                         abac1.squared_length()*abad1.squared_length());
+        }
+        else
+          return LARGER;
+        }
+    }
+  };
+
   template <typename K>
   class Compute_area_3
   {
@@ -196,7 +327,7 @@ namespace CommonKernelFunctors {
     template <class T1, class T2>
     FT
     operator()( const T1& t1, const T2& t2) const
-    { return CGALi::squared_distance(t1, t2, K()); }
+    { return internal::squared_distance(t1, t2, K()); }
   };
 
   template <typename K>
@@ -211,7 +342,7 @@ namespace CommonKernelFunctors {
     template <class T1, class T2>
     FT
     operator()( const T1& t1, const T2& t2) const
-    { return CGALi::squared_distance(t1, t2, K()); }
+    { return internal::squared_distance(t1, t2, K()); }
 
     FT
     operator()( const Point_3& pt1, const Point_3& pt2) const
@@ -1706,7 +1837,7 @@ namespace CommonKernelFunctors {
   };
 
   template <typename K>
-  class Construct_vertex_3
+  class Construct_vertex_3 : Has_qrt
   {
     typedef typename K::Point_3          Point_3;
     typedef typename K::Segment_3        Segment_3;
@@ -1853,7 +1984,7 @@ namespace CommonKernelFunctors {
     template <class T1, class T2>
     result_type
     operator()(const T1& t1, const T2& t2) const
-    { return CGALi::do_intersect(t1, t2, K()); }
+    { return internal::do_intersect(t1, t2, K()); }
   };
 
   template <typename K>
@@ -1866,7 +1997,7 @@ namespace CommonKernelFunctors {
     template <class T1, class T2>
     result_type
     operator()(const T1& t1, const T2& t2) const
-    { return CGALi::do_intersect(t1, t2, K()); }
+    { return internal::do_intersect(t1, t2, K()); }
   };
 
   template <typename K>
@@ -2342,7 +2473,7 @@ namespace CommonKernelFunctors {
     template <class T1, class T2>
     Object_2
     operator()(const T1& t1, const T2& t2) const
-    { return CGALi::intersection(t1, t2, K()); }
+    { return internal::intersection(t1, t2, K()); }
   };
 
   template <typename K>
@@ -2357,11 +2488,11 @@ namespace CommonKernelFunctors {
     template <class T1, class T2>
     Object_3
     operator()(const T1& t1, const T2& t2) const
-    { return CGALi::intersection(t1, t2, K() ); }
+    { return internal::intersection(t1, t2, K() ); }
 
     Object_3
     operator()(const Plane_3& pl1, const Plane_3& pl2, const Plane_3& pl3)const
-    { return CGALi::intersection(pl1, pl2, pl3, K() ); }
+    { return internal::intersection(pl1, pl2, pl3, K() ); }
   };
 
   template <typename K>
@@ -2581,6 +2712,11 @@ namespace CommonKernelFunctors {
 
 } // namespace CommonKernelFunctors
 
+  template <class K>
+  struct Qualified_result_of<CommonKernelFunctors::Construct_vertex_3<K>,Iso_cuboid_3<K> > :
+    qrt_or_not<typename CommonKernelFunctors::Construct_vertex_3<K>,false>
+  {};
+
 CGAL_END_NAMESPACE
 
 #endif // CGAL_KERNEL_FUNCTION_OBJECTS_H
