@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Kinetic_data_structures/include/CGAL/Kinetic/IO/internal/GUI_base.h $
-// $Id: GUI_base.h 40832 2007-11-08 00:27:20Z ameyer $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Kinetic_data_structures/include/CGAL/Kinetic/IO/internal/GUI_base.h $
+// $Id: GUI_base.h 53026 2009-11-14 11:49:52Z spion $
 // 
 //
 // Author(s)     : Daniel Russel <drussel@alumni.princeton.edu>
@@ -112,7 +112,7 @@ public:
     }
   }
 
-  CGAL_KINETIC_LISTENER1(CURRENT_TIME);
+  CGAL_KINETIC_LISTENER1(CURRENT_TIME)
 public:
   //! get the simulator
   typename Simulator::Handle& simulator() {
@@ -168,7 +168,7 @@ protected:
 
   
 
-  CGAL_KINETIC_LISTEN1(Timer, TICKS, timer_rang());
+  CGAL_KINETIC_LISTEN1(Timer, TICKS, timer_rang())
   /*class Timer_listener: public Timer::Listener
   {
   public:
@@ -328,5 +328,5 @@ protected:
   //Listener *drawable_;
   bool processing_;
 };
-CGAL_KINETIC_END_NAMESPACE;
+CGAL_KINETIC_END_NAMESPACE
 #endif
