@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Kinetic_data_structures/include/CGAL/Kinetic/IO/internal/Qt_core.h $
-// $Id: Qt_core.h 40530 2007-10-04 11:14:00Z drussel $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Kinetic_data_structures/include/CGAL/Kinetic/IO/internal/Qt_core.h $
+// $Id: Qt_core.h 53026 2009-11-14 11:49:52Z spion $
 // 
 //
 // Author(s)     : Daniel Russel <drussel@alumni.princeton.edu>
@@ -42,7 +42,7 @@ namespace CGAL
 
 	Qt_core();
 
-	CGAL_KINETIC_LISTENERNT1(LAST_BUTTON_PRESSED);
+	CGAL_KINETIC_LISTENERNT1(LAST_BUTTON_PRESSED)
       public:
       
 	/*class Listener
@@ -143,7 +143,7 @@ namespace CGAL
 	typename Base::Handle t_;
       };
 
-    };
-  };
-};
+    }
+  }
+}
 #endif
