@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.3-branch/Kinetic_data_structures/include/CGAL/Kinetic/IO/internal/Qt_widget_2_core.h $
-// $Id: Qt_widget_2_core.h 30976 2006-05-03 13:20:30Z drussel $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Kinetic_data_structures/include/CGAL/Kinetic/IO/internal/Qt_widget_2_core.h $
+// $Id: Qt_widget_2_core.h 39380 2007-07-15 17:12:23Z drussel $
 // 
 //
 // Author(s)     : Daniel Russel <drussel@alumni.princeton.edu>
@@ -24,6 +24,8 @@
 #include <CGAL/Kinetic/basic.h>
 #include <CGAL/IO/Qt_widget.h>
 #include <qmainwindow.h>
+#include <CGAL/Kinetic/Listener.h>
+#include <CGAL/Kinetic/Ref_counted.h>
 
 namespace CGAL
 {
@@ -31,11 +33,26 @@ namespace CGAL
   {
     namespace internal
     {
-      class Qt_widget_2_core: public ::CGAL::Qt_widget
+      class Qt_widget_2_core: public ::CGAL::Qt_widget, public Non_ref_counted<Qt_widget_2_core>
       {
 	Q_OBJECT
+      private:			
+	struct Listener_core{						
+	  typedef  This Notifier;		
+	  typedef enum {PICTURE_IS_CURRENT} Notification_type;		
+	};								
+      public:							
+	typedef CGAL::Kinetic::Listener_base<Listener_core> Listener;	
+	friend class CGAL::Kinetic::Listener_base<Listener_core>;	
+      private:							
+	void set_listener(Listener *sk) {				
+	  listener_=sk;						
+	}								
+	Listener* listener() {return listener_.get();}		
+	Listener::Handle listener_;
       public:
-	class Listener
+
+	/*class Listener
 	{
 	public:
 	  Listener(Qt_widget_2_core *widget): widget_(widget) {
@@ -49,13 +66,13 @@ namespace CGAL
 	  typedef enum {PICTURE_IS_CURRENT}
 	  Notification_type;
 	  virtual void new_notification(Notification_type) {
-	    //CGAL_KINETIC_ERROR( "draw not implemented.\n");
+	    //CGAL_ERROR( "draw not implemented.\n");
 	    std::cerr << "Drawing but nothing is to be drawn.\n";
 	  }
 	  Qt_widget_2_core *widget(){return widget_;}
 	protected:
 	  Qt_widget_2_core *widget_;
-	};
+	  };*/
 
 	Qt_widget_2_core(QMainWindow *parent);
 
@@ -70,15 +87,8 @@ namespace CGAL
 	  if (tf==false) redraw();
 	}
       protected:
-	Listener *drawable_;
 	bool is_drawn_;
-      private:
-	friend class Listener;
-	void set_listener(Listener *d) {
-	  //CGAL_precondition(drawable_==NULL);
-	  drawable_=d;
-	  //redraw(); // this doesn't work since virtual functions can't be called from teh constructor
-	}
+
       };
     }
   }
