@@ -1,4 +1,4 @@
-// Copyright (c) 2006  INRIA Sophia-Antipolis (France).
+// Copyright (c) 2006-2007  INRIA Sophia-Antipolis (France).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org); you may redistribute it under
@@ -11,18 +11,23 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.3-branch/Mesh_2/include/CGAL/Mesh_2/Output_stream.h $
-// $Id: Output_stream.h 32347 2006-07-10 09:25:35Z lrineau $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Mesh_2/include/CGAL/Mesh_2/Output_stream.h $
+// $Id: Output_stream.h 40619 2007-10-16 12:01:02Z lrineau $
 //
 //
 // Author(s)     : Laurent Rineau
 
 #ifndef CGAL_MESHES_OUTPUT_STREAM_H
 
-#ifndef CGAL_MESHES_OUTPUT_ON_CERR
-#define CGAL_MESHES_OUTPUT_STREAM std::cout
+#ifdef CGAL_MESHES_NO_OUTPUT
+#  include <CGAL/IO/Verbose_ostream.h>
+#  define CGAL_MESHES_OUTPUT_STREAM CGAL::Verbose_ostream()
 #else
-#define CGAL_MESHES_OUTPUT_STREAM std::cerr
+#  ifndef CGAL_MESHES_OUTPUT_ON_CERR
+#    define CGAL_MESHES_OUTPUT_STREAM std::cout
+#  else
+#    define CGAL_MESHES_OUTPUT_STREAM std::cerr
+#  endif
 #endif
 
 #endif
