@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.4-branch/Min_sphere_of_spheres_d/include/CGAL/Min_sphere_of_spheres_d/Min_sphere_of_spheres_d_impl.h $
-// $Id: Min_sphere_of_spheres_d_impl.h 47405 2008-12-12 10:53:21Z lrineau $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Min_sphere_of_spheres_d/include/CGAL/Min_sphere_of_spheres_d/Min_sphere_of_spheres_d_impl.h $
+// $Id: Min_sphere_of_spheres_d_impl.h 50491 2009-07-09 08:20:14Z afabri $
 // 
 //
 // Author(s)     : Kaspar Fischer
@@ -101,7 +101,7 @@ namespace CGAL_MINIBALL_NAMESPACE {
     for (int k=from; k<to; ++k) {
       // compute the (squared) distance from c1 to c2:
       const FT dist = inner_product_n<D>(ss.begin(),
-        t.center_cartesian_begin(*l[k]),0.0,std::plus<FT>(),
+        t.center_cartesian_begin(*l[k]),0.0f,std::plus<FT>(),
         Subtract_and_square<FT>());
   
       // compute excess:
@@ -137,7 +137,7 @@ namespace CGAL_MINIBALL_NAMESPACE {
     for (int k=from; k<to; ++k) {
       // compute the (squared) distance from c1 to c2:
       const double dist = inner_product_n<D>(center,
-         t.center_cartesian_begin(*l[k]),0.0,std::plus<double>(),
+         t.center_cartesian_begin(*l[k]),0.0f,std::plus<double>(),
          Subtract_and_square_to_double<FT>());
   
       // compute excess:
@@ -174,7 +174,7 @@ namespace CGAL_MINIBALL_NAMESPACE {
     for (int k=from; k<to; ++k) {
       // compute the (squared) distance from c1 to c2:
       const FT dist = inner_product_n<D>(ss.begin(),
-        t.center_cartesian_begin(*l[k]),0.0,std::plus<FT>(),
+        t.center_cartesian_begin(*l[k]),0.0f,std::plus<FT>(),
         Subtract_and_square<FT>());
   
       if (compare(max,maxp,t.radius(*l[k]),dist)) {
@@ -208,7 +208,7 @@ namespace CGAL_MINIBALL_NAMESPACE {
     for (int k=from; k<to; ++k) {
       // compute the (squared) distance from c1 to c2:
       const double dist = inner_product_n<D>(center,
-         t.center_cartesian_begin(*l[k]),0.0,std::plus<double>(),
+         t.center_cartesian_begin(*l[k]),0.0f,std::plus<double>(),
          Subtract_and_square_to_double<FT>());
   
       const double r = CGAL_MINIBALL_NTS to_double(t.radius(*l[k]));
