@@ -11,13 +11,15 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.3-branch/Nef_2/include/CGAL/Nef_2/PM_persistent_PL.h $
-// $Id: PM_persistent_PL.h 28567 2006-02-16 14:30:13Z lsaboret $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Nef_2/include/CGAL/Nef_2/PM_persistent_PL.h $
+// $Id: PM_persistent_PL.h 48717 2009-04-08 11:54:51Z spion $
 // 
 //
 // Author(s)     : Michael Seel <seel@mpi-sb.mpg.de>
+
 #ifndef CGAL_PM_PERSISTENT_PL_H
-#define CGAL_PM_PM_PERSISTENT_PL_H
+#define CGAL_PM_PERSISTENT_PL_H
+
 #include <CGAL/Nef_2/gen_point_location.h>
 
 template <typename PMPL>
@@ -82,7 +84,7 @@ struct PM_persistent_PL_traits
     if ( cmpX > 0 ) return EndingNonVertical;
 
     int cmpY = pK->compare_y(p_u, p_v); 
-    assert(cmpY != 0);
+    CGAL_assertion(cmpY != 0);
     if ( cmpY < 0 ) return StartingVertical;
     return EndingVertical;
   }    
@@ -173,14 +175,14 @@ struct PM_persistent_PL_traits
   { /* we only get an L_plus (non-nil) if L is ABOVE a vertex
        in which case we want to extract the face from the edge
        below (p+epsilon) available via L_plus. */
-    if (!L_plus.is_nil()) { assert(L_plus.is_edge());
+    if (!L_plus.is_nil()) { CGAL_assertion(L_plus.is_edge());
       return Object_handle(Edge(L_plus));
     } else { 
       if ( L.is_edge() ) {
         return Object_handle(Edge(L));
       }
       if ( L.is_node() ) {
-        Node v(L); assert( v != Node() );
+        Node v(L); CGAL_assertion( v != Node() );
         return Object_handle(v);
       }
       return Object_handle();
@@ -199,4 +201,3 @@ struct PM_persistent_PL_traits
 
 
 #endif // CGAL_PM_PM_PERSISTENT_PL_H
-
