@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.3-branch/Nef_2/include/CGAL/Nef_2/iterator_tools.h $
-// $Id: iterator_tools.h 28567 2006-02-16 14:30:13Z lsaboret $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Nef_2/include/CGAL/Nef_2/iterator_tools.h $
+// $Id: iterator_tools.h 44130 2008-07-12 21:58:52Z spion $
 // 
 //
 // Author(s)     : Michael Seel <seel@mpi-sb.mpg.de>
@@ -39,11 +39,11 @@ public:
 // OPERATIONS Forward Category
 // ---------------------------
 
-    bool operator==( CGAL_NULL_TYPE p ) const {
+    bool operator==( Nullptr_t p ) const {
       CGAL_assertion( p == NULL );
       return Iter::operator==( Iter(NULL) );
     }
-    bool operator!=( CGAL_NULL_TYPE p ) const {
+    bool operator!=( Nullptr_t p ) const {
       return !(*this == p);
     }
     bool operator==( const Self& i ) const {
