@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.4-branch/Nef_3/include/CGAL/Nef_3/SNC_SM_overlayer.h $
-// $Id: SNC_SM_overlayer.h 39419 2007-07-18 19:02:25Z hachenb $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Nef_3/include/CGAL/Nef_3/SNC_SM_overlayer.h $
+// $Id: SNC_SM_overlayer.h 50723 2009-07-20 13:46:03Z hachenb $
 // 
 //
 // Author(s)     : Michael Seel <seel@mpi-sb.mpg.de>
@@ -104,7 +104,7 @@ public:
 			e->incident_sface()->mark() << " " << 
 			e->twin()->incident_sface()->mark());
 	if (( e->mark() == e->incident_sface()->mark() && 
-	      e->mark() == e->twin()->incident_sface()->mark())){
+	      e->incident_sface()->mark() == e->twin()->incident_sface()->mark())){
 	  CGAL_NEF_TRACEN("deleting "<<PH(e));
 	  if ( !UF.same_set(Pitem[e->incident_sface()],
 			    Pitem[e->twin()->incident_sface()]) ) {
@@ -159,7 +159,7 @@ public:
       } else { // v not isolated
 	SHalfedge_handle e2 = first_out_edge(v), e1 = e2->sprev();
 	if ( has_outdeg_two(v) &&
-	     v->mark() == e1->mark() && v->mark() == e2->mark() &&
+	     v->mark() == e1->mark() && e1->mark() == e2->mark() &&
 	     e1->circle() == e2->circle() ) {
 	  CGAL_NEF_TRACEN("collinear at "<<PH(v)<<PH(e1)<<PH(e2));
 	  if ( e1 == e2 ){ 
@@ -353,7 +353,7 @@ class SNC_SM_overlayer<SNC_indexed_items, SM_decorator_>
 			e->incident_sface()->mark() << " " << 
 			e->twin()->incident_sface()->mark());
 	if (( e->mark() == e->incident_sface()->mark() && 
-	      e->mark() == e->twin()->incident_sface()->mark())){
+	      e->incident_sface()->mark() == e->twin()->incident_sface()->mark())){
 	  CGAL_NEF_TRACEN("deleting "<<PH(e));
 	  if ( !UF.same_set(Pitem[e->incident_sface()],
 			    Pitem[e->twin()->incident_sface()]) ) {
@@ -408,7 +408,7 @@ class SNC_SM_overlayer<SNC_indexed_items, SM_decorator_>
       } else { // v not isolated
 	SHalfedge_handle e2 = first_out_edge(v), e1 = e2->sprev();
 	if ( has_outdeg_two(v) &&
-	     v->mark() == e1->mark() && v->mark() == e2->mark() &&
+	     v->mark() == e1->mark() && e1->mark() == e2->mark() &&
 	     e1->circle() == e2->circle() ) {
 	  CGAL_NEF_TRACEN("collinear at "<<PH(v)<<PH(e1)<<PH(e2));
 	  if ( e1 == e2 ){ 
