@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Nef_3/include/CGAL/Nef_3/SNC_structure.h $
-// $Id: SNC_structure.h 45448 2008-09-09 16:03:25Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Nef_3/include/CGAL/Nef_3/SNC_structure.h $
+// $Id: SNC_structure.h 56321 2010-05-18 09:17:38Z lrineau $
 // 
 //
 // Author(s)     : Michael Seel    <seel@mpi-sb.mpg.de>
@@ -1467,25 +1467,29 @@ pointer_update(const SNC_structure<Kernel,Items,Mark>& D)
   }
 
   CGAL_forall_sfaces(sf,*this) {
-    sf->center_vertex() = VM[sf->center_vertex()];
-    sf->volume() = CM[sf->volume()];
-    SFace_cycle_iterator sfc;
-    for(sfc = sf->sface_cycles_begin(); 
-        sfc != sf->sface_cycles_end(); ++sfc) {
-      if (sfc.is_svertex()) { 
-	SVertex_handle sv(sfc);
-	*sfc = make_object(EM[sv]);
-	store_sm_boundary_item(sv,sfc);
-      } else if (sfc.is_shalfedge()) { 
-	se = SHalfedge_handle(sfc);
-	*sfc = make_object(SEM[se]);
-	store_sm_boundary_item(se,sfc);
-      } else if (sfc.is_shalfloop()) { 
-	sl = SHalfloop_handle(sfc);
-	*sfc = make_object(SLM[sl]);
-	store_sm_boundary_item(sl,sfc);
-      } else CGAL_error_msg("damn wrong boundary item in sface.");
-    }
+	  sf->center_vertex() = VM[sf->center_vertex()];
+	  sf->volume() = CM[sf->volume()];
+	  SFace_cycle_iterator sfc;
+	  for(sfc = sf->sface_cycles_begin(); 
+		  sfc != sf->sface_cycles_end(); ++sfc) 
+	  {
+		  if (sfc.is_svertex()) { 
+			  SVertex_handle sv(sfc);
+			  sv = EM[sv];
+			  *sfc = make_object(sv);
+			  store_sm_boundary_item(sv,sfc);
+		  } else if (sfc.is_shalfedge()) { 
+			  se = SHalfedge_handle(sfc);
+			  se = SEM[se];
+			  *sfc = make_object(se);
+			  store_sm_boundary_item(se,sfc);
+		  } else if (sfc.is_shalfloop()) { 
+			  sl = SHalfloop_handle(sfc);
+			  sl = SLM[sl];
+			  *sfc = make_object(sl);
+			  store_sm_boundary_item(sl,sfc);
+		  } else CGAL_error_msg("damn wrong boundary item in sface.");
+	  }
   }
 }
 
