@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Number_types/include/CGAL/Number_types/internal_functions_comparison_root_of_2.h $
-// $Id: internal_functions_comparison_root_of_2.h 44918 2008-08-12 14:59:20Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Number_types/include/CGAL/Number_types/internal_functions_comparison_root_of_2.h $
+// $Id: internal_functions_comparison_root_of_2.h 51456 2009-08-24 17:10:04Z spion $
 //
 //
 // Author(s)     : Sylvain Pion, Monique Teillaud, Athanasios Kakargias
@@ -26,7 +26,7 @@
 #include <CGAL/kernel_assertions.h>
 
 namespace CGAL {
-namespace CGALi {
+namespace internal {
 
 // Maybe we can trash this
 /*1 1*/template <class FT>
@@ -218,7 +218,7 @@ template <class FT>
 inline FT calcD(const FT& A1, const FT& I1, const FT& A2, const FT& I2)
 { return I1*CGAL_NTS square(A2) - I2*CGAL_NTS square(A1);}
 
-} // namespace CGALi
+} // namespace internal
 } // namespace CGAL
 
 #endif // CGAL_NUMBER_TypeS_ROOT_OF_COMPARISON_FUNCTIONS_22_H
