@@ -3,7 +3,7 @@
 #include <CGAL/PDB/basic.h>
 #include <CGAL/PDB/internal/tnt/tnt_array2d.h>
 
-CGAL_PDB_BEGIN_NAMESPACE
+namespace CGAL { namespace PDB {
 //! Use TNT::Array2D<double> as a matrix
 typedef TNT::Array2D<double> Matrix;
 
@@ -29,5 +29,5 @@ Matrix transpose(const Matrix& m) {
 
 
 
-CGAL_PDB_END_NAMESPACE
+}}
 #endif
