@@ -5,10 +5,19 @@
 #include <CGAL/PDB/Point.h>
 #include <iostream>
 
-CGAL_PDB_BEGIN_NAMESPACE
+namespace CGAL { namespace PDB {
 
 typedef Aff_transformation_3<CGAL::Exact_predicates_inexact_constructions_kernel> Transform;
 
-CGAL_PDB_END_NAMESPACE
+inline void write(const Transform &tr) {
+  for (unsigned int i=0; i< 3; ++i) {
+    for (unsigned int j=0; j< 4; ++j) {
+      std::cout << tr.cartesian(i,j) << " ";
+    }
+    std::cout << std::endl;
+  }
+}
+
+}}
 
 #endif
