@@ -15,8 +15,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Intersections_2/include/CGAL/Point_2_Iso_rectangle_2_intersection.h $
-// $Id: Point_2_Iso_rectangle_2_intersection.h 39776 2007-08-08 15:15:20Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Intersections_2/include/CGAL/Point_2_Iso_rectangle_2_intersection.h $
+// $Id: Point_2_Iso_rectangle_2_intersection.h 51456 2009-08-24 17:10:04Z spion $
 // 
 //
 // Author(s)     : Geert-Jan Giezeman
@@ -31,7 +31,7 @@
 
 CGAL_BEGIN_NAMESPACE
 
-namespace CGALi {
+namespace internal {
 
 template <class K>
 inline 
@@ -59,7 +59,7 @@ intersection(const typename K::Point_2 &pt,
 	     const typename K::Iso_rectangle_2 &iso,
 	     const K& k)
 {
-  if (CGALi::do_intersect(pt,iso,k)) {
+  if (internal::do_intersect(pt,iso,k)) {
     return make_object(pt);
     }
     return Object();
@@ -72,13 +72,13 @@ intersection(const typename K::Iso_rectangle_2 &iso,
 	     const typename K::Point_2 &pt,
 	     const K& k)
 {
-  if (CGALi::do_intersect(pt,iso,k)) {
+  if (internal::do_intersect(pt,iso,k)) {
     return make_object(pt);
     }
     return Object();
 }
 
-} // namespace CGALi
+} // namespace internal
 
 
 template <class K>
