@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Polynomial/include/CGAL/Polynomial/fwd.h $
-// $Id: fwd.h 48562 2009-03-27 17:30:16Z mkerber $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Polynomial/include/CGAL/Polynomial/fwd.h $
+// $Id: fwd.h 55605 2010-04-21 10:05:02Z hemmer $
 //
 //
 // Author(s)     : Michael Hemmer 
@@ -28,15 +28,13 @@ namespace CGAL{
 
 template <class NT> class Polynomial; 
 
-namespace CGALi{
-template <class NT> inline Polynomial<NT> gcd (const Polynomial<NT>&, const Polynomial<NT>&);
+namespace internal{
+template <class NT> inline Polynomial<NT> gcd_(const Polynomial<NT>&, const Polynomial<NT>&);
 template <class NT> inline Polynomial<NT> gcd_(const Polynomial<NT>&, const Polynomial<NT>&, Field_tag);
 template <class NT> inline Polynomial<NT> gcd_(const Polynomial<NT>&, const Polynomial<NT>&, Unique_factorization_domain_tag);
 
 
 template <class NT> inline NT gcd_utcf_(const NT& a, const NT& b){return NT(1);}
-template <class NT> inline Polynomial<NT> gcd_utcf(const Polynomial<NT>&, const Polynomial<NT>&);
-
 template <class NT> inline Polynomial<NT> gcd_utcf_(const Polynomial<NT>&, const Polynomial<NT>&);
 template <class NT> inline Polynomial<NT> gcd_utcf_UFD( Polynomial<NT> , Polynomial<NT>) ;
 template <class NT> inline Polynomial<NT> gcd_utcf_Integral_domain(Polynomial<NT>, Polynomial<NT>);
@@ -52,11 +50,11 @@ template <class NT> inline Polynomial<NT> gcd_utcf_is_fraction_( const Polynomia
 // is type modularizable 
 template <class NT> inline Polynomial<NT> gcd_utcf_modularizable_algebra_( const Polynomial<NT>&, const Polynomial<NT>&, ::CGAL::Tag_false, Integral_domain_tag);
 template <class NT> inline Polynomial<NT> gcd_utcf_modularizable_algebra_( const Polynomial<NT>&, const Polynomial<NT>&, ::CGAL::Tag_false, Unique_factorization_domain_tag);
-template <class NT> inline Polynomial<NT> gcd_utcf_modularizable_algebra_( const Polynomial<NT>&, const Polynomial<NT>&, ::CGAL::Tag_false, Field_tag);
+template <class NT> inline Polynomial<NT> gcd_utcf_modularizable_algebra_( const Polynomial<NT>&, const Polynomial<NT>&, ::CGAL::Tag_false, Euclidean_ring_tag);
 
 template <class NT> inline Polynomial<NT> gcd_utcf_modularizable_algebra_( const Polynomial<NT>&, const Polynomial<NT>&, ::CGAL::Tag_true, Integral_domain_tag);
 template <class NT> inline Polynomial<NT> gcd_utcf_modularizable_algebra_( const Polynomial<NT>&, const Polynomial<NT>&, ::CGAL::Tag_true, Unique_factorization_domain_tag);
-template <class NT> inline Polynomial<NT> gcd_utcf_modularizable_algebra_( const Polynomial<NT>&, const Polynomial<NT>&, ::CGAL::Tag_true, Field_tag);
+template <class NT> inline Polynomial<NT> gcd_utcf_modularizable_algebra_( const Polynomial<NT>&, const Polynomial<NT>&, ::CGAL::Tag_true, Euclidean_ring_tag);
 
 
 // template <class NT> inline NT content_utcf(const Polynomial<NT>&);
@@ -95,7 +93,7 @@ template< class Coeff >
 struct Simple_matrix;
 
 template<class NT>
-CGALi::Simple_matrix<NT> polynomial_subresultant_matrix(
+internal::Simple_matrix<NT> polynomial_subresultant_matrix(
                                                CGAL::Polynomial<NT> f,
 					       CGAL::Polynomial<NT> g,
 					       int d=0);
@@ -148,7 +146,7 @@ sturm_habicht_sequence_with_cofactors
  OutputIterator2 out_f,
  OutputIterator3 out_fx);
 
-} // namespace CGALi
+} // namespace internal
 
 
 } // namespace CGAL
