@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Polynomial/include/CGAL/Polynomial/polynomial_gcd.h $
-// $Id: polynomial_gcd.h 47254 2008-12-06 21:18:27Z afabri $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Polynomial/include/CGAL/Polynomial/polynomial_gcd.h $
+// $Id: polynomial_gcd.h 55605 2010-04-21 10:05:02Z hemmer $
 //
 //
 // Author(s)     : Arno Eigenwillig <arno@mpi-inf.mpg.de>
@@ -70,7 +70,7 @@
 // see CGAL/Polynomial/polynomial_gcd_ntl.h
 
 namespace CGAL { 
-namespace CGALi {
+namespace internal {
 
 template <class NT> 
 inline
@@ -79,7 +79,7 @@ Polynomial<NT> gcd_(
         const Polynomial<NT>& p2, 
         Field_tag)
 { 
-    return CGAL::CGALi::gcd_utcf(p1,p2);
+    return CGAL::internal::gcd_utcf_(p1,p2);
 }
 
 template <class NT> 
@@ -101,12 +101,12 @@ Polynomial<NT> gcd_(
     POLY p1_ = CGAL::integral_division(p1,ictp(mcont_p1));
     POLY p2_ = CGAL::integral_division(p2,ictp(mcont_p2));
             
-    return CGAL::CGALi::gcd_utcf(p1_, p2_) * ictp(CGAL::gcd(mcont_p1, mcont_p2)); 
+    return CGAL::internal::gcd_utcf_(p1_, p2_) * ictp(CGAL::gcd(mcont_p1, mcont_p2)); 
 }
 
 
 
-// name gcd() forwarded to the CGALi::gcd_() dispatch function
+// name gcd() forwarded to the internal::gcd_() dispatch function
 /*! \ingroup CGAL_Polynomial
  *  \relates CGAL::Polynomial
  *  \brief return the greatest common divisor of \c p1 and \c p2
@@ -115,9 +115,9 @@ Polynomial<NT> gcd_(
  */
 template <class NT> 
 inline
-Polynomial<NT> gcd(const Polynomial<NT>& p1, const Polynomial<NT>& p2)
+Polynomial<NT> gcd_(const Polynomial<NT>& p1, const Polynomial<NT>& p2)
 { 
-    typedef typename CGALi::Innermost_coefficient_type<Polynomial<NT> >::Type IC;
+    typedef typename internal::Innermost_coefficient_type<Polynomial<NT> >::Type IC;
     typedef typename Algebraic_structure_traits<IC>::Algebraic_category Algebraic_category;
 
     // Filter for zero-polynomials
@@ -125,50 +125,17 @@ Polynomial<NT> gcd(const Polynomial<NT>& p1, const Polynomial<NT>& p2)
     	return p2;
     if( p2 == Polynomial<NT>(0) )
     	return p1;
-    return CGALi::gcd_(p1,p2,Algebraic_category());
+    return internal::gcd_(p1,p2,Algebraic_category());
 }
 
-} // namespace CGALi
+} // namespace internal
 
 // 2) gcd_utcf computation
 //     (gcd up to scalar factors, for non-UFD non-field coefficients)
 //     a) first try to decompose the coefficients
 //     b) second dispatch depends on the algebra type of NT
 
-namespace CGALi {
-
-template <class NT> Polynomial<NT> 
-gcd_utcf_(const Polynomial<NT>&, const Polynomial<NT>&);
-
-// is fraction ? 
-template <class NT> Polynomial<NT> 
-gcd_utcf_is_fraction_( const Polynomial<NT>&, const Polynomial<NT>&, 
-        ::CGAL::Tag_true); 
-template <class NT> Polynomial<NT> 
-gcd_utcf_is_fraction_( const Polynomial<NT>&, const Polynomial<NT>&, 
-        ::CGAL::Tag_false);
-
-// is type modularizable 
-template <class NT> Polynomial<NT> 
-gcd_utcf_modularizable_algebra_( const Polynomial<NT>&, const Polynomial<NT>&, 
-        ::CGAL::Tag_false, Integral_domain_tag);
-template <class NT> Polynomial<NT> 
-gcd_utcf_modularizable_algebra_( const Polynomial<NT>&, const Polynomial<NT>&, 
-        ::CGAL::Tag_false, Unique_factorization_domain_tag);
-template <class NT> Polynomial<NT> 
-gcd_utcf_modularizable_algebra_( const Polynomial<NT>&, const Polynomial<NT>&, 
-        ::CGAL::Tag_false, Field_tag);
-
-template <class NT> Polynomial<NT> 
-gcd_utcf_modularizable_algebra_( const Polynomial<NT>&, const Polynomial<NT>&, 
-        ::CGAL::Tag_true, Integral_domain_tag);
-template <class NT> Polynomial<NT> 
-gcd_utcf_modularizable_algebra_( const Polynomial<NT>&, const Polynomial<NT>&, 
-        ::CGAL::Tag_true, Unique_factorization_domain_tag);
-template <class NT> Polynomial<NT> 
-gcd_utcf_modularizable_algebra_( const Polynomial<NT>&, const Polynomial<NT>&, 
-        ::CGAL::Tag_true, Field_tag);
-
+namespace internal {
 
 template <class NT> Polynomial<NT> inline
 gcd_utcf_(const Polynomial<NT>& p1, const Polynomial<NT>& p2){
@@ -195,7 +162,7 @@ gcd_utcf_is_fraction_(
     typename FT::Decompose()(p2,p2i, dummy);
 
     typename Coercion_traits<POLY,typename FT::Numerator_type>::Cast cast;
-    return typename PT::Canonicalize()(cast(CGALi::gcd_utcf(p1i, p2i)));
+    return typename PT::Canonicalize()(cast(internal::gcd_utcf_(p1i, p2i)));
 }
 
 template <class NT> Polynomial<NT> inline
@@ -218,7 +185,7 @@ gcd_utcf_modularizable_algebra_(
         const Polynomial<NT>& p2, 
         ::CGAL::Tag_false, 
         Integral_domain_tag){
-    return CGALi::gcd_utcf_Integral_domain(p1, p2);   
+    return internal::gcd_utcf_Integral_domain(p1, p2);   
 }
 template <class NT> Polynomial<NT> inline
 gcd_utcf_modularizable_algebra_( 
@@ -226,7 +193,7 @@ gcd_utcf_modularizable_algebra_(
         const Polynomial<NT>& p2, 
         ::CGAL::Tag_false, 
         Unique_factorization_domain_tag){
-    return CGALi::gcd_utcf_UFD(p1, p2);   
+    return internal::gcd_utcf_UFD(p1, p2);   
 }
 template <class NT> Polynomial<NT> inline
 gcd_utcf_modularizable_algebra_( 
@@ -234,7 +201,7 @@ gcd_utcf_modularizable_algebra_(
         const Polynomial<NT>& p2, 
         ::CGAL::Tag_false, 
         Euclidean_ring_tag){
-    return CGALi::gcd_Euclidean_ring(p1, p2);
+    return internal::gcd_Euclidean_ring(p1, p2);
 }
 
 #if CGAL_USE_INTERNAL_MODULAR_GCD 
@@ -263,7 +230,7 @@ gcd_utcf_modularizable_algebra_(
         const Polynomial<NT>& p2, 
         ::CGAL::Tag_true, 
         Integral_domain_tag){
-    return CGALi::gcd_utcf_Integral_domain(p1, p2);
+    return internal::gcd_utcf_Integral_domain(p1, p2);
 }
 template <class NT> Polynomial<NT> inline
 gcd_utcf_modularizable_algebra_( 
@@ -271,7 +238,7 @@ gcd_utcf_modularizable_algebra_(
         const Polynomial<NT>& p2, 
         ::CGAL::Tag_true, 
         Unique_factorization_domain_tag){
-    return CGALi::gcd_utcf_UFD(p1, p2);   
+    return internal::gcd_utcf_UFD(p1, p2);   
 }
 #endif
 
@@ -282,21 +249,21 @@ gcd_utcf_modularizable_algebra_(
         ::CGAL::Tag_true, 
         Euclidean_ring_tag){
     // No modular algorithm available
-    return CGALi::gcd_Euclidean_ring(p1, p2);
+    return internal::gcd_Euclidean_ring(p1, p2);
 }
 
 template <class NT> Polynomial<NT> inline
 gcd_utcf(const Polynomial<NT>& p1, const Polynomial<NT>& p2){
-    return CGALi::gcd_utcf_(p1,p2);
+    return internal::gcd_utcf_(p1,p2);
 }
 
-} // namespace CGALi 
+} // namespace internal 
 
 
 // 3) extended gcd computation (with cofactors)
 //     with dispatch similar to gcd
 
-namespace CGALi {
+namespace internal {
 
 template <class NT> 
 inline
@@ -307,7 +274,7 @@ Polynomial<NT> gcdex_(
 ) {
     typedef typename Algebraic_structure_traits<NT>::Algebraic_category Algebraic_category;
     return gcdex_(x, y, xf, yf, Algebraic_category());
-};
+}
 
 template <class NT>
 inline
@@ -427,9 +394,9 @@ Polynomial<NT> gcdex_(
     xf.simplify_coefficients();
     yf.simplify_coefficients();
     return v;
-};
+}
 
-} // namespace CGALi
+} // namespace internal
 
 /*! \ingroup CGAL_Polynomial
  *  \relates CGAL::Polynomial
@@ -460,8 +427,8 @@ Polynomial<NT> gcdex(
 ) {
     typedef typename CGAL::Fraction_traits< Polynomial<NT> >
         ::Is_fraction Is_fraction;
-    return CGALi::gcdex_(p1, p2, f1, f2, Is_fraction());
-};
+    return internal::gcdex_(p1, p2, f1, f2, Is_fraction());
+}
 
 
 /*! \ingroup CGAL_Polynomial
@@ -547,7 +514,7 @@ Polynomial<NT> pseudo_gcdex(
          * gcdex(..., Field_tag) apply analogously.
          */
         g = u.lcoeff();
-        CGAL::CGALi::hgdelta_update(h, g, delta);
+        CGAL::internal::hgdelta_update(h, g, delta);
         if (r.degree() == 0) break;
     }
 
