@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Algebraic_kernel_for_circles/include/CGAL/Polynomials_1_2.h $
-// $Id: Polynomials_1_2.h 33727 2006-08-25 09:02:22Z pmachado $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Algebraic_kernel_for_circles/include/CGAL/Polynomials_2_2.h $
+// $Id: Polynomials_2_2.h 33727 2006-08-25 09:02:22Z pmachado $
 //
 // Author(s)     : Monique Teillaud, Sylvain Pion
 
@@ -22,51 +22,54 @@
 // and a STREP (FET Open) Project under Contract No  IST-006413 
 // (ACS -- Algorithms for Complex Shapes)
 
-#ifndef CGAL_ALGEBRAIC_KERNEL_FOR_CIRCLES_POLYNOMIALS_1_2_H
-#define CGAL_ALGEBRAIC_KERNEL_FOR_CIRCLES_POLYNOMIALS_1_2_H
+#ifndef CGAL_ALGEBRAIC_KERNEL_FOR_CIRCLES_POLYNOMIALS_2_2_H
+#define CGAL_ALGEBRAIC_KERNEL_FOR_CIRCLES_POLYNOMIALS_2_2_H
+
+//////////// FIXME - pb RT (cas general Polynomial_2_2) ou FT (ici)
 
 #include <CGAL/enum.h>
 
 CGAL_BEGIN_NAMESPACE
 
-template < typename RT_ >
-class Polynomial_1_2
+// polynomials of the form (X-a)^2 + (Y-b)^2 - R^2
+template < typename FT_ >
+class Polynomial_for_circles_2_2
 {
-  RT_ rep[3]; // stores a, b, c for line ax+by+c=0
+  FT_ rep[3]; // stores a, b, R^2
   
 public:
   
-  typedef RT_ RT;
+  typedef FT_ FT;
   
-  Polynomial_1_2(){}
+  Polynomial_for_circles_2_2(){}
   
-  Polynomial_1_2(const RT & a, const RT & b, const RT & c)
+  Polynomial_for_circles_2_2(const FT & a, const FT & b, const FT & rsq)
   { 
     rep[0]=a;
     rep[1]=b;
-    rep[2]=c;
+    rep[2]=rsq;
   }
 
-  const RT & a() const
+  const FT & a() const
   { return rep[0]; }
 
-  const RT & b() const
+  const FT & b() const
   { return rep[1]; }
-
-  const RT & c() const
+  
+  const FT & r_sq() const
   { return rep[2]; }
 };
 
-template < typename RT >
+template < typename FT >
 bool 
-operator == ( const Polynomial_1_2<RT> & p1,
-	      const Polynomial_1_2<RT> & p2 )
+operator == ( const Polynomial_for_circles_2_2<FT> & p1,
+	      const Polynomial_for_circles_2_2<FT> & p2 )
 {
   return( (p1.a() == p2.a()) && 
               (p1.b() == p2.b()) &&
-              (p1.c() == p2.c()) );
+              (p1.r_sq() == p2.r_sq()) );
 }
-    
+
 CGAL_END_NAMESPACE
 
-#endif //CGAL_ALGEBRAIC_KERNEL_FOR_CIRCLES_POLYNOMIALS_1_2_H
+#endif //CGAL_ALGEBRAIC_KERNEL_FOR_CIRCLES_POLYNOMIALS_2_2_H
