@@ -15,8 +15,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Intersections_2/include/CGAL/Ray_2_Line_2_intersection.h $
-// $Id: Ray_2_Line_2_intersection.h 45075 2008-08-21 12:50:41Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Intersections_2/include/CGAL/Ray_2_Line_2_intersection.h $
+// $Id: Ray_2_Line_2_intersection.h 51456 2009-08-24 17:10:04Z spion $
 // 
 //
 // Author(s)     : Geert-Jan Giezeman
@@ -35,7 +35,7 @@
 
 CGAL_BEGIN_NAMESPACE
 
-namespace CGALi {
+namespace internal {
 
 template <class K>
 class Ray_2_Line_2_pair {
@@ -96,7 +96,7 @@ intersection(const typename K::Line_2 &line,
 	     const typename K::Ray_2 &ray,
 	     const K& k)
 {
-  return CGALi::intersection(ray, line, k);
+  return internal::intersection(ray, line, k);
 }
 
 
@@ -160,7 +160,7 @@ Ray_2_Line_2_pair<K>::intersection_ray() const
     return *_ray;
 }
 
-} // namespace CGALi
+} // namespace internal
 
 template <class K>
 inline bool do_intersect(const Line_2<K> &p1, const Ray_2<K> &p2)
