@@ -15,8 +15,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Intersections_2/include/CGAL/Ray_2_Triangle_2_intersection.h $
-// $Id: Ray_2_Triangle_2_intersection.h 45046 2008-08-20 13:49:31Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Intersections_2/include/CGAL/Ray_2_Triangle_2_intersection.h $
+// $Id: Ray_2_Triangle_2_intersection.h 51456 2009-08-24 17:10:04Z spion $
 // 
 //
 // Author(s)     : Geert-Jan Giezeman
@@ -40,7 +40,7 @@
 
 CGAL_BEGIN_NAMESPACE
 
-namespace CGALi {
+namespace internal {
 
 template <class K>
 class Ray_2_Triangle_2_pair {
@@ -169,7 +169,7 @@ intersection(const typename K::Triangle_2&tr,
 	     const typename K::Ray_2 &ray, 
 	     const K& k)
 {
-  return CGALi::intersection(ray, tr, k);
+  return internal::intersection(ray, tr, k);
 }
 
 
@@ -197,7 +197,7 @@ inline bool do_intersect(
     return pair.intersection_type() != pair_t::NO_INTERSECTION;
 }
 
-} // namespace CGALi
+} // namespace internal
 
 
 template <class K>
