@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Segment_Delaunay_graph_2/include/CGAL/Segment_Delaunay_graph_2/Segment_Delaunay_graph_hierarchy_2_impl.h $
-// $Id: Segment_Delaunay_graph_hierarchy_2_impl.h 48908 2009-04-26 14:03:12Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Segment_Delaunay_graph_2/include/CGAL/Segment_Delaunay_graph_2/Segment_Delaunay_graph_hierarchy_2_impl.h $
+// $Id: Segment_Delaunay_graph_hierarchy_2_impl.h 53904 2010-01-29 14:23:34Z lrineau $
 // 
 //
 // Author(s)     : Menelaos Karavelas <mkaravel@cse.nd.edu>
@@ -48,7 +48,7 @@ init_hierarchy(const Geom_traits& gt)
 template<class Gt, class ST, class STag, class D_S, class LTag>
 Segment_Delaunay_graph_hierarchy_2<Gt,ST,STag,D_S,LTag>::
 Segment_Delaunay_graph_hierarchy_2(const Gt& gt)
-  : Base(gt), random((long)0)
+  : Base(gt)
 { 
   init_hierarchy(gt);
 }
@@ -59,7 +59,7 @@ template<class Gt, class ST, class STag, class D_S, class LTag>
 Segment_Delaunay_graph_hierarchy_2<Gt,ST,STag,D_S,LTag>::
 Segment_Delaunay_graph_hierarchy_2
 (const Segment_Delaunay_graph_hierarchy_2<Gt,ST,STag,D_S,LTag> &sdg)
-    : Base(sdg.geom_traits()), random((long)0)
+    : Base(sdg.geom_traits())
 { 
   // create an empty triangulation to be able to delete it !
   init_hierarchy(sdg.geom_traits());
