@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Segment_Delaunay_graph_2/include/CGAL/Segment_Delaunay_graph_2/edge_list.h $
-// $Id: edge_list.h 28567 2006-02-16 14:30:13Z lsaboret $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Segment_Delaunay_graph_2/include/CGAL/Segment_Delaunay_graph_2/edge_list.h $
+// $Id: edge_list.h 51456 2009-08-24 17:10:04Z spion $
 // 
 //
 // Author(s)     : Menelaos Karavelas <mkaravel@cse.nd.edu>
@@ -28,7 +28,7 @@
 CGAL_BEGIN_NAMESPACE
 
 
-namespace CGALi {
+namespace internal {
 
   template<class Edge_t>
   class Edge_list_item
@@ -184,7 +184,7 @@ namespace CGALi {
   };
 
 
-} // namespace CGALi
+} // namespace internal
 
 
 
@@ -199,10 +199,10 @@ public:
   typedef USE_STL_MAP_Tag   Use_stl_map_tag;
 
 private:
-  typedef CGALi::Edge_list_item<Edge>  List_item;
+  typedef internal::Edge_list_item<Edge>  List_item;
 
   typedef
-  CGALi::Edge_list_which_map<Edge,List_item,Use_stl_map_tag>
+  internal::Edge_list_which_map<Edge,List_item,Use_stl_map_tag>
   Which_map;
 
   typedef typename Which_map::Edge_map  Edge_map;
@@ -210,7 +210,7 @@ private:
   typedef Edge_list<Edge,Use_stl_map_tag>  Self;
 
 public:
-  typedef CGALi::Edge_list_circulator<Self>  circulator;
+  typedef internal::Edge_list_circulator<Self>  circulator;
 
 private:
   // PRIVATE DATA MEMBERS
