@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Circular_kernel_3/include/CGAL/Simple_spherical_kernel_3.h $
-// $Id: Simple_spherical_kernel_3.h 50731 2009-07-21 09:08:07Z sloriot $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Circular_kernel_3/include/CGAL/Simple_spherical_kernel_3.h $
+// $Id: Simple_spherical_kernel_3.h 51456 2009-08-24 17:10:04Z spion $
 //
 // Author(s) : Monique Teillaud, Sylvain Pion, Pedro Machado, 
 //             Sebastien Loriot, Julien Hazebrouck, Damien Leroy
@@ -42,17 +42,17 @@
 #include <CGAL/global_functions_spherical_kernel_3.h>
 
 namespace CGAL {
-  namespace CGALi {
+  namespace internal {
     
     template < class SphericalKernel, class LinearKernelBase >
       struct Spherical_kernel_base_no_ref_count: public LinearKernelBase
 				 // takes classes in internal sub-namespace
       {
-        typedef CGALi::Circular_arc_point_3<SphericalKernel>                        Circular_arc_point_3;
-        typedef CGALi::Line_arc_3<SphericalKernel>                                  Line_arc_3;
-        typedef CGALi::Circular_arc_3<SphericalKernel>                              Circular_arc_3;
+        typedef internal::Circular_arc_point_3<SphericalKernel>                        Circular_arc_point_3;
+        typedef internal::Line_arc_3<SphericalKernel>                                  Line_arc_3;
+        typedef internal::Circular_arc_3<SphericalKernel>                              Circular_arc_3;
        
-        // The mecanism that allows to specify reference-counting or not.
+        // The mechanism that allows to specify reference-counting or not.
         template < typename T >
         struct Handle { typedef T    type; };
 
@@ -70,14 +70,14 @@ namespace CGAL {
         #include <CGAL/Circular_kernel_3/interface_macros.h>
       };
     
-  } // namespace CGALi
+  } // namespace internal
 
   template < class LinearKernel, class AlgebraicKernel >
     struct Simple_spherical_kernel_3
     :  // there should be a derivation from
   // LinearKernel::Kernel_base<Self> to have types equalities for
   // the Linearkernel types
-  public Spherical_kernel_type_equality_wrapper<CGALi::Spherical_kernel_base_no_ref_count<Simple_spherical_kernel_3<LinearKernel,AlgebraicKernel>,
+  public Spherical_kernel_type_equality_wrapper<internal::Spherical_kernel_base_no_ref_count<Simple_spherical_kernel_3<LinearKernel,AlgebraicKernel>,
     typename LinearKernel:: template Base<Simple_spherical_kernel_3<LinearKernel,AlgebraicKernel> >::Type >,
     Simple_spherical_kernel_3<LinearKernel,AlgebraicKernel> >
     {
