@@ -10,8 +10,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Straight_skeleton_2/include/CGAL/Straight_skeleton_2/Straight_skeleton_aux.h $
-// $Id: Straight_skeleton_aux.h 40295 2007-09-10 14:07:00Z fcacciola $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Straight_skeleton_2/include/CGAL/Straight_skeleton_2/Straight_skeleton_aux.h $
+// $Id: Straight_skeleton_aux.h 54007 2010-02-03 13:46:31Z fcacciola $
 //
 // Author(s)     : Fernando Cacciola <fernando_cacciola@ciudad.com.ar>
 //
@@ -20,6 +20,9 @@
 
 #include <boost/optional/optional.hpp>
 #include <boost/none.hpp>
+#include <boost/type_traits/is_same.hpp>
+#include <boost/mpl/if.hpp>
+#include <boost/mpl/or.hpp>
 
 #include <CGAL/Straight_skeleton_2/assertions.h>
 #include <CGAL/Straight_skeleton_2/debug.h>
@@ -33,6 +36,17 @@ CGAL_BEGIN_NAMESPACE
 namespace CGAL_SS_i
 {
 
+template<class K> struct Has_inexact_constructions
+{ 
+  typedef typename K::FT FT ;
+  
+  typedef typename boost::mpl::if_< boost::mpl::or_< boost::is_same<FT,double>
+                                                   , boost::is_same<FT,Interval_nt_advanced>
+                                                   > 
+                                  , Tag_true
+                                  , Tag_false
+                                  >::type type ; 
+} ;
 
 //
 // This record encapsulates the defining contour halfedges for a node (both contour and skeleton)
@@ -51,8 +65,8 @@ public:
   // Contour nodes (input polygon vertices) have only 2 defining contour edges    
   Triedge ( Handle aE0, Handle aE1 )
   {
-    mE[0] = aE0 ;
-    mE[1] = aE1 ;
+    mE[0] = aE0 ; 
+    mE[1] = aE1 ; 
     // mE[2] gets default constructed, i.e., "null".
   }              
   
@@ -70,30 +84,20 @@ public:
   Handle e1() const { return e(1); }
   Handle e2() const { return e(2); }
   
-  bool is_valid() const 
-  { 
-    return    handle_assigned(e0())
-           && handle_assigned(e1())
-           && e0() != e1() && e1() != e2() ; 
-  }
+  bool is_valid() const { return handle_assigned(e0()) && handle_assigned(e1()); }
   
   bool is_contour () const { return !handle_assigned(e2()) ; }
   bool is_skeleton() const { return  handle_assigned(e2()) ; }
   
-  // returns 1 if aE is one of the halfedges stored in this triedge, 0 otherwise.
-  int contains ( Handle aE ) const
-  {
-    return aE == e0() || aE == e1() || aE == e2() ? 1 : 0 ;
-  }
+  bool is_contour_terminal() const { return e0() == e1() ; }
   
-  // Returns the number of common halfedges in the two triedges x and y
-  static int CountInCommon( Self const& x, Self const& y )
-  {
-    return x.contains(y.e0()) + x.contains(y.e1()) + x.contains(y.e2()) ; 
-  }
+  bool is_skeleton_terminal() const { return e0() == e1() || e1() == e2() ; }
   
   // Returns true if the triedges store the same 3 halfedges (in any order)
-  friend bool operator == ( Self const& x, Self const& y ) { return CountInCommon(x,y) == 3 ; }
+  friend bool operator == ( Self const& x, Self const& y ) 
+  { 
+    return x.number_of_unique_edges() == y.number_of_unique_edges() && CountInCommon(x,y) == x.number_of_unique_edges() ; 
+  }
   
   friend bool operator != ( Self const& x, Self const& y ) { return !(x==y) ; }
   
@@ -102,13 +106,6 @@ public:
     return Self(x.e0(), x.e1(), ( x.e0() == y.e0() || x.e1() == y.e0() ) ? y.e1() : y.e0()  ) ;
   }
   
-  static void insert_handle_id( std::ostream& ss, Handle aH )
-  {  
-    if ( handle_assigned(aH) )
-         ss << aH->id() ;
-    else ss << "#" ;
-  }
-  
   friend std::ostream& operator<< ( std::ostream& ss, Self const& t )
   {
     ss << "{E" ;
@@ -123,10 +120,46 @@ public:
   
 private:
   
+  static void insert_handle_id( std::ostream& ss, Handle aH )
+  {  
+    if ( handle_assigned(aH) )
+         ss << aH->id() ;
+    else ss << "#" ;
+  }
+  
+  // returns 1 if aE is one of the halfedges stored in this triedge, 0 otherwise.
+  int contains ( Handle aE ) const
+  {
+    return aE == e0() || aE == e1() || aE == e2() ? 1 : 0 ;
+  }
+  
+  int number_of_unique_edges() const
+  { 
+    return is_contour() ? ( is_contour_terminal() ? 1 : 2 ) : ( is_skeleton_terminal() ? 2 : 3 ) ;
+  }
+  
+  // Returns the number of common halfedges in the two triedges x and y
+  static int CountInCommon( Self const& x, Self const& y )
+  {
+    Handle lE[3];
 
+    int lC = 1 ;
+
+    lE[0] = y.e0();
+
+    if ( y.e0() != y.e1() )
+      lE[lC++] = y.e1();
+
+    if ( y.e0() != y.e2() && y.e1() != y.e2() )
+       lE[lC++] = y.e2();
+
+    return x.contains(lE[0]) + x.contains(lE[1]) + ( lC > 2 ? x.contains(lE[2]) : 0 ) ;
+  }
+  
   Handle mE[3];
 } ;
 
+
 } // namespace CGAL_SS_i
 
 enum Trisegment_collinearity
@@ -151,7 +184,7 @@ static char const* trisegment_collinearity_to_string( Trisegment_collinearity c
   
   return "!!UNKNOWN COLLINEARITY!!" ;
 }
-namespace CGALi 
+namespace internal 
 {
 
 template <>
