@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Arrangement_on_surface_2/include/CGAL/Sweep_line_2/Arr_overlay_traits_2.h $
-// $Id: Arr_overlay_traits_2.h 50366 2009-07-05 12:56:48Z efif $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Arrangement_on_surface_2/include/CGAL/Sweep_line_2/Arr_overlay_traits_2.h $
+// $Id: Arr_overlay_traits_2.h 51984 2009-09-20 16:18:10Z efif $
 // 
 //
 // Author(s)     : Baruch Zukerman <baruchzu@post.tau.ac.il>
@@ -77,14 +77,14 @@ public:
   typedef typename Traits_2::Split_2                Base_split_2;
   typedef typename Traits_2::Equal_2                Base_equal_2;
 
-  typedef typename CGALi::Arr_complete_left_side_tag< Traits_2 >::Tag
-                                                    Arr_left_side_tag;
-  typedef typename CGALi::Arr_complete_bottom_side_tag< Traits_2 >::Tag
-                                                    Arr_bottom_side_tag;
-  typedef typename CGALi::Arr_complete_top_side_tag< Traits_2 >::Tag
-                                                    Arr_top_side_tag;
-  typedef typename CGALi::Arr_complete_right_side_tag< Traits_2 >::Tag
-                                                    Arr_right_side_tag;
+  typedef typename internal::Arr_complete_left_side_tag< Traits_2 >::Tag
+                                                    Arr_left_side_category;
+  typedef typename internal::Arr_complete_bottom_side_tag< Traits_2 >::Tag
+                                                    Arr_bottom_side_category;
+  typedef typename internal::Arr_complete_top_side_tag< Traits_2 >::Tag
+                                                    Arr_top_side_category;
+  typedef typename internal::Arr_complete_right_side_tag< Traits_2 >::Tag
+                                                    Arr_right_side_category;
 
   /* Overlay is implemented as sweep-line visitor. The sweep-line algorithm
    * never uses Compare_y_at_x_left_2, and it never performs merging of curves.
