@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Arrangement_on_surface_2/include/CGAL/Sweep_line_2/Sweep_line_event.h $
-// $Id: Sweep_line_event.h 50366 2009-07-05 12:56:48Z efif $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Arrangement_on_surface_2/include/CGAL/Sweep_line_2/Sweep_line_event.h $
+// $Id: Sweep_line_event.h 51984 2009-09-20 16:18:10Z efif $
 // 
 //
 // Author(s)     : Tali Zvi        <talizvi@post.tau.ac.il>,
@@ -58,14 +58,14 @@ public:
   typedef typename Traits_2::Point_2                    Point_2;
 
   // should be ok, as Traits_ has already extended by Basic_sweep_line
-  typedef typename CGALi::Arr_complete_left_side_tag< Traits_2 >::Tag
-                                                        Arr_left_side_tag;
-  typedef typename CGALi::Arr_complete_bottom_side_tag< Traits_2 >::Tag
-                                                        Arr_bottom_side_tag;
-  typedef typename CGALi::Arr_complete_top_side_tag< Traits_2 >::Tag
-                                                        Arr_top_side_tag;
-  typedef typename CGALi::Arr_complete_right_side_tag< Traits_2 >::Tag
-                                                        Arr_right_side_tag;
+  typedef typename internal::Arr_complete_left_side_tag< Traits_2 >::Tag
+                                                        Arr_left_side_category;
+  typedef typename internal::Arr_complete_bottom_side_tag< Traits_2 >::Tag
+                                                        Arr_bottom_side_category;
+  typedef typename internal::Arr_complete_top_side_tag< Traits_2 >::Tag
+                                                        Arr_top_side_category;
+  typedef typename internal::Arr_complete_right_side_tag< Traits_2 >::Tag
+                                                        Arr_right_side_category;
 
   typedef Subcurve_                                     Subcurve;
   //template<typename SC>
