@@ -11,14 +11,14 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.3-branch/SearchStructures/include/CGAL/Tree_base.h $
-// $Id: Tree_base.h 28567 2006-02-16 14:30:13Z lsaboret $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/SearchStructures/include/CGAL/Tree_base.h $
+// $Id: Tree_base.h 41371 2007-12-30 16:55:25Z spion $
 // 
 //
 // Author(s)     : Gabriele Neyer
 
-#ifndef __CGAL_Tree_base_d__
-#define __CGAL_Tree_base_d__
+#ifndef CGAL_TREE_BASE_H
+#define CGAL_TREE_BASE_H
 
 #include <iterator>
 #include <iostream>
@@ -28,46 +28,25 @@
 #include <CGAL/assertions.h>
 #include <CGAL/Tree_assertions.h>
 
-#ifndef  USE_ARGUMENT
-#define  USE_ARGUMENT( X )  (void)(X);
-#endif  
-#ifndef  USE_VARIABLE
-#define  USE_VARIABLE( X )  (void)(&(X));
-#endif  
-
 #ifndef TREE_BASE_NULL
 #define TREE_BASE_NULL 0
 #endif
 
-#ifndef CGAL__static_cast
-#define CGAL__static_cast(TYPE,EXPR) (TYPE)(EXPR)
-#endif
-
-#ifndef CGAL__const_cast
-#define CGAL__const_cast(TYPE,EXPR) (TYPE)(EXPR)
-#endif
-
-#ifndef CGAL__reinterpret_cast
-#define CGAL__reinterpret_cast(TYPE,EXPR) (TYPE)(EXPR)
-#endif
-
-
 #define stlvector
 
 CGAL_BEGIN_NAMESPACE
 
-
-
 //link type definition of an ordinary vertex of the tree
+template < typename Node >
 struct Tree_node_base {
-  void *parent_link;
-  void *left_link;
-  void *right_link;
+  Node *parent_link;
+  Node *left_link;
+  Node *right_link;
   Tree_node_base()
-    :parent_link(0), left_link(0), right_link(0)
+    : parent_link(0), left_link(0), right_link(0)
   {}
-  Tree_node_base(void* ll, void* rl)
-    :parent_link(0), left_link(ll), right_link(rl)
+  Tree_node_base(Node* ll, Node* rl)
+    : parent_link(0), left_link(ll), right_link(rl)
   {}
 };
 
@@ -170,96 +149,74 @@ public:
   typedef Tree_base<C_Data, C_Window> tbt;
 //  Tree_base_type *clone() const { return new Tree_anchor(); }
 
-  bool make_tree(const typename std::list< C_Data>::iterator& beg, 
-		 const typename std::list< C_Data>::iterator& end, 
+  bool make_tree(const typename std::list< C_Data>::iterator& /*beg*/, 
+		 const typename std::list< C_Data>::iterator& /*end*/, 
 		 typename tbt::lit * =0) 
   {
-    USE_ARGUMENT(beg);
-    USE_ARGUMENT(end);
     return true;
   }
 #ifdef stlvector
-  bool make_tree(const typename std::vector< C_Data>::iterator& beg, 
-		 const typename std::vector< C_Data>::iterator& end, 
+  bool make_tree(const typename std::vector< C_Data>::iterator& /*beg*/, 
+		 const typename std::vector< C_Data>::iterator& /*end*/, 
 		 typename tbt::vit * =0) 
   {
-    USE_ARGUMENT(beg);
-    USE_ARGUMENT(end);
     return true;
   }
 #endif
 #ifdef carray
-  bool make_tree(const  C_Data *beg, 
-                 const  C_Data *end) 
+  bool make_tree(const C_Data * /*beg*/, 
+                 const C_Data * /*end*/) 
   {
-    USE_ARGUMENT(beg);
-    USE_ARGUMENT(end);
     return true;
   }
 #endif
    std::back_insert_iterator< std::list< C_Data> > 
       window_query( 
-       C_Window const &win, 
+       C_Window const &, 
        std::back_insert_iterator< std::list< C_Data> > out,
        typename tbt::lbit * =0){
-    USE_ARGUMENT(win);
-    USE_ARGUMENT(out);
     return out;
   }
    
   std::back_insert_iterator< std::vector< C_Data> >  
-      window_query( C_Window const &win, 
+      window_query( C_Window const &, 
 		    std::back_insert_iterator< std::vector< C_Data> > out, 
                     typename tbt::vbit * =0){
-    USE_ARGUMENT(win);
-    USE_ARGUMENT(out);
     return out;
   }
 #ifdef carray
-   C_Data * window_query( C_Window const &win, 
+   C_Data * window_query( C_Window const &, 
                      C_Data * out){
-    USE_ARGUMENT(win);
-    USE_ARGUMENT(out);
     return out;
   }
 #endif
 #ifdef ostreamiterator
-   std::ostream_iterator< C_Data> window_query( C_Window const &win, 
+   std::ostream_iterator< C_Data> window_query( C_Window const &,
 				        std::ostream_iterator< C_Data> out, 
 					typename tbt::oit *dummy=0){
-    USE_ARGUMENT(win);
-    USE_ARGUMENT(out);
     return out;
   }
 #endif
-   std::back_insert_iterator< std::list< C_Data> > enclosing_query( C_Window const &win, 
+   std::back_insert_iterator< std::list< C_Data> > enclosing_query( C_Window const &,
                                    std::back_insert_iterator< std::list< C_Data> > out,
 				   typename tbt::lbit * =0){
-    USE_ARGUMENT(win);
-    USE_ARGUMENT(out);
     return out;
   }
-   std::back_insert_iterator< std::vector< C_Data> > enclosing_query( C_Window const &win, 
+   std::back_insert_iterator< std::vector< C_Data> > enclosing_query( C_Window const &,
                                    std::back_insert_iterator< std::vector< C_Data> > out,
 				   typename tbt::vbit * =0){
-    USE_ARGUMENT(win);
-    USE_ARGUMENT(out); 
     return out;
   }
 #ifdef carray
-   C_Data * enclosing_query( C_Window const &win, 
+   C_Data * enclosing_query( C_Window const &, 
                         C_Data * out){
-    USE_ARGUMENT(win);
-    USE_ARGUMENT(out);
     return out;
   }
 #endif
 #ifdef ostreamiterator
-   std::ostream_iterator< C_Data> enclosing_query( C_Window const &win, 
+   std::ostream_iterator< C_Data> enclosing_query( C_Window const &, 
 					   std::ostream_iterator< C_Data> out,
                                            typename tbt::oit *dummy=0){
-    USE_ARGUMENT(win);
-    USE_ARGUMENT(out);
     return out;
   }
 #endif
@@ -267,11 +224,9 @@ public:
 
 protected:
 
-  bool is_inside( C_Window const &win, 
-		  C_Data const& object) const
+  bool is_inside( C_Window const &, 
+		  C_Data const&) const
   {     
-    USE_ARGUMENT(win);
-    USE_ARGUMENT(object);
     return true;
   }
   bool is_anchor()const {return true;}
