@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.3-branch/Triangulation_2/include/CGAL/Triangulation_ds_iterators_2.h $
-// $Id: Triangulation_ds_iterators_2.h 28567 2006-02-16 14:30:13Z lsaboret $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Triangulation_2/include/CGAL/Triangulation_ds_iterators_2.h $
+// $Id: Triangulation_ds_iterators_2.h 48844 2009-04-21 18:28:04Z spion $
 // 
 //
 // Author(s)     : Mariette Yvinec
@@ -22,7 +22,6 @@
 
 #include <iterator>
 #include <CGAL/triangulation_assertions.h>
-#include <CGAL/Triangulation_short_names_2.h>
 //#include <CGAL/Triangulation_iterator_adaptator.h>
 
 CGAL_BEGIN_NAMESPACE
@@ -79,12 +78,12 @@ Triangulation_ds_edge_iterator_2(const Tds * tds)
 {
   edge.second = 0;
   if (_tds->dimension()<= 0) {
-    pos = _tds->face_container().end();       // there is no edge
+    pos = _tds->faces().end();       // there is no edge
     return;
   }
-  pos = _tds->face_container().begin();
+  pos = _tds->faces().begin();
   if (_tds->dimension() == 1) edge.second = 2;
-    while ( pos != _tds->face_container().end()  
+    while ( pos != _tds->faces().end()  
 	  && !associated_edge() ) increment();
 }
 
@@ -93,7 +92,7 @@ Triangulation_ds_edge_iterator_2<Tds> ::
 Triangulation_ds_edge_iterator_2(const Tds * tds, int )
   : _tds(tds) 
 {
-  pos = tds->face_container().end();
+  pos = tds->faces().end();
   edge.second = 0;
   if (_tds->dimension() == 1) {edge.second = 2;}
 }
@@ -151,9 +150,9 @@ Triangulation_ds_edge_iterator_2<Tds> ::
 operator++()
 {
   //CGAL_triangulation_precondition(pos != Iterator_base() && 
-  //			       pos != _tds->face_container().end());
+  //			       pos != _tds->faces().end());
   do     increment();
-  while( pos != _tds->face_container().end() && !associated_edge());
+  while( pos != _tds->faces().end() && !associated_edge());
   return *this;
 }
     
