@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Principal_component_analysis/include/CGAL/bounding_box.h $
-// $Id: bounding_box.h 42946 2008-04-17 20:53:36Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Principal_component_analysis/include/CGAL/bounding_box.h $
+// $Id: bounding_box.h 51456 2009-08-24 17:10:04Z spion $
 // 
 //
 // Author(s)     : Sylvain Pion
@@ -33,7 +33,7 @@ CGAL_BEGIN_NAMESPACE
 // - Generalize to d-dimension.
 // - Maybe the internal code itself could be factorized across dimensions...
 
-namespace CGALi {
+namespace internal {
 
 // internal functions specialized by dimension.
 
@@ -130,7 +130,7 @@ typename Access::Iso_box<K, typename Ambient_dimension<typename std::iterator_tr
 bounding_box(ForwardIterator f, ForwardIterator l, const K& k)
 {
   typedef typename std::iterator_traits< ForwardIterator >::value_type Pt;
-  return CGALi::bounding_box(f, l, k, typename Ambient_dimension<Pt>::type() );
+  return internal::bounding_box(f, l, k, typename Ambient_dimension<Pt>::type() );
 }
 
 template < class ForwardIterator >
