@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Principal_component_analysis/include/CGAL/centroid.h $
-// $Id: centroid.h 42952 2008-04-18 10:09:45Z palliez $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Principal_component_analysis/include/CGAL/centroid.h $
+// $Id: centroid.h 56724 2010-06-14 07:01:34Z stayeb $
 // 
 //
 // Author(s)     : Sylvain Pion
@@ -41,7 +41,7 @@
 
 CGAL_BEGIN_NAMESPACE
 
-namespace CGALi {
+namespace internal {
 
 //:::::::::: 2D Objects :::::::::::::::::::
 
@@ -793,7 +793,7 @@ centroid(InputIterator begin,
   return ORIGIN + v / sum_volumes;
 } // end centroid of a 3D Tetrahedron set with 3D tag
 
-} // namespace CGALi
+} // namespace internal
 
 
 // We have 4 documented overloads of centroid():
@@ -803,26 +803,53 @@ centroid(InputIterator begin,
 // centroid(begin, end, kernel, dim_tag)
 
 // One issue is that it is difficult to separate the 2 overloads with 3 arguments.
-// So we have to resort to an internal CGALi dispatcher hack.
+// So we have to resort to an internal internal dispatcher hack.
 // ( Note : Dynamic_dimension_tag is not yet supported, but shouldn't be too hard. )
 
 // computes the centroid of a set of kernel objects
 // takes an iterator range over kernel objects
-template < typename InputIterator, 
-           typename K, 
-           typename Dim_tag  >
-inline
-typename Access::Point<K, typename Ambient_dimension<typename std::iterator_traits<InputIterator>::value_type, K>::type>::type
-centroid(InputIterator begin,
-         InputIterator end, 
-         const K& k,
-         Dim_tag tag)
+
+namespace internal {
+  
+template < typename InputIterator, typename K, typename Dim_tag >
+struct Dispatch_centroid_3
 {
-  typedef typename std::iterator_traits<InputIterator>::value_type Value_type;
-  return CGALi::centroid(begin, end, k,(Value_type*) NULL, tag);
+  typedef typename Access::Point<K, typename Ambient_dimension<typename std::iterator_traits<InputIterator>::value_type, K>::type>::type result_type;
+  
+  result_type operator()(InputIterator begin, InputIterator end, const K& k, Dim_tag tag) const
+  {
+    typedef typename std::iterator_traits<InputIterator>::value_type Value_type;
+    return centroid(begin, end, k,(Value_type*) NULL, tag);
+  }
+};
+
+#if defined(_MSC_VER) || defined (__INTEL_COMPILER)
+  // Workaround for VC++ and Intel compiler
+  // (avoids wrong template function instanciation)
+  template <typename K>
+  struct Dispatch_centroid_3<Point_3<K>, Point_3<K>, Dynamic_dimension_tag >
+  {
+    typedef void result_type;
+  };
+#endif
+  
+} // namespace internal
+
+template < typename InputIterator, typename K>
+typename internal::Dispatch_centroid_3<InputIterator,K,Dynamic_dimension_tag>::result_type
+centroid(InputIterator begin, InputIterator end, const K& k, Dynamic_dimension_tag tag)
+{
+  return internal::Dispatch_centroid_3<InputIterator,K,Dynamic_dimension_tag>()(begin,end,k,tag);
 }
 
-namespace CGALi {
+template < typename InputIterator, typename K, int d >
+typename internal::Dispatch_centroid_3<InputIterator,K,Dimension_tag<d> >::result_type
+centroid(InputIterator begin, InputIterator end, const K& k, Dimension_tag<d> tag)
+{
+  return internal::Dispatch_centroid_3<InputIterator,K,Dimension_tag<d> >()(begin,end,k,tag);
+}
+
+namespace internal {
 
 // computes the centroid of a set of kernel objects
 // takes an iterator range over kernel objects, and a feature dimension tag.
@@ -839,6 +866,14 @@ struct Dispatch_centroid
   }
 };
 
+// Avoids wrong matching with
+// CGAL::centroid(Point_3<K>, Point_3<K>, Point_3<K>)
+template < typename K >
+struct Dispatch_centroid < Point_3<K>, Point_3<K> >
+{
+  typedef void result_type;
+};
+
 // this one takes an iterator range over kernel objects, and a dimension tag,
 // and uses Kernel_traits<> to find out its kernel.
 template < typename InputIterator, int dim >
@@ -873,16 +908,16 @@ struct Dispatch_centroid <InputIterator, Dynamic_dimension_tag>
   }
 };
 
-} // namespace CGALi
+} // namespace internal
 
 
 // The 3 argument overload calls the internal dispatcher.
 template < typename InputIterator, typename Kernel_or_dim >
 inline
-typename CGALi::Dispatch_centroid<InputIterator, Kernel_or_dim>::result_type
+typename internal::Dispatch_centroid<InputIterator, Kernel_or_dim>::result_type
 centroid(InputIterator begin, InputIterator end, const Kernel_or_dim& k_or_d)
 {
-  CGALi::Dispatch_centroid<InputIterator, Kernel_or_dim> dispatch_centroid;
+  internal::Dispatch_centroid<InputIterator, Kernel_or_dim> dispatch_centroid;
   return dispatch_centroid(begin, end, k_or_d);
 }
 
