@@ -15,8 +15,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Installation/include/CGAL/config.h $
-// $Id: config.h 49591 2009-05-26 08:18:11Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Installation/include/CGAL/config.h $
+// $Id: config.h 53268 2009-12-03 10:16:09Z spion $
 // 
 //
 // Author(s)     : Wieger Wesselink 
@@ -152,6 +152,19 @@
 #  define CGAL_SUNPRO_INITIALIZE(C)
 #endif
 
+//----------------------------------------------------------------------//
+// MacOSX specific.
+//----------------------------------------------------------------------//
+
+#ifdef __APPLE__
+#  if defined(__GNUG__) && (__GNUG__ == 4) && (__GNUC_MINOR__ == 0) \
+   && defined(__OPTIMIZE__) && !defined(CGAL_NO_WARNING_FOR_MACOSX_GCC_4_0_BUG)
+#    warning "Your configuration may exhibit run-time errors in CGAL code"
+#    warning "This appears with g++ 4.0 on MacOSX when optimizing"
+#    warning "You can disable this warning using -DCGAL_NO_WARNING_FOR_MACOSX_GCC_4_0_BUG"
+#    warning "For more information, see http://www.cgal.org/FAQ.html#mac_optimization_bug"
+#  endif
+#endif
 
 //-------------------------------------------------------------------//
 // When the global min and max are no longer defined (as macros) 
