@@ -1,4 +1,4 @@
-// Copyright (c) 2006-2007 Max-Planck-Institute Saarbruecken (Germany).
+// Copyright (c) 2006-2008 Max-Planck-Institute Saarbruecken (Germany).
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org); you can redistribute it and/or
@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.3-branch/Number_types/include/CGAL/gmpxx_coercion_traits.h $
-// $Id: gmpxx_coercion_traits.h 38995 2007-06-08 14:00:19Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Number_types/include/CGAL/gmpxx_coercion_traits.h $
+// $Id: gmpxx_coercion_traits.h 47264 2008-12-08 06:25:14Z hemmer $
 //
 //
 // Author(s)     : Michael Hemmer   <hemmer@mpi-inf.mpg.de>
@@ -30,8 +30,6 @@
 #include <CGAL/number_type_basic.h>
 #include <CGAL/Coercion_traits.h>
 
-#ifdef CGAL_USE_GMP
-
 #include <cstring> // needed by GMP 4.1.4 since <gmpxx.h> misses it.
 #include <gmpxx.h>
 #include <mpfr.h>
@@ -109,6 +107,5 @@ struct Coercion_traits< int , ::__gmp_expr< T , U> >
 
 CGAL_END_NAMESPACE
 
-#endif // CGAL_USE_GMP
 #endif //CGAL_GMPXX_COERCION_TRAITS_H 1
 //EOF
