@@ -15,8 +15,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/STL_Extension/include/CGAL/iterator.h $
-// $Id: iterator.h 50386 2009-07-06 09:30:22Z afabri $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/STL_Extension/include/CGAL/iterator.h $
+// $Id: iterator.h 56906 2010-06-21 09:55:07Z sloriot $
 // 
 //
 // Author(s)     : Michael Hoffmann <hoffmann@inf.ethz.ch>
@@ -1178,7 +1178,7 @@ filter_output_iterator(I e, const P& p)
 
 #ifndef CGAL_CFG_NO_CPP0X_VARIADIC_TEMPLATES
 
-namespace CGALi {
+namespace internal {
 
 template < typename D, typename V = cpp0x::tuple<>, typename O = cpp0x::tuple<> >
 struct Derivator
@@ -1209,7 +1209,7 @@ struct Derivator<D, cpp0x::tuple<V1, V...>, cpp0x::tuple<O1, O...> >
   }
 };
 
-} // CGALi
+} // internal
 
 
 // OutputIterator which accepts several types in *o++= and dispatches,
@@ -1219,7 +1219,7 @@ class Dispatch_output_iterator;
 
 template < typename... V, typename... O >
 class Dispatch_output_iterator < cpp0x::tuple<V...>, cpp0x::tuple<O...> >
- : private CGALi::Derivator<Dispatch_output_iterator< cpp0x::tuple<V...>, cpp0x::tuple<O...> >, cpp0x::tuple<V...>, cpp0x::tuple<O...> >
+ : private internal::Derivator<Dispatch_output_iterator< cpp0x::tuple<V...>, cpp0x::tuple<O...> >, cpp0x::tuple<V...>, cpp0x::tuple<O...> >
  , public cpp0x::tuple<O...>
 {
   static_assert(sizeof...(V) == sizeof...(O),
@@ -1228,7 +1228,7 @@ class Dispatch_output_iterator < cpp0x::tuple<V...>, cpp0x::tuple<O...> >
   static const int size = sizeof...(V);
 
   template <typename D, typename V_, typename O_>
-  friend class CGALi::Derivator;
+  friend class internal::Derivator;
 
 public:
 
@@ -1244,7 +1244,7 @@ public:
 private:
 
   typedef Dispatch_output_iterator Self;
-  typedef CGALi::Derivator<Self, Value_type_tuple, Iterator_tuple > Base;
+  typedef internal::Derivator<Self, Value_type_tuple, Iterator_tuple > Base;
 
 public:
 
@@ -1287,7 +1287,7 @@ class Dispatch_or_drop_output_iterator < cpp0x::tuple<V...>, cpp0x::tuple<O...>
   typedef Dispatch_output_iterator< cpp0x::tuple<V...>, cpp0x::tuple<O...> > Base;
 
   template <typename D, typename V_, typename O_>
-  friend class CGALi::Derivator;
+  friend class internal::Derivator;
 
 public:
 
@@ -1343,6 +1343,11 @@ public:
   Self& operator++(int){ return *this; }  
   
   Dispatch_output_iterator(O1 out1):Iterator_tuple(out1){}
+    
+  //Added because required by MSVC10
+  Dispatch_output_iterator(const Self& other):
+    Iterator_tuple(static_cast<const Iterator_tuple&>(other))
+  {}
   
   Self& operator=(const V1& obj){
     *cpp0x::get<0>(static_cast<Iterator_tuple& >(*this))++=obj;
@@ -1434,7 +1439,12 @@ public:
   Self& operator++(int){ return *this; }  
   
   Dispatch_output_iterator(O1 out1,O2 out2):Iterator_tuple(out1,out2){}
-  
+
+  //Added because required by MSVC10
+  Dispatch_output_iterator(const Self& other):
+    Iterator_tuple(static_cast<const Iterator_tuple&>(other))
+  {}
+
   Self& operator=(const V1& obj){
     *cpp0x::get<0>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
@@ -1515,7 +1525,7 @@ dispatch_or_drop_output(O1 out1,O2 out2){
   return Dispatch_or_drop_output_iterator<cpp0x::tuple<V1,V2>,cpp0x::tuple<O1,O2> >(out1,out2);
 }
 
-//Versio with 3 parameters
+//Version with 3 parameters
 template<class V1,class O1,class V2,class O2,class V3, class O3>
 class Dispatch_output_iterator<cpp0x::tuple<V1,V2,V3>,cpp0x::tuple<O1,O2,O3> >:public cpp0x::tuple<O1,O2,O3>{
   typedef Dispatch_output_iterator Self;
@@ -1535,7 +1545,12 @@ public:
   Self& operator++(int){ return *this; }  
   
   Dispatch_output_iterator(O1 out1,O2 out2,O3 out3):Iterator_tuple(out1,out2,out3){}
-  
+
+  //Added because required by MSVC10
+  Dispatch_output_iterator(const Self& other):
+    Iterator_tuple(static_cast<const Iterator_tuple&>(other))
+  {}  
+
   Self& operator=(const V1& obj){
     *cpp0x::get<0>(static_cast<Iterator_tuple& >(*this))++=obj;
     return *this;
@@ -1629,7 +1644,7 @@ dispatch_or_drop_output(O1 out1,O2 out2,O3 out3){
   return Dispatch_or_drop_output_iterator<cpp0x::tuple<V1,V2,V3>,cpp0x::tuple<O1,O2,O3> >(out1,out2,out3);
 }
 
-//Versio with 4 parameters
+//Version with 4 parameters
 template<class V1,class O1,class V2,class O2,class V3,class O3,class V4,class O4>
 class Dispatch_output_iterator<cpp0x::tuple<V1,V2,V3,V4>,cpp0x::tuple<O1,O2,O3,O4> >:public cpp0x::tuple<O1,O2,O3,O4>{
   typedef Dispatch_output_iterator Self;
@@ -1649,6 +1664,11 @@ public:
   Self& operator++(int){ return *this; }  
   
   Dispatch_output_iterator(O1 out1,O2 out2,O3 out3,O4 out4):Iterator_tuple(out1,out2,out3,out4){}
+
+  //Added because required by MSVC10
+  Dispatch_output_iterator(const Self& other):
+    Iterator_tuple(static_cast<const Iterator_tuple&>(other))
+  {}  
   
   Self& operator=(const V1& obj){
     *cpp0x::get<0>(static_cast<Iterator_tuple& >(*this))++=obj;
@@ -1753,7 +1773,7 @@ dispatch_or_drop_output(O1 out1,O2 out2,O3 out3,O4 out4){
   return Dispatch_or_drop_output_iterator<cpp0x::tuple<V1,V2,V3,V4>,cpp0x::tuple<O1,O2,O3,O4> >(out1,out2,out3,out4);
 }
 
-//Versio with 5 parameters
+//Version with 5 parameters
 template<class V1,class O1,class V2,class O2,class V3,class O3,class V4,class O4,class V5,class O5>
 class Dispatch_output_iterator<cpp0x::tuple<V1,V2,V3,V4,V5>,cpp0x::tuple<O1,O2,O3,O4,O5> >:public cpp0x::tuple<O1,O2,O3,O4,O5>{
   typedef Dispatch_output_iterator Self;
@@ -1773,6 +1793,11 @@ public:
   Self& operator++(int){ return *this; }  
   
   Dispatch_output_iterator(O1 out1,O2 out2,O3 out3,O4 out4,O5 out5):Iterator_tuple(out1,out2,out3,out4,out5){}
+
+  //Added because required by MSVC10
+  Dispatch_output_iterator(const Self& other):
+    Iterator_tuple(static_cast<const Iterator_tuple&>(other))
+  {}  
   
   Self& operator=(const V1& obj){
     *cpp0x::get<0>(static_cast<Iterator_tuple& >(*this))++=obj;
@@ -1887,7 +1912,7 @@ dispatch_or_drop_output(O1 out1,O2 out2,O3 out3,O4 out4,O5 out5){
   return Dispatch_or_drop_output_iterator<cpp0x::tuple<V1,V2,V3,V4,V5>,cpp0x::tuple<O1,O2,O3,O4,O5> >(out1,out2,out3,out4,out5);
 }
 
-//Versio with 6 parameters
+//Version with 6 parameters
 template<class V1,class O1,class V2,class O2,class V3,class O3,class V4,class O4,class V5,class O5,class V6,class O6>
 class Dispatch_output_iterator<cpp0x::tuple<V1,V2,V3,V4,V5,V6>,cpp0x::tuple<O1,O2,O3,O4,O5,O6> >:public cpp0x::tuple<O1,O2,O3,O4,O5,O6>{
   typedef Dispatch_output_iterator Self;
@@ -1907,6 +1932,11 @@ public:
   Self& operator++(int){ return *this; }  
   
   Dispatch_output_iterator(O1 out1,O2 out2,O3 out3,O4 out4,O5 out5,O6 out6):Iterator_tuple(out1,out2,out3,out4,out5,out6){}
+
+  //Added because required by MSVC10
+  Dispatch_output_iterator(const Self& other):
+    Iterator_tuple(static_cast<const Iterator_tuple&>(other))
+  {}  
   
   Self& operator=(const V1& obj){
     *cpp0x::get<0>(static_cast<Iterator_tuple& >(*this))++=obj;
@@ -2031,7 +2061,7 @@ dispatch_or_drop_output(O1 out1,O2 out2,O3 out3,O4 out4,O5 out5,O6 out6){
   return Dispatch_or_drop_output_iterator<cpp0x::tuple<V1,V2,V3,V4,V5,V6>,cpp0x::tuple<O1,O2,O3,O4,O5,O6> >(out1,out2,out3,out4,out5,out6);
 }
 
-//Versio with 7 parameters
+//Version with 7 parameters
 template<class V1,class O1,class V2,class O2,class V3,class O3,class V4,class O4,class V5,class O5,class V6,class O6,class V7,class O7>
 class Dispatch_output_iterator<cpp0x::tuple<V1,V2,V3,V4,V5,V6,V7>,cpp0x::tuple<O1,O2,O3,O4,O5,O6,O7> >:public cpp0x::tuple<O1,O2,O3,O4,O5,O6,O7>{
   typedef Dispatch_output_iterator Self;
@@ -2051,6 +2081,11 @@ public:
   Self& operator++(int){ return *this; }  
   
   Dispatch_output_iterator(O1 out1,O2 out2,O3 out3,O4 out4,O5 out5,O6 out6,O7 out7):Iterator_tuple(out1,out2,out3,out4,out5,out6,out7){}
+
+  //Added because required by MSVC10
+  Dispatch_output_iterator(const Self& other):
+    Iterator_tuple(static_cast<const Iterator_tuple&>(other))
+  {}  
   
   Self& operator=(const V1& obj){
     *cpp0x::get<0>(static_cast<Iterator_tuple& >(*this))++=obj;
