@@ -11,14 +11,14 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.3-branch/Min_quadrilateral_2/include/CGAL/minimum_enclosing_quadrilateral_2.h $
-// $Id: minimum_enclosing_quadrilateral_2.h 28567 2006-02-16 14:30:13Z lsaboret $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Min_quadrilateral_2/include/CGAL/minimum_enclosing_quadrilateral_2.h $
+// $Id: minimum_enclosing_quadrilateral_2.h 48717 2009-04-08 11:54:51Z spion $
 // 
 //
 // Author(s)     : Michael Hoffmann <hoffmann@inf.ethz.ch> and
 //                 Emo Welzl <emo@inf.ethz.ch>
 
-#if ! (CGAL_MINIMUM_ENCLOSING_QUADRILATERAL_2_H)
+#ifndef CGAL_MINIMUM_ENCLOSING_QUADRILATERAL_2_H
 #define CGAL_MINIMUM_ENCLOSING_QUADRILATERAL_2_H 1
 
 #ifndef CGAL_NO_DEPRECATED_CODE
