@@ -11,8 +11,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Matrix_search/include/CGAL/pierce_rectangles_2.h $
-// $Id: pierce_rectangles_2.h 48717 2009-04-08 11:54:51Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Matrix_search/include/CGAL/pierce_rectangles_2.h $
+// $Id: pierce_rectangles_2.h 56908 2010-06-21 10:05:32Z afabri $
 // 
 //
 // Author(s)     : Michael Hoffmann <hoffmann@inf.ethz.ch>
@@ -239,14 +239,14 @@ struct Staircases : public Loc_domain< Traits_ > {
     do {
       brstc.push_back(*i++);
       i = find_if(i, ysort.end(),
-                  bind(this->traits.less_x_2_object(), brstc.back(), _1));
+                  boost::bind(this->traits.less_x_2_object(), brstc.back(), _1));
     } while (i != ysort.end());
     // top-left
     Riterator j = ysort.rbegin();
     do {
       tlstc.push_back(*j++);
       j = find_if(j, ysort.rend(),
-                  bind(this->traits.less_x_2_object(), _1, tlstc.back()));
+                  boost::bind(this->traits.less_x_2_object(), _1, tlstc.back()));
     } while (j != ysort.rend());
 
     // build left-bottom and right-top staircases
@@ -256,14 +256,14 @@ struct Staircases : public Loc_domain< Traits_ > {
     do {
       lbstc.push_back(*i++);
       i = find_if(i, xsort.end(),
-                  bind(this->traits.less_y_2_object(), _1, lbstc.back()));
+                  boost::bind(this->traits.less_y_2_object(), _1, lbstc.back()));
     } while (i != xsort.end());
     // right-top
     j = xsort.rbegin();
     do {
       rtstc.push_back(*j++);
       j = find_if(j, xsort.rend(),
-                  bind(this->traits.less_y_2_object(), rtstc.back(), _1));
+                  boost::bind(this->traits.less_y_2_object(), rtstc.back(), _1));
     } while (j != xsort.rend());
   } // Staircases(b, e, t)
 
@@ -489,7 +489,6 @@ two_cover_points(
 {
   using std::find_if;
   using std::less;
-  using boost::bind;
 
   typedef typename Traits::FT           FT;
   typedef typename Traits::Point_2      Point_2;
@@ -510,11 +509,11 @@ two_cover_points(
     if (d.end() ==
         find_if(d.begin(),
                 d.end(),
-                bind(less<FT>(), 
+                boost::bind(less<FT>(), 
 		     d.r,
-		     bind(Min<FT>(), 
-			  bind(dist, d[0], _1), 
-			  bind(dist, d[2], _1)))))
+		     boost::bind(Min<FT>(), 
+			  boost::bind(dist, d[0], _1), 
+			  boost::bind(dist, d[2], _1)))))
       {
         *o++ = d[0];
         *o++ = d[2];
@@ -526,11 +525,11 @@ two_cover_points(
     if (d.end() ==
         find_if(d.begin(),
                 d.end(),
-                bind(less<FT>(), 
+                boost::bind(less<FT>(), 
 		     d.r,
-		     bind(Min<FT>(), 
-			  bind(dist, d[1], _1), 
-			  bind(dist, d[3], _1)))))
+		     boost::bind(Min<FT>(), 
+			  boost::bind(dist, d[1], _1), 
+			  boost::bind(dist, d[3], _1)))))
       {
         *o++ = d[1];
         *o++ = d[3];
@@ -553,7 +552,6 @@ three_cover_points(
   using std::find_if;
   using std::less;
   using std::iter_swap;
-  using boost::bind;
 
   CGAL_optimisation_precondition(!d.empty());
 
@@ -572,7 +570,7 @@ three_cover_points(
     
     // find first point not covered by the rectangle at d[k]
     Iterator i = find_if(d.begin(), d.end(),
-                         bind(less<FT>(), d.r, bind(dist, corner, _1)));
+                         boost::bind(less<FT>(), d.r, boost::bind(dist, corner, _1)));
     
     // are all points already covered?
     if (i == d.end()) {
@@ -615,12 +613,12 @@ three_cover_points(
     
     CGAL_optimisation_expensive_assertion(
       save_end == find_if(d.end(), save_end,
-                          bind(less<FT>(), d.r, bind(dist, corner, _1))));
+                          boost::bind(less<FT>(), d.r, boost::bind(dist, corner, _1))));
     CGAL_optimisation_expensive_assertion(
       d.end() == find_if(d.begin(), d.end(),
-                         bind(std::greater_equal<FT>(), 
+                         boost::bind(std::greater_equal<FT>(), 
 			      d.r,
-			      bind(dist, corner, _1))));
+			      boost::bind(dist, corner, _1))));
     
     
     two_cover_points(d, o, ok);
@@ -657,7 +655,6 @@ four_cover_points(Staircases< Traits >& d, OutputIterator o, bool& ok)
   using std::iter_swap;
   using std::find_if;
   using std::back_inserter;
-  using boost::bind;
   
   typedef typename Traits::Point_2                  Point_2;
   typedef typename Traits::FT                       FT;
@@ -710,7 +707,7 @@ four_cover_points(Staircases< Traits >& d, OutputIterator o, bool& ok)
   
     // find first point not covered by the rectangle at d[k]
     Iterator i = find_if(d.begin(), d.end(),
-                         bind(less<FT>(), d.r, bind(dist, corner, _1)));
+                         boost::bind(less<FT>(), d.r, boost::bind(dist, corner, _1)));
     
     // are all points already covered?
     if (i == d.end()) {
@@ -753,12 +750,12 @@ four_cover_points(Staircases< Traits >& d, OutputIterator o, bool& ok)
     
     CGAL_optimisation_expensive_assertion(
       save_end == find_if(d.end(), save_end,
-                          bind(less<FT>(), d.r, bind(dist, corner, _1))));
+                          boost::bind(less<FT>(), d.r, boost::bind(dist, corner, _1))));
     CGAL_optimisation_expensive_assertion(
       d.end() == find_if(d.begin(), d.end(),
-                         bind(std::greater_equal<FT>(), 
+                         boost::bind(std::greater_equal<FT>(), 
 			      d.r,
-			      bind(dist, corner, _1))));
+			      boost::bind(dist, corner, _1))));
     
     
     three_cover_points(d, o, ok);
