@@ -15,8 +15,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Number_types/src/CGAL/Interval_arithmetic.cpp $
-// $Id: Interval_arithmetic.cpp 41714 2008-01-20 20:24:20Z spion $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Number_types/src/CGAL/Interval_arithmetic.cpp $
+// $Id: Interval_arithmetic.cpp 51456 2009-08-24 17:10:04Z spion $
 // 
 //
 // Author(s)     : Sylvain Pion
@@ -42,7 +42,7 @@ double init_min_double()
 }
 } // anonymous namespace
 
-namespace CGALi {
+namespace internal {
 double minimin = init_min_double();
 }
 #endif
