@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.5-branch/Qt_widget/src/CGALQt/Qt_widget_history.cpp $
-// $Id: Qt_widget_history.cpp 45380 2008-09-08 13:15:39Z lrineau $
+// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.6-branch/Qt_widget/src/CGALQt/Qt_widget_history.cpp $
+// $Id: Qt_widget_history.cpp 53026 2009-11-14 11:49:52Z spion $
 // 
 //
 // Author(s)     : Radu Ursu and Laurent Rineau
@@ -42,7 +42,7 @@ Qt_widget_history::Qt_widget_history(Qt_widget* parent, const char* name):
 	  this, SLOT(save()));
   connect(parent, SIGNAL(internal_clear_history()),
 	  this, SLOT(clear()));
-};
+}
 
 void Qt_widget_history::backward()
 {
@@ -90,6 +90,6 @@ void Qt_widget_history::save()
   emit forwardAvaillable(false);
 }
 
-}; // end namespace
+} // end namespace
 #include "Qt_widget_history.moc"
 
